@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp.c 5956 2006-09-13 18:22:34Z mike $"
+ * "$Id: ipp.c 6484 2007-04-30 17:18:21Z mike $"
  *
  *   IPP backend for the Common UNIX Printing System (CUPS).
  *
@@ -101,12 +101,14 @@ main(int  argc,				/* I - Number of command-line args */
      char *argv[])			/* I - Command-line arguments */
 {
   int		i;			/* Looping var */
+  int		send_options;		/* Send job options? */
   int		num_options;		/* Number of printer options */
   cups_option_t	*options;		/* Printer options */
   char		method[255],		/* Method in URI */
 		hostname[1024],		/* Hostname */
 		username[255],		/* Username info */
 		resource[1024],		/* Resource info (printer name) */
+		addrname[256],		/* Address name */
 		*optptr,		/* Pointer to URI options */
 		name[255],		/* Name of option */
 		value[255],		/* Value of option */
@@ -415,6 +417,8 @@ main(int  argc,				/* I - Number of command-line args */
     filename  = tmpfilename;
     files     = &filename;
     num_files = 1;
+
+    send_options = 0;
   }
   else
   {
@@ -425,6 +429,8 @@ main(int  argc,				/* I - Number of command-line args */
     num_files = argc - 6;
     files     = argv + 6;
 
+    send_options = strncasecmp(content_type, "application/vnd.cups-", 21) != 0;
+
 #ifdef HAVE_LIBZ
     if (compression)
       compress_files(num_files, files);
@@ -574,6 +580,18 @@ main(int  argc,				/* I - Number of command-line args */
   fputs("STATE: -connecting-to-device\n", stderr);
   fprintf(stderr, "INFO: Connected to %s...\n", hostname);
 
+#ifdef AF_INET6
+  if (http->hostaddr->addr.sa_family == AF_INET6)
+    fprintf(stderr, "DEBUG: Connected to [%s]:%d (IPv6)...\n", 
+		    httpAddrString(http->hostaddr, addrname, sizeof(addrname)),
+		    ntohs(http->hostaddr->ipv6.sin6_port));
+  else
+#endif /* AF_INET6 */
+    if (http->hostaddr->addr.sa_family == AF_INET)
+      fprintf(stderr, "DEBUG: Connected to %s:%d (IPv4)...\n",
+		      httpAddrString(http->hostaddr, addrname, sizeof(addrname)),
+		      ntohs(http->hostaddr->ipv4.sin_port));
+
  /*
   * Build a URI for the printer and fill the standard IPP attributes for
   * an IPP_PRINT_FILE request.  We can't use the URI in argv[0] because it
@@ -840,6 +858,7 @@ main(int  argc,				/* I - Number of command-line args */
 	content_type     = "application/postscript";
 	copies           = 1;
 	copies_remaining = 1;
+        send_options     = 0;
       }
     }
 #endif /* __APPLE__ */
@@ -855,7 +874,7 @@ main(int  argc,				/* I - Number of command-line args */
 	                            num_options, &options);
     }
 
-    if (copies_sup && version > 0)
+    if (copies_sup && version > 0 && send_options)
     {
      /*
       * Only send options if the destination printer supports the copies
@@ -1065,8 +1084,7 @@ main(int  argc,				/* I - Number of command-line args */
           * Stop polling if the job is finished or pending-held...
 	  */
 
-          if (job_state->values[0].integer > IPP_JOB_PROCESSING ||
-	      job_state->values[0].integer == IPP_JOB_HELD)
+          if (job_state->values[0].integer > IPP_JOB_STOPPED)
 	  {
 	    if ((job_sheets = ippFindAttribute(response, 
 	                                       "job-media-sheets-completed",
@@ -1367,7 +1385,7 @@ report_printer_state(ipp_t *ipp)	/* I - IPP response */
     strlcat(state, reason, sizeof(state));
 
     prefix  = ",";
-    message = NULL;
+    message = "";
 
     if (!strncmp(reason, "media-needed", 12))
       message = "Media tray needs to be filled.";
@@ -1653,5 +1671,5 @@ sigterm_handler(int sig)		/* I - Signal */
 
 
 /*
- * End of "$Id: ipp.c 5956 2006-09-13 18:22:34Z mike $".
+ * End of "$Id: ipp.c 6484 2007-04-30 17:18:21Z mike $".
  */
