@@ -1,11 +1,11 @@
 /*
- * "$Id: usb-unix.c 6032 2006-10-12 19:19:47Z mike $"
+ * "$Id: usb-unix.c 6511 2007-05-04 14:03:02Z mike $"
  *
  *   USB port backend for the Common UNIX Printing System (CUPS).
  *
  *   This file is included from "usb.c" when compiled on UNIX/Linux.
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -44,7 +44,7 @@
  * Local functions...
  */
 
-int	open_device(const char *uri, int *use_bc);
+static int	open_device(const char *uri, int *use_bc);
 
 
 /*
@@ -78,14 +78,28 @@ print_device(const char *uri,		/* I - Device URI */
 
   do
   {
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__DragonFly__)
    /*
-    * Disable backchannel data when printing to Canon or Minolta USB
-    * printers - apparently these printers will return the IEEE-1284
-    * device ID over and over and over when they get a read request...
+    * *BSD's ulpt driver currently does not support the
+    * back-channel, incorrectly returns data ready on a select(),
+    * and locks up on read()...
     */
 
-    use_bc = strcasecmp(hostname, "Canon") != 0 ||
-             strstr(hostname, "Minolta") != NULL;
+    use_bc = 0;
+
+#else
+   /*
+    * Disable backchannel data when printing to Brother, Canon, or
+    * Minolta USB printers - apparently these printers will return
+    * the IEEE-1284 device ID over and over and over when they get
+    * a read request...
+    */
+
+    use_bc = strcasecmp(hostname, "Brother") &&
+             strcasecmp(hostname, "Canon") &&
+             strcasecmp(hostname, "Konica Minolta") &&
+             strcasecmp(hostname, "Minolta");
+#endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ || __DragonFly__ */
 
     if ((device_fd = open_device(uri, &use_bc)) == -1)
     {
@@ -182,7 +196,7 @@ print_device(const char *uri,		/* I - Device URI */
  * 'list_devices()' - List all USB devices.
  */
 
-void
+static void
 list_devices(void)
 {
 #ifdef __linux
@@ -287,7 +301,7 @@ list_devices(void)
  * 'open_device()' - Open a USB device...
  */
 
-int					/* O - File descriptor or -1 on error */
+static int				/* O - File descriptor or -1 on error */
 open_device(const char *uri,		/* I - Device URI */
             int        *use_bc)		/* O - Set to 0 for unidirectional */
 {
@@ -507,7 +521,12 @@ open_device(const char *uri,		/* I - Device URI */
   }
 #else
   {
-    if ((fd = open(uri + 4, O_RDWR | O_EXCL)) < 0)
+    if (use_bc)
+      fd = open(uri + 4, O_RDWR | O_EXCL);
+    else
+      fd = -1;
+
+    if (fd < 0)
     {
       fd      = open(uri + 4, O_WRONLY | O_EXCL);
       *use_bc = 0;
@@ -525,5 +544,5 @@ open_device(const char *uri,		/* I - Device URI */
 
 
 /*
- * End of "$Id: usb-unix.c 6032 2006-10-12 19:19:47Z mike $".
+ * End of "$Id: usb-unix.c 6511 2007-05-04 14:03:02Z mike $".
  */
