@@ -1,9 +1,9 @@
 /*
- * "$Id: usb.c 5591 2006-05-26 19:51:59Z mike $"
+ * "$Id: usb.c 6441 2007-04-04 13:54:51Z mike $"
  *
  *   USB port backend for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -60,10 +60,10 @@
  * Local functions...
  */
 
-void	list_devices(void);
-int	print_device(const char *uri, const char *hostname,
-	             const char *resource, const char *options,
-		     int print_fd, int copies, int argc, char *argv[]);
+static void	list_devices(void);
+static int	print_device(const char *uri, const char *hostname,
+		             const char *resource, const char *options,
+			     int print_fd, int copies, int argc, char *argv[]);
 
 
 /*
@@ -85,7 +85,7 @@ int	print_device(const char *uri, const char *hostname,
  * 'list_devices()' - List all available USB devices to stdout.
  */
 
-void
+static void
 list_devices(void)
 {
  /*
@@ -103,7 +103,7 @@ list_devices(void)
  * 'print_device()' - Print a file to a USB device.
  */
 
-int					/* O - Exit status */
+static int				/* O - Exit status */
 print_device(const char *uri,		/* I - Device URI */
              const char *hostname,	/* I - Hostname/manufacturer */
              const char *resource,	/* I - Resource/modelname */
@@ -270,5 +270,5 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
 
 
 /*
- * End of "$Id: usb.c 5591 2006-05-26 19:51:59Z mike $".
+ * End of "$Id: usb.c 6441 2007-04-04 13:54:51Z mike $".
  */
