@@ -1,9 +1,9 @@
 /*
- * "$Id: lpq.c,v 1.31 2004/09/08 19:01:34 mike Exp $"
+ * "$Id: lpq.c 5926 2006-09-05 20:45:47Z mike $"
  *
  *   "lpq" command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2004 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -15,9 +15,9 @@
  *       Attn: CUPS Licensing Information
  *       Easy Software Products
  *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636-3111 USA
+ *       Hollywood, Maryland 20636 USA
  *
- *       Voice: (301) 373-9603
+ *       Voice: (301) 373-9600
  *       EMail: cups-info@cups.org
  *         WWW: http://www.cups.org
  *
@@ -41,7 +41,7 @@
 #include <stdlib.h>
 #include <cups/string.h>
 #include <cups/cups.h>
-#include <cups/language.h>
+#include <cups/i18n.h>
 #include <cups/debug.h>
 
 
@@ -49,9 +49,10 @@
  * Local functions...
  */
 
-static int	show_jobs(http_t *, const char *, const char *, const int,
-		          const int);
-static void	show_printer(http_t *, const char *);
+static http_t	*connect_server(const char *, http_t *);
+static int	show_jobs(const char *, http_t *, const char *,
+		          const char *, const int, const int);
+static void	show_printer(const char *, http_t *, const char *);
 static void	usage(void);
 
 
@@ -60,49 +61,38 @@ static void	usage(void);
  */
 
 int
-main(int  argc,		/* I - Number of command-line arguments */
-     char *argv[])	/* I - Command-line arguments */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  int		i;		/* Looping var */
-  http_t	*http;		/* Connection to server */
-  const char	*dest,		/* Desired printer */
-		*user,		/* Desired user */
-		*val;		/* Environment variable name */
-  char		*instance;	/* Printer instance */
-  int		id,		/* Desired job ID */
-		all,		/* All printers */
-		interval,	/* Reporting interval */
-		longstatus;	/* Show file details */
-  int		num_dests;	/* Number of destinations */
-  cups_dest_t	*dests;		/* Destinations */
-#ifdef HAVE_SSL
-  http_encryption_t encryption;	/* Encryption? */
-#endif /* HAVE_SSL */
+  int		i;			/* Looping var */
+  http_t	*http;			/* Connection to server */
+  const char	*dest,			/* Desired printer */
+		*user,			/* Desired user */
+		*val;			/* Environment variable name */
+  char		*instance;		/* Printer instance */
+  int		id,			/* Desired job ID */
+		all,			/* All printers */
+		interval,		/* Reporting interval */
+		longstatus;		/* Show file details */
+  int		num_dests;		/* Number of destinations */
+  cups_dest_t	*dests;			/* Destinations */
 
 
- /*
-  * Connect to the scheduler...
-  */
-
-  if ((http = httpConnectEncrypt(cupsServer(), ippPort(),
-                                 cupsEncryption())) == NULL)
-  {
-    fputs("lpq: Unable to contact server!\n", stderr);
-    return (1);
-  }
+  _cupsSetLocale(argv);
 
  /*
   * Check for command-line options...
   */
 
+  http       = NULL;
   dest       = NULL;
   user       = NULL;
   id         = 0;
   interval   = 0;
   longstatus = 0;
   all        = 0;
-
-  num_dests = cupsGetDests(&dests);
+  num_dests  = 0;
+  dests      = NULL;
 
   for (i = 1; i < argc; i ++)
     if (argv[i][0] == '+')
@@ -113,16 +103,36 @@ main(int  argc,		/* I - Number of command-line arguments */
       {
         case 'E' : /* Encrypt */
 #ifdef HAVE_SSL
-	    encryption = HTTP_ENCRYPT_REQUIRED;
+	    cupsSetEncryption(HTTP_ENCRYPT_REQUIRED);
 
 	    if (http)
-	      httpEncryption(http, encryption);
+	      httpEncryption(http, HTTP_ENCRYPT_REQUIRED);
 #else
-            fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
-	            argv[0]);
+            _cupsLangPrintf(stderr,
+	                    _("%s: Sorry, no encryption support compiled in!\n"),
+	                    argv[0]);
 #endif /* HAVE_SSL */
 	    break;
 
+        case 'U' : /* Username */
+	    if (argv[i][2] != '\0')
+	      cupsSetUser(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected username after "
+				  "\'-U\' option!\n"),
+		        	argv[0]);
+	        return (1);
+	      }
+
+              cupsSetUser(argv[i]);
+	    }
+	    break;
+	    
         case 'P' : /* Printer */
 	    if (argv[i][2])
 	      dest = argv[i] + 2;
@@ -144,13 +154,21 @@ main(int  argc,		/* I - Number of command-line arguments */
 	    if ((instance = strchr(dest, '/')) != NULL)
 	      *instance++ = '\0';
 
+            http = connect_server(argv[0], http);
+
+            if (num_dests == 0)
+              num_dests = cupsGetDests2(http, &dests);
+
             if (cupsGetDest(dest, instance, num_dests, dests) == NULL)
 	    {
 	      if (instance)
-		fprintf(stderr, "lpq: Unknown destination \"%s/%s\"!\n",
-		        dest, instance);
+		_cupsLangPrintf(stderr,
+		                _("%s: Error - unknown destination \"%s/%s\"!\n"),
+		        	argv[0], dest, instance);
               else
-		fprintf(stderr, "lpq: Unknown destination \"%s\"!\n", dest);
+		_cupsLangPrintf(stderr,
+		                _("%s: Unknown destination \"%s\"!\n"),
+				argv[0], dest);
 
 	      return (1);
 	    }
@@ -160,6 +178,32 @@ main(int  argc,		/* I - Number of command-line arguments */
 	    all = 1;
 	    break;
 
+        case 'h' : /* Connect to host */
+	    if (http)
+	    {
+	      httpClose(http);
+	      http = NULL;
+	    }
+
+	    if (argv[i][2] != '\0')
+              cupsSetServer(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		        	_("%s: Error - expected hostname after "
+			          "\'-h\' option!\n"),
+				argv[0]);
+		return (1);
+              }
+	      else
+                cupsSetServer(argv[i]);
+	    }
+	    break;
+
 	case 'l' : /* Long status */
 	    longstatus = 1;
 	    break;
@@ -177,8 +221,13 @@ main(int  argc,		/* I - Number of command-line arguments */
     else
       user = argv[i];
 
+  http = connect_server(argv[0], http);
+
   if (dest == NULL && !all)
   {
+    if (num_dests == 0)
+      num_dests = cupsGetDests2(http, &dests);
+
     for (i = 0; i < num_dests; i ++)
       if (dests[i].is_default)
 	dest = dests[i].name;
@@ -201,10 +250,14 @@ main(int  argc,		/* I - Number of command-line arguments */
 	val = "LPDEST";
 
       if (dest && !cupsGetDest(dest, NULL, num_dests, dests))
-	fprintf(stderr, "lp: error - %s environment variable names non-existent destination \"%s\"!\n",
-        	val, dest);
+	_cupsLangPrintf(stderr,
+	                _("%s: error - %s environment variable names "
+			  "non-existent destination \"%s\"!\n"),
+        	        argv[0], val, dest);
       else
-	fputs("lpq: error - no default destination available.\n", stderr);
+	_cupsLangPrintf(stderr,
+	                _("%s: error - no default destination available.\n"),
+			argv[0]);
       httpClose(http);
       cupsFreeDests(num_dests, dests);
       return (1);
@@ -218,9 +271,9 @@ main(int  argc,		/* I - Number of command-line arguments */
   for (;;)
   {
     if (dest)
-      show_printer(http, dest);
+      show_printer(argv[0], http, dest);
 
-    i = show_jobs(http, dest, user, id, longstatus);
+    i = show_jobs(argv[0], http, dest, user, id, longstatus);
 
     if (i && interval)
     {
@@ -242,37 +295,61 @@ main(int  argc,		/* I - Number of command-line arguments */
 }
 
 
+/*
+ * 'connect_server()' - Connect to the server as necessary...
+ */
+
+static http_t *				/* O - New HTTP connection */
+connect_server(const char *command,	/* I - Command name */
+               http_t     *http)	/* I - Current HTTP connection */
+{
+  if (!http)
+  {
+    http = httpConnectEncrypt(cupsServer(), ippPort(),
+	                      cupsEncryption());
+
+    if (http == NULL)
+    {
+      _cupsLangPrintf(stderr, _("%s: Unable to connect to server\n"), command);
+      exit(1);
+    }
+  }
+
+  return (http);
+}
+
+
 /*
  * 'show_jobs()' - Show jobs.
  */
 
-static int			/* O - Number of jobs in queue */
-show_jobs(http_t     *http,	/* I - HTTP connection to server */
-          const char *dest,	/* I - Destination */
-	  const char *user,	/* I - User */
-	  const int  id,	/* I - Job ID */
-	  const int  longstatus)/* I - 1 if long report desired */
+static int				/* O - Number of jobs in queue */
+show_jobs(const char *command,		/* I - Command name */
+          http_t     *http,		/* I - HTTP connection to server */
+          const char *dest,		/* I - Destination */
+	  const char *user,		/* I - User */
+	  const int  id,		/* I - Job ID */
+	  const int  longstatus)	/* I - 1 if long report desired */
 {
-  ipp_t		*request,	/* IPP Request */
-		*response;	/* IPP Response */
-  ipp_attribute_t *attr;	/* Current attribute */
-  cups_lang_t	*language;	/* Default language */
-  const char	*jobdest,	/* Pointer into job-printer-uri */
-		*jobuser,	/* Pointer to job-originating-user-name */
-		*jobname;	/* Pointer to job-name */
-  ipp_jstate_t	jobstate;	/* job-state */
-  int		jobid,		/* job-id */
-		jobsize,	/* job-k-octets */
+  ipp_t		*request,		/* IPP Request */
+		*response;		/* IPP Response */
+  ipp_attribute_t *attr;		/* Current attribute */
+  const char	*jobdest,		/* Pointer into job-printer-uri */
+		*jobuser,		/* Pointer to job-originating-user-name */
+		*jobname;		/* Pointer to job-name */
+  ipp_jstate_t	jobstate;		/* job-state */
+  int		jobid,			/* job-id */
+		jobsize,		/* job-k-octets */
 #ifdef __osf__
-		jobpriority,	/* job-priority */
+		jobpriority,		/* job-priority */
 #endif /* __osf__ */
-		jobcount,	/* Number of jobs */
-		jobcopies,	/* Number of copies */
-		rank;		/* Rank of job */
-  char		resource[1024];	/* Resource string */
-  char		rankstr[255];	/* Rank string */
-  char		namestr[1024];	/* Job name string */
-  static const char *ranks[10] =/* Ranking strings */
+		jobcount,		/* Number of jobs */
+		jobcopies,		/* Number of copies */
+		rank;			/* Rank of job */
+  char		resource[1024];		/* Resource string */
+  char		rankstr[255];		/* Rank string */
+  char		namestr[1024];		/* Job name string */
+  static const char *ranks[10] =	/* Ranking strings */
 		{
 		  "th",
 		  "st",
@@ -302,18 +379,7 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
   *    job-uri or printer-uri
   */
 
-  request = ippNew();
-
-  request->request.op.operation_id = id ? IPP_GET_JOB_ATTRIBUTES : IPP_GET_JOBS;
-  request->request.op.request_id   = 1;
-
-  language = cupsLangDefault();
-
-  attr = ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-                      "attributes-charset", NULL, cupsLangEncoding(language));
-
-  attr = ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-                      "attributes-natural-language", NULL, language->language);
+  request = ippNewRequest(id ? IPP_GET_JOB_ATTRIBUTES : IPP_GET_JOBS);
 
   if (dest == NULL)
   {
@@ -327,7 +393,8 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
   }
   else
   {
-    snprintf(resource, sizeof(resource), "ipp://localhost/printers/%s", dest);
+    httpAssembleURIf(HTTP_URI_CODING_ALL, resource, sizeof(resource), "ipp",
+                     NULL, "localhost", 0, "/printers/%s", dest);
 
     ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI, "printer-uri",
                  NULL, resource);
@@ -350,8 +417,7 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
   {
     if (response->request.status.status_code > IPP_OK_CONFLICT)
     {
-      fprintf(stderr, "lpq: get-jobs failed: %s\n",
-              ippErrorString(response->request.status.status_code));
+      _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
       ippDelete(response);
       return (0);
     }
@@ -391,38 +457,38 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
 
       while (attr != NULL && attr->group_tag == IPP_TAG_JOB)
       {
-        if (strcmp(attr->name, "job-id") == 0 &&
+        if (!strcmp(attr->name, "job-id") &&
 	    attr->value_tag == IPP_TAG_INTEGER)
 	  jobid = attr->values[0].integer;
 
-        if (strcmp(attr->name, "job-k-octets") == 0 &&
+        if (!strcmp(attr->name, "job-k-octets") &&
 	    attr->value_tag == IPP_TAG_INTEGER)
-	  jobsize = attr->values[0].integer * 1024;
+	  jobsize = attr->values[0].integer;
 
 #ifdef __osf__
-        if (strcmp(attr->name, "job-priority") == 0 &&
+        if (!strcmp(attr->name, "job-priority") &&
 	    attr->value_tag == IPP_TAG_INTEGER)
 	  jobpriority = attr->values[0].integer;
 #endif /* __osf__ */
 
-        if (strcmp(attr->name, "job-state") == 0 &&
+        if (!strcmp(attr->name, "job-state") &&
 	    attr->value_tag == IPP_TAG_ENUM)
 	  jobstate = (ipp_jstate_t)attr->values[0].integer;
 
-        if (strcmp(attr->name, "job-printer-uri") == 0 &&
+        if (!strcmp(attr->name, "job-printer-uri") &&
 	    attr->value_tag == IPP_TAG_URI)
 	  if ((jobdest = strrchr(attr->values[0].string.text, '/')) != NULL)
 	    jobdest ++;
 
-        if (strcmp(attr->name, "job-originating-user-name") == 0 &&
+        if (!strcmp(attr->name, "job-originating-user-name") &&
 	    attr->value_tag == IPP_TAG_NAME)
 	  jobuser = attr->values[0].string.text;
 
-        if (strcmp(attr->name, "job-name") == 0 &&
+        if (!strcmp(attr->name, "job-name") &&
 	    attr->value_tag == IPP_TAG_NAME)
 	  jobname = attr->values[0].string.text;
 
-        if (strcmp(attr->name, "copies") == 0 &&
+        if (!strcmp(attr->name, "copies") &&
 	    attr->value_tag == IPP_TAG_INTEGER)
 	  jobcopies = attr->values[0].integer;
 
@@ -443,9 +509,13 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
 
       if (!longstatus && jobcount == 0)
 #ifdef __osf__
-	puts("Rank   Owner      Pri  Job        Files                       Total Size");
+	_cupsLangPuts(stdout,
+	              _("Rank   Owner      Pri  Job        Files"
+		        "                       Total Size\n"));
 #else
-	puts("Rank    Owner   Job     File(s)                         Total Size");
+	_cupsLangPuts(stdout,
+	              _("Rank    Owner   Job     File(s)"
+		        "                         Total Size\n"));
 #endif /* __osf__ */
 
       jobcount ++;
@@ -473,7 +543,7 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
 
       if (longstatus)
       {
-        puts("");
+        _cupsLangPuts(stdout, "\n");
 
         if (jobcopies > 1)
 	  snprintf(namestr, sizeof(namestr), "%d copies of %s", jobcopies,
@@ -481,16 +551,21 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
 	else
 	  strlcpy(namestr, jobname, sizeof(namestr));
 
-        printf("%s: %-33.33s [job %d localhost]\n", jobuser, rankstr, jobid);
-        printf("        %-39.39s %d bytes\n", namestr, jobsize);
+        _cupsLangPrintf(stdout, _("%s: %-33.33s [job %d localhost]\n"),
+	                jobuser, rankstr, jobid);
+        _cupsLangPrintf(stdout, _("        %-39.39s %.0f bytes\n"),
+	                namestr, 1024.0 * jobsize);
       }
       else
 #ifdef __osf__
-        printf("%-6s %-10.10s %-4d %-10d %-27.27s %d bytes\n", rankstr, jobuser,
-	       jobpriority, jobid, jobname, jobsize);
+        _cupsLangPrintf(stdout,
+	                _("%-6s %-10.10s %-4d %-10d %-27.27s %.0f bytes\n"),
+			rankstr, jobuser, jobpriority, jobid, jobname,
+			1024.0 * jobsize);
 #else
-        printf("%-7s %-7.7s %-7d %-31.31s %d bytes\n", rankstr, jobuser,
-	       jobid, jobname, jobsize);
+        _cupsLangPrintf(stdout,
+	                _("%-7s %-7.7s %-7d %-31.31s %.0f bytes\n"),
+			rankstr, jobuser, jobid, jobname, 1024.0 * jobsize);
 #endif /* __osf */
 
       if (attr == NULL)
@@ -501,12 +576,12 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
   }
   else
   {
-    fprintf(stderr, "lpq: get-jobs failed: %s\n", ippErrorString(cupsLastError()));
+    _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
     return (0);
   }
 
   if (jobcount == 0)
-    puts("no entries");
+    _cupsLangPuts(stdout, _("no entries\n"));
 
   return (jobcount);
 }
@@ -517,16 +592,15 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
  */
 
 static void
-show_printer(http_t     *http,	/* I - HTTP connection to server */
-             const char *dest)	/* I - Destination */
+show_printer(const char *command,	/* I - Command name */
+             http_t     *http,		/* I - HTTP connection to server */
+             const char *dest)		/* I - Destination */
 {
-  ipp_t		*request,	/* IPP Request */
-		*response;	/* IPP Response */
-  ipp_attribute_t *attr;	/* Current attribute */
-  cups_lang_t	*language;	/* Default language */
-  ipp_pstate_t	state;		/* Printer state */
-  char		uri[HTTP_MAX_URI];
-				/* Printer URI */
+  ipp_t		*request,		/* IPP Request */
+		*response;		/* IPP Response */
+  ipp_attribute_t *attr;		/* Current attribute */
+  ipp_pstate_t	state;			/* Printer state */
+  char		uri[HTTP_MAX_URI];	/* Printer URI */
 
 
   if (http == NULL)
@@ -541,20 +615,10 @@ show_printer(http_t     *http,	/* I - HTTP connection to server */
   *    printer-uri
   */
 
-  request = ippNew();
+  request = ippNewRequest(IPP_GET_PRINTER_ATTRIBUTES);
 
-  request->request.op.operation_id = IPP_GET_PRINTER_ATTRIBUTES;
-  request->request.op.request_id   = 1;
-
-  language = cupsLangDefault();
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-               "attributes-charset", NULL, cupsLangEncoding(language));
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-               "attributes-natural-language", NULL, language->language);
-
-  snprintf(uri, sizeof(uri), "ipp://localhost/printers/%s", dest);
+  httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
+                   "localhost", 0, "/printers/%s", dest);
   ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
                "printer-uri", NULL, uri);
 
@@ -566,8 +630,7 @@ show_printer(http_t     *http,	/* I - HTTP connection to server */
   {
     if (response->request.status.status_code > IPP_OK_CONFLICT)
     {
-      fprintf(stderr, "lpq: get-printer-attributes failed: %s\n",
-              ippErrorString(response->request.status.status_code));
+      _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
       ippDelete(response);
       return;
     }
@@ -580,21 +643,21 @@ show_printer(http_t     *http,	/* I - HTTP connection to server */
     switch (state)
     {
       case IPP_PRINTER_IDLE :
-          printf("%s is ready\n", dest);
+          _cupsLangPrintf(stdout, _("%s is ready\n"), dest);
 	  break;
       case IPP_PRINTER_PROCESSING :
-          printf("%s is ready and printing\n", dest);
+          _cupsLangPrintf(stdout, _("%s is ready and printing\n"),
+	                  dest);
 	  break;
       case IPP_PRINTER_STOPPED :
-          printf("%s is not ready\n", dest);
+          _cupsLangPrintf(stdout, _("%s is not ready\n"), dest);
 	  break;
     }
 
     ippDelete(response);
   }
   else
-    fprintf(stderr, "lpq: get-printer-attributes failed: %s\n",
-            ippErrorString(cupsLastError()));
+    _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
 }
 
 
@@ -605,11 +668,13 @@ show_printer(http_t     *http,	/* I - HTTP connection to server */
 static void
 usage(void)
 {
-  fputs("Usage: lpq [-P dest] [-l] [+interval]\n", stderr);
+  _cupsLangPuts(stderr,
+                _("Usage: lpq [-P dest] [-U username] [-h hostname[:port]] "
+		  "[-l] [+interval]\n"));
   exit(1);
 }
 
 
 /*
- * End of "$Id: lpq.c,v 1.31 2004/09/08 19:01:34 mike Exp $".
+ * End of "$Id: lpq.c 5926 2006-09-05 20:45:47Z mike $".
  */
