@@ -1,9 +1,9 @@
 /*
- * "$Id: lprm.c,v 1.25 2005/01/03 19:29:44 mike Exp $"
+ * "$Id: lprm.c 5926 2006-09-05 20:45:47Z mike $"
  *
  *   "lprm" command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -34,7 +34,7 @@
 #include <stdlib.h>
 
 #include <cups/cups.h>
-#include <cups/language.h>
+#include <cups/i18n.h>
 #include <cups/string.h>
 
 
@@ -55,12 +55,14 @@ main(int  argc,			/* I - Number of command-line arguments */
   ipp_t		*request;	/* IPP request */
   ipp_t		*response;	/* IPP response */
   ipp_op_t	op;		/* Operation */
-  cups_lang_t	*language;	/* Language */
   int		num_dests;	/* Number of destinations */
-  cups_dest_t	*dests;		/* Destinations */
+  cups_dest_t	*dests,		/* Destinations */
+		*defdest;	/* Default destination */
   http_encryption_t encryption;	/* Encryption? */
 
 
+  _cupsSetLocale(argv);
+
  /*
   * Setup to cancel individual print jobs...
   */
@@ -72,23 +74,20 @@ main(int  argc,			/* I - Number of command-line arguments */
   http       = NULL;
   encryption = cupsEncryption();
 
-  num_dests = cupsGetDests(&dests);
-
-  for (i = 0; i < num_dests; i ++)
-    if (dests[i].is_default)
-      dest = dests[i].name;
-
  /*
   * Open a connection to the server...
   */
 
   if ((http = httpConnectEncrypt(cupsServer(), ippPort(), encryption)) == NULL)
   {
-    fputs("lprm: Unable to contact server!\n", stderr);
-    cupsFreeDests(num_dests, dests);
+    _cupsLangPuts(stderr, _("lprm: Unable to contact server!\n"));
     return (1);
   }
 
+  num_dests  = cupsGetDests2(http, &dests);
+  defdest    = cupsGetDest(NULL, NULL, num_dests, dests);
+  dest       = defdest ? defdest->name : NULL;
+
  /*
   * Process command-line arguments...
   */
@@ -102,9 +101,11 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    encryption = HTTP_ENCRYPT_REQUIRED;
 
 	    httpEncryption(http, encryption);
+	    cupsSetEncryption(encryption);
 #else
-            fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
-	            argv[0]);
+            _cupsLangPrintf(stderr,
+	                    _("%s: Sorry, no encryption support compiled in!\n"),
+	                    argv[0]);
 #endif /* HAVE_SSL */
 	    break;
 
@@ -122,15 +123,72 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 	    if (cupsGetDest(dest, NULL, num_dests, dests) == NULL)
 	    {
-	      fprintf(stderr, "lprm: Unknown destination \"%s\"!\n", dest);
+	      _cupsLangPrintf(stderr,
+	                      _("%s: Error - unknown destination \"%s\"!\n"),
+			      argv[0], dest);
               cupsFreeDests(num_dests, dests);
 	      httpClose(http);
 	      return(1);
 	    }
 	    break;
 
+        case 'U' : /* Username */
+	    if (argv[i][2] != '\0')
+	      cupsSetUser(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected username after "
+				  "\'-U\' option!\n"),
+		        	argv[0]);
+	        return (1);
+	      }
+
+              cupsSetUser(argv[i]);
+	    }
+	    break;
+	    
+        case 'h' : /* Connect to host */
+	    if (argv[i][2] != '\0')
+              cupsSetServer(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		        	_("%s: Error - expected hostname after "
+			          "\'-h\' option!\n"),
+				argv[0]);
+		return (1);
+              }
+	      else
+                cupsSetServer(argv[i]);
+	    }
+
+            httpClose(http);
+            cupsFreeDests(num_dests, dests);
+
+	    if ((http = httpConnectEncrypt(cupsServer(), ippPort(),
+	                                   encryption)) == NULL)
+	    {
+	      _cupsLangPuts(stderr, _("lprm: Unable to contact server!\n"));
+	      return (1);
+	    }
+
+	    num_dests  = cupsGetDests2(http, &dests);
+	    defdest    = cupsGetDest(NULL, NULL, num_dests, dests);
+	    dest       = defdest ? defdest->name : NULL;
+	    break;
+
 	default :
-	    fprintf(stderr, "lprm: Unknown option \'%c\'!\n", argv[i][1]);
+	    _cupsLangPrintf(stderr,
+	                    _("%s: Error - unknown option \'%c\'!\n"),
+			    argv[0], argv[i][1]);
             cupsFreeDests(num_dests, dests);
 	    httpClose(http);
 	    return (1);
@@ -148,7 +206,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 	op     = IPP_CANCEL_JOB;
         job_id = atoi(argv[i]);
       }
-      else if (strcmp(argv[i], "-") == 0)
+      else if (!strcmp(argv[i], "-"))
       {
        /*
         * Cancel all jobs
@@ -172,22 +230,12 @@ main(int  argc,			/* I - Number of command-line arguments */
       *    [requesting-user-name]
       */
 
-      request = ippNew();
-
-      request->request.op.operation_id = op;
-      request->request.op.request_id   = 1;
-
-      language = cupsLangDefault();
-
-      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-              	   "attributes-charset", NULL, cupsLangEncoding(language));
-
-      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-                   "attributes-natural-language", NULL, language->language);
+      request = ippNewRequest(op);
 
       if (dest)
       {
-        snprintf(uri, sizeof(uri), "ipp://localhost/printers/%s", dest);
+        httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
+	                 "localhost", 0, "/printers/%s", dest);
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
 	             "printer-uri", NULL, uri);
 	ippAddInteger(request, IPP_TAG_OPERATION, IPP_TAG_INTEGER, "job-id",
@@ -212,38 +260,12 @@ main(int  argc,			/* I - Number of command-line arguments */
       else
         response = cupsDoRequest(http, request, "/jobs/");
 
-      if (response != NULL)
-      {
-        switch (response->request.status.status_code)
-	{
-	  case IPP_NOT_FOUND :
-              fputs("lprm: Job or printer not found!\n", stderr);
-	      break;
-	  case IPP_NOT_AUTHORIZED :
-              fputs("lprm: Not authorized to lprm job(s)!\n", stderr);
-	      break;
-	  case IPP_FORBIDDEN :
-              fprintf(stderr, "lprm: You don't own job ID %d!\n", job_id);
-	      break;
-	  default :
-              if (response->request.status.status_code > IPP_OK_CONFLICT)
-                fputs("lprm: Unable to lprm job(s)!\n", stderr);
-	      break;
-	}
+      ippDelete(response);
 
-        if (response->request.status.status_code > IPP_OK_CONFLICT)
-	{
-          ippDelete(response);
-          cupsFreeDests(num_dests, dests);
-          httpClose(http);
-	  return (1);
-	}
-
-        ippDelete(response);
-      }
-      else
+      if (cupsLastError() > IPP_OK_CONFLICT)
       {
-        fputs("lprm: Unable to cancel job(s)!\n", stderr);
+        _cupsLangPrintf(stderr, "%s: %s\n", argv[0], cupsLastErrorString());
+
         cupsFreeDests(num_dests, dests);
         httpClose(http);
 	return (1);
@@ -251,14 +273,14 @@ main(int  argc,			/* I - Number of command-line arguments */
     }
 
  /*
-  * If nothing has been cancelled yet, cancel the current job on the specified
+  * If nothing has been canceled yet, cancel the current job on the specified
   * (or default) printer...
   */
 
   if (response == NULL)
     if (!cupsCancelJob(dest, 0))
     {
-      fputs("lprm: Unable to cancel job(s)!\n", stderr);
+      _cupsLangPrintf(stderr, "%s: %s\n", argv[0], cupsLastErrorString());
       cupsFreeDests(num_dests, dests);
       httpClose(http);
       return (1);
@@ -272,5 +294,5 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 
 /*
- * End of "$Id: lprm.c,v 1.25 2005/01/03 19:29:44 mike Exp $".
+ * End of "$Id: lprm.c 5926 2006-09-05 20:45:47Z mike $".
  */
