@@ -1,43 +1,50 @@
 /*
- * "$Id: template.c,v 1.32 2005/01/03 19:29:45 mike Exp $"
+ * "$Id: template.c 5549 2006-05-19 19:39:28Z mike $"
  *
  *   CGI template function.
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
- *   This program is free software; you can redistribute it and/or modify it
- *   under the terms of the GNU General Public License as published by the Free
- *   Software Foundation; either version 2 of the License, or (at your option)
- *   any later version.
+ *   These coded instructions, statements, and computer programs are the
+ *   property of Easy Software Products and are protected by Federal
+ *   copyright law.  Distribution and use rights are outlined in the file
+ *   "LICENSE.txt" which should have been included with this file.  If this
+ *   file is missing or damaged please contact Easy Software Products
+ *   at:
  *
- *   This program is distributed in the hope that it will be useful, but
- *   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *   for more details.
+ *       Attn: CUPS Licensing Information
+ *       Easy Software Products
+ *       44141 Airport View Drive, Suite 204
+ *       Hollywood, Maryland 20636 USA
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *       Voice: (301) 373-9600
+ *       EMail: cups-info@cups.org
+ *         WWW: http://www.cups.org
  *
  * Contents:
  *
  *   cgiCopyTemplateFile() - Copy a template file and replace all the
  *                           '{variable}' strings with the variable value.
  *   cgiCopyTemplateLang() - Copy a template file using a language...
+ *   cgiGetTemplateDir()   - Get the templates directory...
+ *   cgiSetServerVersion() - Set the server name and CUPS version...
  *   cgi_copy()            - Copy the template file, substituting as needed...
  *   cgi_puts()            - Put a string to the output file, quoting as
  *                           needed...
  */
 
-#include "cgi.h"
+#include "cgi-private.h"
+#include <errno.h>
 
 
 /*
  * Local functions...
  */
 
-static void	cgi_copy(FILE *out, FILE *in, int element, char term);
+static void	cgi_copy(FILE *out, FILE *in, int element, char term,
+		         int indent);
 static void	cgi_puts(const char *s, FILE *out);
+static void	cgi_puturi(const char *s, FILE *out);
 
 
 /*
@@ -52,18 +59,25 @@ cgiCopyTemplateFile(FILE       *out,	/* I - Output file */
   FILE	*in;				/* Input file */
 
 
+  fprintf(stderr, "DEBUG: cgiCopyTemplateFile(out=%p, tmpl=\"%s\")\n", out,
+          tmpl ? tmpl : "(null)");
+
  /*
   * Open the template file...
   */
 
   if ((in = fopen(tmpl, "r")) == NULL)
+  {
+    fprintf(stderr, "ERROR: Unable to open template file \"%s\" - %s\n",
+            tmpl ? tmpl : "(null)", strerror(errno));
     return;
+  }
 
  /*
   * Parse the file to the end...
   */
 
-  cgi_copy(out, in, 0, 0);
+  cgi_copy(out, in, 0, 0, 0);
 
  /*
   * Close the template file and return...
@@ -78,38 +92,46 @@ cgiCopyTemplateFile(FILE       *out,	/* I - Output file */
  */
 
 void
-cgiCopyTemplateLang(FILE       *out,		/* I - Output file */
-                    const char *directory,	/* I - Directory */
-                    const char *tmpl,		/* I - Base filename */
-		    const char *lang)		/* I - Language */
+cgiCopyTemplateLang(const char *tmpl)	/* I - Base filename */
 {
-  int	i;					/* Looping var */
-  char	filename[1024],				/* Filename */
-	locale[16];				/* Locale name */
-  FILE	*in;					/* Input file */
+  int		i;			/* Looping var */
+  char		filename[1024],		/* Filename */
+		locale[16];		/* Locale name */
+  const char	*directory,		/* Directory for templates */
+		*lang;			/* Language */
+  FILE		*in;			/* Input file */
 
 
+  fprintf(stderr, "DEBUG: cgiCopyTemplateLang(tmpl=\"%s\")\n",
+          tmpl ? tmpl : "(null)");
+
  /*
   * Convert the language to a locale name...
   */
 
-  if (lang != NULL)
+  if ((lang = getenv("LANG")) != NULL)
   {
     for (i = 0; lang[i] && i < 15; i ++)
-      if (isalnum(lang[i] & 255))
+      if (isalnum(lang[i] & 255) || lang[i] == '_')
         locale[i] = tolower(lang[i]);
-      else
+      else if (lang[i] == '-')
         locale[i] = '_';
+      else
+        break;
 
     locale[i] = '\0';
   }
   else
     locale[0] = '\0';
 
+  fprintf(stderr, "DEBUG: locale=\"%s\"...\n", locale);
+
  /*
   * See if we have a template file for this language...
   */
 
+  directory = cgiGetTemplateDir();
+
   snprintf(filename, sizeof(filename), "%s/%s/%s", directory, locale, tmpl);
   if (access(filename, 0))
   {
@@ -120,18 +142,24 @@ cgiCopyTemplateLang(FILE       *out,		/* I - Output file */
       snprintf(filename, sizeof(filename), "%s/%s", directory, tmpl);
   }
 
+  fprintf(stderr, "DEBUG: Template file is \"%s\"...\n", filename);
+
  /*
   * Open the template file...
   */
 
   if ((in = fopen(filename, "r")) == NULL)
+  {
+    fprintf(stderr, "ERROR: Unable to open template file \"%s\" - %s\n",
+            filename, strerror(errno));
     return;
+  }
 
  /*
   * Parse the file to the end...
   */
 
-  cgi_copy(out, in, 0, 0);
+  cgi_copy(stdout, in, 0, 0, 0);
 
  /*
   * Close the template file and return...
@@ -141,31 +169,80 @@ cgiCopyTemplateLang(FILE       *out,		/* I - Output file */
 }
 
 
+/*
+ * 'cgiGetTemplateDir()' - Get the templates directory...
+ */
+
+char *					/* O - Template directory */
+cgiGetTemplateDir(void)
+{
+  const char	*datadir;		/* CUPS_DATADIR env var */
+  static char	templates[1024] = "";	/* Template directory */
+
+
+  if (!templates[0])
+  {
+   /*
+    * Build the template directory pathname...
+    */
+
+    if ((datadir = getenv("CUPS_DATADIR")) == NULL)
+      datadir = CUPS_DATADIR;
+
+    snprintf(templates, sizeof(templates), "%s/templates", datadir);
+  }
+
+  return (templates);
+}
+
+
+/*
+ * 'cgiSetServerVersion()' - Set the server name and CUPS version...
+ */
+
+void
+cgiSetServerVersion(void)
+{
+  cgiSetVariable("SERVER_NAME", getenv("SERVER_NAME"));
+  cgiSetVariable("REMOTE_USER", getenv("REMOTE_USER"));
+  cgiSetVariable("CUPS_VERSION", CUPS_SVERSION);
+
+#ifdef LC_TIME
+  setlocale(LC_TIME, "");
+#endif /* LC_TIME */
+}
+
+
 /*
  * 'cgi_copy()' - Copy the template file, substituting as needed...
  */
 
 static void
-cgi_copy(FILE *out,		/* I - Output file */
-         FILE *in,		/* I - Input file */
-	 int  element,		/* I - Element number (0 to N) */
-	 char term)		/* I - Terminating character */
+cgi_copy(FILE *out,			/* I - Output file */
+         FILE *in,			/* I - Input file */
+	 int  element,			/* I - Element number (0 to N) */
+	 char term,			/* I - Terminating character */
+	 int  indent)			/* I - Debug info indentation */
 {
-  int		ch;		/* Character from file */
-  char		op;		/* Operation */
-  char		name[255],	/* Name of variable */
-		*nameptr,	/* Pointer into name */
-		innername[255],	/* Inner comparison name */
-		*innerptr,	/* Pointer into inner name */
-		*s;		/* String pointer */
-  const char	*value;		/* Value of variable */
-  const char	*innerval;	/* Inner value */
-  const char	*outptr;	/* Output string pointer */
-  char		outval[1024],	/* Formatted output string */
-		compare[1024];	/* Comparison string */
-  int		result;		/* Result of comparison */
+  int		ch;			/* Character from file */
+  char		op;			/* Operation */
+  char		name[255],		/* Name of variable */
+		*nameptr,		/* Pointer into name */
+		innername[255],		/* Inner comparison name */
+		*innerptr,		/* Pointer into inner name */
+		*s;			/* String pointer */
+  const char	*value;			/* Value of variable */
+  const char	*innerval;		/* Inner value */
+  const char	*outptr;		/* Output string pointer */
+  char		outval[1024],		/* Formatted output string */
+		compare[1024];		/* Comparison string */
+  int		result;			/* Result of comparison */
+  int		uriencode;		/* Encode as URI */
 
 
+  fprintf(stderr, "DEBUG: %*sStarting at file position %ld...\n", indent, "",
+          ftell(in));
+
  /*
   * Parse the file to the end...
   */
@@ -179,9 +256,13 @@ cgi_copy(FILE *out,		/* I - Output file */
       * Get a variable name...
       */
 
+      uriencode = 0;
+
       for (s = name; (ch = getc(in)) != EOF;)
         if (strchr("}]<>=! \t\n", ch))
           break;
+	else if (s == name && ch == '%')
+	  uriencode = 1;
         else if (s > name && ch == '?')
 	  break;
 	else if (s < (name + sizeof(name) - 1))
@@ -191,6 +272,8 @@ cgi_copy(FILE *out,		/* I - Output file */
 
       if (s == name && isspace(ch & 255))
       {
+        fprintf(stderr, "DEBUG: %*sLone { at %ld...\n", indent, "", ftell(in));
+
         if (out)
 	{
           putc('{', out);
@@ -200,6 +283,10 @@ cgi_copy(FILE *out,		/* I - Output file */
 	continue;
       }
 
+      if (ch == '}')
+	fprintf(stderr, "DEBUG: %*s\"{%s}\" at %ld...\n", indent, "", name,
+        	ftell(in));
+
      /*
       * See if it has a value...
       */
@@ -261,16 +348,24 @@ cgi_copy(FILE *out,		/* I - Output file */
 
 	pos = ftell(in);
 
+        fprintf(stderr, "DEBUG: %*sLooping on \"%s\" at %ld, count=%d...\n",
+	        indent, "", name + 1, pos, count);
+
         if (count > 0)
 	{
           for (i = 0; i < count; i ++)
 	  {
-	    fseek(in, pos, SEEK_SET);
-	    cgi_copy(out, in, i, '}');
+	    if (i)
+	      fseek(in, pos, SEEK_SET);
+
+	    cgi_copy(out, in, i, '}', indent + 2);
 	  }
         }
 	else
-	  cgi_copy(NULL, in, 0, '}');
+	  cgi_copy(NULL, in, 0, '}', indent + 2);
+
+        fprintf(stderr, "DEBUG: %*sFinished looping on \"%s\"...\n", indent,
+	        "", name + 1);
 
         continue;
       }
@@ -311,7 +406,12 @@ cgi_copy(FILE *out,		/* I - Output file */
         */
 
 	if (out)
-	  cgi_puts(outptr, out);
+	{
+	  if (uriencode)
+	    cgi_puturi(outptr, out);
+	  else
+	    cgi_puts(outptr, out);
+        }
 
         continue;
       }
@@ -326,13 +426,16 @@ cgi_copy(FILE *out,		/* I - Output file */
       *   {name!value?true:false}    Not equal
       */
 
+      op = ch;
+
       if (ch == '?')
       {
        /*
         * Test for existance...
 	*/
 
-        result = cgiGetArray(name, element) != NULL && outptr[0];
+        result     = cgiGetArray(name, element) != NULL && outptr[0];
+	compare[0] = '\0';
       }
       else
       {
@@ -340,8 +443,6 @@ cgi_copy(FILE *out,		/* I - Output file */
         * Compare to a string...
 	*/
 
-        op = ch;
-
 	for (s = compare; (ch = getc(in)) != EOF;)
           if (ch == '?')
             break;
@@ -397,7 +498,12 @@ cgi_copy(FILE *out,		/* I - Output file */
         *s = '\0';
 
         if (ch != '?')
+	{
+	  fprintf(stderr,
+	          "DEBUG: %*sBad terminator '%c' at file position %ld...\n",
+	          indent, "", ch, ftell(in));
 	  return;
+	}
 
        /*
         * Do the comparison...
@@ -423,14 +529,21 @@ cgi_copy(FILE *out,		/* I - Output file */
 	}
       }
 
+      fprintf(stderr,
+              "DEBUG: %*sStarting \"{%s%c%s\" at %ld, result=%d...\n",
+	      indent, "", name, op, compare, ftell(in), result);
+
       if (result)
       {
        /*
 	* Comparison true; output first part and ignore second...
 	*/
 
-	cgi_copy(out, in, element, ':');
-	cgi_copy(NULL, in, element, '}');
+        fprintf(stderr, "DEBUG: %*sOutput first part...\n", indent, "");
+	cgi_copy(out, in, element, ':', indent + 2);
+
+        fprintf(stderr, "DEBUG: %*sSkip second part...\n", indent, "");
+	cgi_copy(NULL, in, element, '}', indent + 2);
       }
       else
       {
@@ -438,9 +551,15 @@ cgi_copy(FILE *out,		/* I - Output file */
 	* Comparison false; ignore first part and output second...
 	*/
 
-	cgi_copy(NULL, in, element, ':');
-	cgi_copy(out, in, element, '}');
+        fprintf(stderr, "DEBUG: %*sSkip first part...\n", indent, "");
+	cgi_copy(NULL, in, element, ':', indent + 2);
+
+        fprintf(stderr, "DEBUG: %*sOutput second part...\n", indent, "");
+	cgi_copy(out, in, element, '}', indent + 2);
       }
+
+      fprintf(stderr, "DEBUG: %*sFinished \"{%s%c%s\", out=%p...\n", indent, "",
+              name, op, compare, out);
     }
     else if (ch == '\\')	/* Quoted char */
     {
@@ -452,6 +571,17 @@ cgi_copy(FILE *out,		/* I - Output file */
     else if (out)
       putc(ch, out);
 
+  if (ch == EOF)
+    fprintf(stderr, "DEBUG: %*sReturning at file position %ld on EOF...\n",
+	    indent, "", ftell(in));
+  else
+    fprintf(stderr,
+            "DEBUG: %*sReturning at file position %ld on character '%c'...\n",
+	    indent, "", ftell(in), ch);
+
+  if (ch == EOF && term)
+    fprintf(stderr, "ERROR: %*sSaw EOF, expected '%c'!\n", indent, "", term);
+
  /*
   * Flush any pending output...
   */
@@ -466,18 +596,50 @@ cgi_copy(FILE *out,		/* I - Output file */
  */
 
 static void
-cgi_puts(const char *s,
-         FILE       *out)
+cgi_puts(const char *s,			/* I - String to output */
+         FILE       *out)		/* I - Output file */
 {
   while (*s)
   {
-    if (s[0] == '<')
-      fputs("&lt;", out);
-    else if (s[0] == '>')
+    if (*s == '<')
+    {
+     /*
+      * Pass <A HREF="url"> and </A>, otherwise quote it...
+      */
+
+      if (!strncasecmp(s, "<A HREF=\"", 9))
+      {
+        fputs("<A HREF=\"", out);
+	s += 9;
+
+	while (*s && *s != '\"')
+	{
+          if (*s == '&')
+            fputs("&amp;", out);
+	  else
+	    putc(*s, out);
+
+	  s ++;
+	}
+
+        if (*s)
+	  s ++;
+
+	fputs("\">", out);
+      }
+      else if (!strncasecmp(s, "</A>", 4))
+      {
+        fputs("</A>", out);
+	s += 3;
+      }
+      else
+        fputs("&lt;", out);
+    }
+    else if (*s == '>')
       fputs("&gt;", out);
     else if (*s == '\"')
       fputs("&quot;", out);
-    else if (s[0] == '&')
+    else if (*s == '&')
       fputs("&amp;", out);
     else
       putc(*s, out);
@@ -488,5 +650,25 @@ cgi_puts(const char *s,
 
 
 /*
- * End of "$Id: template.c,v 1.32 2005/01/03 19:29:45 mike Exp $".
+ * 'cgi_puturi()' - Put a URI string to the output file, quoting as needed...
+ */
+
+static void
+cgi_puturi(const char *s,		/* I - String to output */
+           FILE       *out)		/* I - Output file */
+{
+  while (*s)
+  {
+    if (strchr("%&+ <>#=", *s) || *s & 128)
+      fprintf(out, "%%%02X", *s & 255);
+    else
+      putc(*s, out);
+
+    s ++;
+  }
+}
+
+
+/*
+ * End of "$Id: template.c 5549 2006-05-19 19:39:28Z mike $".
  */
