@@ -1,5 +1,5 @@
 /*
- * "$Id: file.c 5812 2006-08-09 22:42:51Z mike $"
+ * "$Id: file.c 6313 2007-02-27 15:46:10Z mike $"
  *
  *   File functions for the Common UNIX Printing System (CUPS).
  *
@@ -8,7 +8,7 @@
  *   our own file functions allows us to provide transparent support of
  *   gzip'd print files, PPD files, etc.
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -94,6 +94,16 @@
 #endif /* !O_LARGEFILE */
 
 
+/*
+ * Some operating systems don't define O_BINARY, which is used by Microsoft
+ * and IBM to flag binary files...
+ */
+
+#ifndef O_BINARY
+#  define O_BINARY 0
+#endif /* !O_BINARY */
+
+
 /*
  * Types and structures...
  */
@@ -332,7 +342,11 @@ cupsFileFind(const char *filename,	/* I - File to find */
 
   while (*path)
   {
+#ifdef WIN32
+    if (*path == ';' || (*path == ':' && ((bufptr - buffer) > 1 || !isalpha(buffer[0] & 255))))
+#else
     if (*path == ';' || *path == ':')
+#endif /* WIN32 */
     {
       if (bufptr > buffer && bufptr[-1] != '/' && bufptr < bufend)
         *bufptr++ = '/';
@@ -344,7 +358,10 @@ cupsFileFind(const char *filename,	/* I - File to find */
 #else
       if (!access(buffer, executable ? X_OK : 0))
 #endif /* WIN32 */
+      {
+        DEBUG_printf(("cupsFileFind: Returning \"%s\"\n", buffer));
         return (buffer);
+      }
 
       bufptr = buffer;
     }
@@ -364,9 +381,15 @@ cupsFileFind(const char *filename,	/* I - File to find */
   strlcpy(bufptr, filename, bufend - bufptr);
 
   if (!access(buffer, 0))
+  {
+    DEBUG_printf(("cupsFileFind: Returning \"%s\"\n", buffer));
     return (buffer);
+  }
   else
+  {
+    DEBUG_puts("cupsFileFind: Returning NULL");
     return (NULL);
+  }
 }
 
 
@@ -377,7 +400,7 @@ cupsFileFind(const char *filename,	/* I - File to find */
 int					/* O - 0 on success, -1 on error */
 cupsFileFlush(cups_file_t *fp)		/* I - CUPS file */
 {
-  size_t	bytes;			/* Bytes to write */
+  ssize_t	bytes;			/* Bytes to write */
 
 
   DEBUG_printf(("cupsFileFlush(fp=%p)\n", fp));
@@ -392,7 +415,7 @@ cupsFileFlush(cups_file_t *fp)		/* I - CUPS file */
     return (-1);
   }
 
-  bytes = fp->ptr - fp->buf;
+  bytes = (ssize_t)(fp->ptr - fp->buf);
 
   DEBUG_printf(("    Flushing %ld bytes...\n", (long)bytes));
 
@@ -427,7 +450,10 @@ cupsFileGetChar(cups_file_t *fp)	/* I - CUPS file */
   */
 
   if (!fp || (fp->mode != 'r' && fp->mode != 's'))
+  {
+    DEBUG_puts("cupsFileGetChar: Bad arguments!");
     return (-1);
+  }
 
  /*
   * If the input buffer is empty, try to read more data...
@@ -435,12 +461,17 @@ cupsFileGetChar(cups_file_t *fp)	/* I - CUPS file */
 
   if (fp->ptr >= fp->end)
     if (cups_fill(fp) < 0)
+    {
+      DEBUG_puts("cupsFileGetChar: Unable to fill buffer!");
       return (-1);
+    }
 
  /*
   * Return the next character in the buffer...
   */
 
+  DEBUG_printf(("cupsFileGetChar: Returning %d...\n", *(fp->ptr) & 255));
+
   return (*(fp->ptr)++ & 255);
 }
 
@@ -477,7 +508,7 @@ cupsFileGetConf(cups_file_t *fp,	/* I  - CUPS file */
   */
 
   *value = NULL;
-  
+
   while (cupsFileGets(fp, buf, buflen))
   {
     (*linenum) ++;
@@ -488,15 +519,24 @@ cupsFileGetConf(cups_file_t *fp,	/* I  - CUPS file */
 
     if ((ptr = strchr(buf, '#')) != NULL)
     {
-      while (ptr > buf)
+      if (ptr > buf && ptr[-1] == '\\')
       {
-	if (!isspace(ptr[-1] & 255))
-	  break;
-
-        ptr --;
+        // Unquote the #...
+	_cups_strcpy(ptr - 1, ptr);
       }
+      else
+      {
+        // Strip the comment and any trailing whitespace...
+	while (ptr > buf)
+	{
+	  if (!isspace(ptr[-1] & 255))
+	    break;
 
-      *ptr = '\0';
+	  ptr --;
+	}
+
+	*ptr = '\0';
+      }
     }
 
    /*
@@ -780,15 +820,15 @@ cupsFileOpen(const char *filename,	/* I - Name of file */
   switch (*mode)
   {
     case 'a' : /* Append file */
-        fd = open(filename, O_RDWR | O_CREAT | O_APPEND | O_LARGEFILE, 0666);
+        fd = open(filename, O_RDWR | O_CREAT | O_APPEND | O_LARGEFILE | O_BINARY, 0666);
         break;
 
     case 'r' : /* Read file */
-	fd = open(filename, O_RDONLY | O_LARGEFILE, 0);
+	fd = open(filename, O_RDONLY | O_LARGEFILE | O_BINARY, 0);
 	break;
 
     case 'w' : /* Write file */
-        fd = open(filename, O_WRONLY | O_TRUNC | O_CREAT | O_LARGEFILE, 0666);
+        fd = open(filename, O_WRONLY | O_TRUNC | O_CREAT | O_LARGEFILE | O_BINARY, 0666);
         break;
 
     case 's' : /* Read/write socket */
@@ -991,7 +1031,7 @@ cupsFilePrintf(cups_file_t *fp,		/* I - CUPS file */
 	       ...)			/* I - Additional args as necessary */
 {
   va_list	ap;			/* Argument list */
-  size_t	bytes;			/* Formatted size */
+  ssize_t	bytes;			/* Formatted size */
   char		buf[8192];		/* Formatted text */
 
 
@@ -1090,7 +1130,7 @@ int					/* O - Number of bytes written or -1 */
 cupsFilePuts(cups_file_t *fp,		/* I - CUPS file */
              const char  *s)		/* I - String to write */
 {
-  size_t	bytes;			/* Bytes to write */
+  ssize_t	bytes;			/* Bytes to write */
 
 
  /*
@@ -1104,7 +1144,7 @@ cupsFilePuts(cups_file_t *fp,		/* I - CUPS file */
   * Write the string...
   */
 
-  bytes = strlen(s);
+  bytes = (int)strlen(s);
 
   if (fp->mode == 's')
   {
@@ -1149,8 +1189,8 @@ cupsFileRead(cups_file_t *fp,		/* I - CUPS file */
              char        *buf,		/* O - Buffer */
 	     size_t      bytes)		/* I - Number of bytes to read */
 {
-  size_t	total,			/* Total bytes read */
-		count;			/* Bytes read */
+  size_t	total;			/* Total bytes read */
+  ssize_t	count;			/* Bytes read */
 
 
   DEBUG_printf(("cupsFileRead(fp=%p, buf=%p, bytes=%ld)\n", fp, buf,
@@ -1179,14 +1219,14 @@ cupsFileRead(cups_file_t *fp,		/* I - CUPS file */
         DEBUG_printf(("    cups_fill() returned -1, total=%d\n", total));
 
         if (total > 0)
-          return (total);
+          return ((ssize_t)total);
 	else
 	  return (-1);
       }
 
-    count = fp->end - fp->ptr;
-    if (count > bytes)
-      count = bytes;
+    count = (ssize_t)(fp->end - fp->ptr);
+    if (count > (ssize_t)bytes)
+      count = (ssize_t)bytes;
 
     memcpy(buf, fp->ptr, count);
     fp->ptr += count;
@@ -1206,7 +1246,7 @@ cupsFileRead(cups_file_t *fp,		/* I - CUPS file */
 
   DEBUG_printf(("    total=%d\n", total));
 
-  return (total);
+  return ((ssize_t)total);
 }
 
 
@@ -1274,7 +1314,7 @@ off_t					/* O - New file position or -1 */
 cupsFileSeek(cups_file_t *fp,		/* I - CUPS file */
              off_t       pos)		/* I - Position in file */
 {
-  size_t	bytes;			/* Number bytes in buffer */
+  ssize_t	bytes;			/* Number bytes in buffer */
 
 
   DEBUG_printf(("cupsFileSeek(fp=%p, pos=" CUPS_LLFMT ")\n", fp, pos));
@@ -1328,7 +1368,7 @@ cupsFileSeek(cups_file_t *fp,		/* I - CUPS file */
   */
 
   if (fp->ptr)
-    bytes = fp->end - fp->buf;
+    bytes = (ssize_t)(fp->end - fp->buf);
   else
     bytes = 0;
 
@@ -1582,16 +1622,16 @@ cupsFileWrite(cups_file_t *fp,		/* I - CUPS file */
     if (cups_write(fp, buf, bytes) < 0)
       return (-1);
 
-    fp->pos += bytes;
+    fp->pos += (off_t)bytes;
 
-    return (bytes);
+    return ((ssize_t)bytes);
   }
 
   if ((fp->ptr + bytes) > fp->end)
     if (cupsFileFlush(fp))
       return (-1);
 
-  fp->pos += bytes;
+  fp->pos += (off_t)bytes;
 
   if (bytes > sizeof(fp->buf))
   {
@@ -1606,7 +1646,7 @@ cupsFileWrite(cups_file_t *fp,		/* I - CUPS file */
   {
     memcpy(fp->ptr, buf, bytes);
     fp->ptr += bytes;
-    return (bytes);
+    return ((ssize_t)bytes);
   }
 }
 
@@ -1687,7 +1727,7 @@ cups_fill(cups_file_t *fp)		/* I - CUPS file */
   */
 
   if (fp->ptr && fp->end)
-    fp->pos += fp->end - fp->buf;
+    fp->pos += (off_t)(fp->end - fp->buf);
 
 #ifdef HAVE_LIBZ
   DEBUG_printf(("    fp->compressed=%d\n", fp->compressed));
@@ -1995,10 +2035,17 @@ cups_read(cups_file_t *fp,		/* I - CUPS file */
 
   for (;;)
   {
+#ifdef WIN32
+    if (fp->mode == 's')
+      total = (ssize_t)recv(fp->fd, buf, (unsigned)bytes, 0);
+    else
+      total = (ssize_t)read(fp->fd, buf, (unsigned)bytes);
+#else
     if (fp->mode == 's')
       total = recv(fp->fd, buf, bytes, 0);
     else
       total = read(fp->fd, buf, bytes);
+#endif /* WIN32 */
 
     if (total >= 0)
       break;
@@ -2030,8 +2077,8 @@ cups_write(cups_file_t *fp,		/* I - CUPS file */
            const char  *buf,		/* I - Buffer */
 	   size_t      bytes)		/* I - Number bytes */
 {
-  size_t	total,			/* Total bytes written */
-		count;			/* Count this time */
+  size_t	total;			/* Total bytes written */
+  ssize_t	count;			/* Count this time */
 
 
   DEBUG_printf(("cups_write(fp=%p, buf=%p, bytes=%ld)\n", fp, buf,
@@ -2044,10 +2091,17 @@ cups_write(cups_file_t *fp,		/* I - CUPS file */
   total = 0;
   while (bytes > 0)
   {
+#ifdef WIN32
+    if (fp->mode == 's')
+      count = (ssize_t)send(fp->fd, buf, (unsigned)bytes, 0);
+    else
+      count = (ssize_t)write(fp->fd, buf, (unsigned)bytes);
+#else
     if (fp->mode == 's')
       count = send(fp->fd, buf, bytes, 0);
     else
       count = write(fp->fd, buf, bytes);
+#endif /* WIN32 */
 
     if (count < 0)
     {
@@ -2076,10 +2130,10 @@ cups_write(cups_file_t *fp,		/* I - CUPS file */
   * Return the total number of bytes written...
   */
 
-  return (total);
+  return ((ssize_t)total);
 }
 
 
 /*
- * End of "$Id: file.c 5812 2006-08-09 22:42:51Z mike $".
+ * End of "$Id: file.c 6313 2007-02-27 15:46:10Z mike $".
  */
