@@ -1,9 +1,9 @@
 /*
- * "$Id: options.c 5151 2006-02-22 22:43:17Z mike $"
+ * "$Id: options.c 6313 2007-02-27 15:46:10Z mike $"
  *
  *   Option routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products.
+ *   Copyright 1997-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -578,7 +578,7 @@ cupsParseOptions(
 
 
 /*
- * 'cupsRemoveOptions()' - Remove an option from an option array.
+ * 'cupsRemoveOption()' - Remove an option from an option array.
  *
  * @since CUPS 1.2@
  */
@@ -622,7 +622,7 @@ cupsRemoveOption(
       free(option->value);
 
     if (i > 0)
-      memmove(option, option + 1, i * sizeof(cups_option_t *));
+      memmove(option, option + 1, i * sizeof(cups_option_t));
   }
 
  /*
@@ -634,5 +634,5 @@ cupsRemoveOption(
 
 
 /*
- * End of "$Id: options.c 5151 2006-02-22 22:43:17Z mike $".
+ * End of "$Id: options.c 6313 2007-02-27 15:46:10Z mike $".
  */
