@@ -1,9 +1,9 @@
 /*
- * "$Id: ppd.c 5826 2006-08-15 19:04:11Z mike $"
+ * "$Id: ppd.c 6446 2007-04-04 23:43:50Z mike $"
  *
  *   PPD file routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -819,17 +819,17 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
       strlcpy(profile->resolution, name, sizeof(profile->resolution));
       strlcpy(profile->media_type, text, sizeof(profile->media_type));
 
-      profile->density      = _cupsStrScand(string, &sptr, loc);
-      profile->gamma        = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[0][0] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[0][1] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[0][2] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[1][0] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[1][1] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[1][2] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[2][0] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[2][1] = _cupsStrScand(sptr, &sptr, loc);
-      profile->matrix[2][2] = _cupsStrScand(sptr, &sptr, loc);
+      profile->density      = (float)_cupsStrScand(string, &sptr, loc);
+      profile->gamma        = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[0][0] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[0][1] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[0][2] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[1][0] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[1][1] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[1][2] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[2][0] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[2][1] = (float)_cupsStrScand(sptr, &sptr, loc);
+      profile->matrix[2][2] = (float)_cupsStrScand(sptr, &sptr, loc);
     }
     else if (!strcmp(keyword, "cupsFilter"))
     {
@@ -928,8 +928,8 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
       if (!strcmp(ctype, "curve"))
       {
         cparam->type = PPD_CUSTOM_CURVE;
-	cparam->minimum.custom_curve = _cupsStrScand(cminimum, NULL, loc);
-	cparam->maximum.custom_curve = _cupsStrScand(cmaximum, NULL, loc);
+	cparam->minimum.custom_curve = (float)_cupsStrScand(cminimum, NULL, loc);
+	cparam->maximum.custom_curve = (float)_cupsStrScand(cmaximum, NULL, loc);
       }
       else if (!strcmp(ctype, "int"))
       {
@@ -940,8 +940,8 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
       else if (!strcmp(ctype, "invcurve"))
       {
         cparam->type = PPD_CUSTOM_INVCURVE;
-	cparam->minimum.custom_invcurve = _cupsStrScand(cminimum, NULL, loc);
-	cparam->maximum.custom_invcurve = _cupsStrScand(cmaximum, NULL, loc);
+	cparam->minimum.custom_invcurve = (float)_cupsStrScand(cminimum, NULL, loc);
+	cparam->maximum.custom_invcurve = (float)_cupsStrScand(cmaximum, NULL, loc);
       }
       else if (!strcmp(ctype, "passcode"))
       {
@@ -958,14 +958,14 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
       else if (!strcmp(ctype, "points"))
       {
         cparam->type = PPD_CUSTOM_POINTS;
-	cparam->minimum.custom_points = _cupsStrScand(cminimum, NULL, loc);
-	cparam->maximum.custom_points = _cupsStrScand(cmaximum, NULL, loc);
+	cparam->minimum.custom_points = (float)_cupsStrScand(cminimum, NULL, loc);
+	cparam->maximum.custom_points = (float)_cupsStrScand(cmaximum, NULL, loc);
       }
       else if (!strcmp(ctype, "real"))
       {
         cparam->type = PPD_CUSTOM_REAL;
-	cparam->minimum.custom_real = _cupsStrScand(cminimum, NULL, loc);
-	cparam->maximum.custom_real = _cupsStrScand(cmaximum, NULL, loc);
+	cparam->minimum.custom_real = (float)_cupsStrScand(cminimum, NULL, loc);
+	cparam->maximum.custom_real = (float)_cupsStrScand(cmaximum, NULL, loc);
       }
       else if (!strcmp(ctype, "string"))
       {
@@ -1001,9 +1001,9 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
     else if (!strcmp(keyword, "HWMargins"))
     {
       for (i = 0, sptr = string; i < 4; i ++)
-        ppd->custom_margins[i] = _cupsStrScand(sptr, &sptr, loc);
+        ppd->custom_margins[i] = (float)_cupsStrScand(sptr, &sptr, loc);
     }
-    else if (!strncmp(keyword, "Custom", 6) && !strcmp(name, "True"))
+    else if (!strncmp(keyword, "Custom", 6) && !strcmp(name, "True") && !option)
     {
       DEBUG_puts("Processing Custom option...");
 
@@ -1076,6 +1076,34 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	*/
 
 	ppd_add_size(ppd, "Custom");
+
+	if ((option = ppdFindOption(ppd, "PageRegion")) == NULL)
+	{
+	  ppd_group_t	*gtemp;		/* Temporary group */
+
+	  if ((gtemp = ppd_get_group(ppd, "General", _("General"), cg,
+				     encoding)) == NULL)
+	  {
+	    DEBUG_puts("Unable to get general group!");
+
+	    goto error;
+	  }
+
+	  option = ppd_get_option(gtemp, "PageRegion");
+        }
+
+	if ((choice = ppd_add_choice(option, "Custom")) == NULL)
+	{
+	  DEBUG_puts("Unable to add Custom choice!");
+
+	  cg->ppd_status = PPD_ALLOC_ERROR;
+
+	  goto error;
+	}
+
+	strlcpy(choice->text, text[0] ? text : _("Custom"),
+		sizeof(choice->text));
+        option = NULL;
       }
     }
     else if (!strcmp(keyword, "LandscapeOrientation"))
@@ -1400,7 +1428,7 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
     else if (!strcmp(keyword, "OrderDependency") ||
              !strcmp(keyword, "NonUIOrderDependency"))
     {
-      order = _cupsStrScand(string, &sptr, loc);
+      order = (float)_cupsStrScand(string, &sptr, loc);
 
       if (!sptr || sscanf(sptr, "%40s%40s", name, keyword) != 2)
       {
@@ -1523,10 +1551,10 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
              !strcmp(keyword, "NonUIConstraints"))
     {
       if (ppd->num_consts == 0)
-	constraint = calloc(1, sizeof(ppd_const_t));
+	constraint = calloc(2, sizeof(ppd_const_t));
       else
 	constraint = realloc(ppd->consts,
-	                     (ppd->num_consts + 1) * sizeof(ppd_const_t));
+	                     (ppd->num_consts + 2) * sizeof(ppd_const_t));
 
       if (constraint == NULL)
       {
@@ -1549,6 +1577,18 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	    goto error;
 
 	case 2 : /* Two options... */
+	   /*
+	    * Check for broken constraints like "* Option"...
+	    */
+
+	    if (cg->ppd_conform == PPD_CONFORM_STRICT &&
+	        (!strcmp(constraint->option1, "*") ||
+	         !strcmp(constraint->choice1, "*")))
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
+
 	   /*
 	    * The following strcpy's are safe, as optionN and
 	    * choiceN are all the same size (size defined by PPD spec...)
@@ -1556,17 +1596,38 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 
 	    if (constraint->option1[0] == '*')
 	      _cups_strcpy(constraint->option1, constraint->option1 + 1);
+	    else if (cg->ppd_conform == PPD_CONFORM_STRICT)
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
 
 	    if (constraint->choice1[0] == '*')
 	      _cups_strcpy(constraint->option2, constraint->choice1 + 1);
-	    else
-	      _cups_strcpy(constraint->option2, constraint->choice1);
+	    else if (cg->ppd_conform == PPD_CONFORM_STRICT)
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
 
             constraint->choice1[0] = '\0';
             constraint->choice2[0] = '\0';
 	    break;
 	    
 	case 3 : /* Two options, one choice... */
+	   /*
+	    * Check for broken constraints like "* Option"...
+	    */
+
+	    if (cg->ppd_conform == PPD_CONFORM_STRICT &&
+	        (!strcmp(constraint->option1, "*") ||
+	         !strcmp(constraint->choice1, "*") ||
+	         !strcmp(constraint->option2, "*")))
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
+
 	   /*
 	    * The following _cups_strcpy's are safe, as optionN and
 	    * choiceN are all the same size (size defined by PPD spec...)
@@ -1574,9 +1635,21 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 
 	    if (constraint->option1[0] == '*')
 	      _cups_strcpy(constraint->option1, constraint->option1 + 1);
+	    else if (cg->ppd_conform == PPD_CONFORM_STRICT)
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
 
 	    if (constraint->choice1[0] == '*')
 	    {
+	      if (cg->ppd_conform == PPD_CONFORM_STRICT &&
+	          constraint->option2[0] == '*')
+	      {
+		cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+		goto error;
+	      }
+
 	      _cups_strcpy(constraint->choice2, constraint->option2);
 	      _cups_strcpy(constraint->option2, constraint->choice1 + 1);
               constraint->choice1[0] = '\0';
@@ -1585,20 +1658,113 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	    {
 	      if (constraint->option2[0] == '*')
   	        _cups_strcpy(constraint->option2, constraint->option2 + 1);
+	      else if (cg->ppd_conform == PPD_CONFORM_STRICT)
+	      {
+		cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+		goto error;
+	      }
 
               constraint->choice2[0] = '\0';
 	    }
 	    break;
 	    
 	case 4 : /* Two options, two choices... */
+	   /*
+	    * Check for broken constraints like "* Option"...
+	    */
+
+	    if (cg->ppd_conform == PPD_CONFORM_STRICT &&
+	        (!strcmp(constraint->option1, "*") ||
+	         !strcmp(constraint->choice1, "*") ||
+	         !strcmp(constraint->option2, "*") ||
+	         !strcmp(constraint->choice2, "*")))
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
+
 	    if (constraint->option1[0] == '*')
 	      _cups_strcpy(constraint->option1, constraint->option1 + 1);
+	    else if (cg->ppd_conform == PPD_CONFORM_STRICT)
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
+
+            if (cg->ppd_conform == PPD_CONFORM_STRICT &&
+	        constraint->choice1[0] == '*')
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
 
 	    if (constraint->option2[0] == '*')
   	      _cups_strcpy(constraint->option2, constraint->option2 + 1);
+	    else if (cg->ppd_conform == PPD_CONFORM_STRICT)
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
+
+            if (cg->ppd_conform == PPD_CONFORM_STRICT &&
+	        constraint->choice2[0] == '*')
+	    {
+	      cg->ppd_status = PPD_BAD_UI_CONSTRAINTS;
+	      goto error;
+	    }
 	    break;
       }
 
+     /*
+      * For CustomPageSize and InputSlot/ManualFeed, create a duplicate
+      * constraint for PageRegion...
+      */
+
+      if (!strcasecmp(constraint->option1, "CustomPageSize") &&
+          (!strcasecmp(constraint->option2, "InputSlot") ||
+	   !strcasecmp(constraint->option2, "ManualFeed")))
+      {
+        ppd->num_consts ++;
+
+        strcpy(constraint[1].option1, "PageRegion");
+	strcpy(constraint[1].choice1, "Custom");
+	strcpy(constraint[1].option2, constraint->option2);
+	strcpy(constraint[1].choice2, constraint->choice2);
+      }
+      else if (!strcasecmp(constraint->option2, "CustomPageSize") &&
+               (!strcasecmp(constraint->option1, "InputSlot") ||
+	        !strcasecmp(constraint->option1, "ManualFeed")))
+      {
+        ppd->num_consts ++;
+
+	strcpy(constraint[1].option1, constraint->option1);
+	strcpy(constraint[1].choice1, constraint->choice1);
+        strcpy(constraint[1].option2, "PageRegion");
+	strcpy(constraint[1].choice2, "Custom");
+      }
+
+     /*
+      * Handle CustomFoo option constraints...
+      */
+
+      if (!strncasecmp(constraint->option1, "Custom", 6) &&
+          !strcasecmp(constraint->choice1, "True"))
+      {
+        _cups_strcpy(constraint->option1, constraint->option1 + 6);
+	strcpy(constraint->choice1, "Custom");
+      }
+
+      if (!strncasecmp(constraint->option2, "Custom", 6) &&
+          !strcasecmp(constraint->choice2, "True"))
+      {
+        _cups_strcpy(constraint->option2, constraint->option2 + 6);
+	strcpy(constraint->choice2, "Custom");
+      }
+
+     /*
+      * Don't add this one as an attribute...
+      */
+
       ppd_free(string);
       string = NULL;
     }
@@ -1618,8 +1784,8 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	goto error;
       }
 
-      size->width  = _cupsStrScand(string, &sptr, loc);
-      size->length = _cupsStrScand(sptr, NULL, loc);
+      size->width  = (float)_cupsStrScand(string, &sptr, loc);
+      size->length = (float)_cupsStrScand(sptr, NULL, loc);
 
       ppd_free(string);
       string = NULL;
@@ -1640,10 +1806,10 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	goto error;
       }
 
-      size->left   = _cupsStrScand(string, &sptr, loc);
-      size->bottom = _cupsStrScand(sptr, &sptr, loc);
-      size->right  = _cupsStrScand(sptr, &sptr, loc);
-      size->top    = _cupsStrScand(sptr, NULL, loc);
+      size->left   = (float)_cupsStrScand(string, &sptr, loc);
+      size->bottom = (float)_cupsStrScand(sptr, &sptr, loc);
+      size->right  = (float)_cupsStrScand(sptr, &sptr, loc);
+      size->top    = (float)_cupsStrScand(sptr, NULL, loc);
 
       ppd_free(string);
       string = NULL;
@@ -2260,7 +2426,7 @@ ppd_get_cparam(ppd_coption_t *opt,	/* I - PPD file */
     return (NULL);
 
   strlcpy(cparam->name, param, sizeof(cparam->name));
-  strlcpy(cparam->text, text, sizeof(cparam->text));
+  strlcpy(cparam->text, text[0] ? text : param, sizeof(cparam->text));
 
  /*
   * Add this record to the array...
@@ -2936,5 +3102,5 @@ ppd_read(cups_file_t    *fp,		/* I - File to read from */
 
 
 /*
- * End of "$Id: ppd.c 5826 2006-08-15 19:04:11Z mike $".
+ * End of "$Id: ppd.c 6446 2007-04-04 23:43:50Z mike $".
  */
