@@ -1,9 +1,9 @@
 /*
- * "$Id: testlang.c,v 1.8 2005/01/03 19:29:45 mike Exp $"
+ * "$Id: testlang.c 6346 2007-03-17 18:07:17Z mike $"
  *
  *   Localization test program for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -33,7 +33,8 @@
  */
 
 #include <stdio.h>
-#include "language.h"
+#include "i18n.h"
+#include "string.h"
 
 
 /*
@@ -44,40 +45,24 @@ int					/* O - Exit status */
 main(int  argc,				/* I - Number of command-line arguments */
      char *argv[])			/* I - Command-line arguments */
 {
+  int			i;		/* Looping var */
+  int			errors = 0;	/* Number of errors */
   cups_lang_t		*language;	/* Message catalog */
   cups_lang_t		*language2;	/* Message catalog */
-  static const char * const charsets[] =/* Character sets */
-			{
-			  "us-ascii",
-			  "iso-8859-1",
-			  "iso-8859-2",
-			  "iso-8859-3",
-			  "iso-8859-4",
-			  "iso-8859-5",
-			  "iso-8859-6",
-			  "iso-8859-7",
-			  "iso-8859-8",
-			  "iso-8859-9",
-			  "iso-8859-10",
-			  "utf-8",
-			  "iso8859-13",
-			  "iso8859-14",
-			  "iso8859-15",
-			  "windows-874",
-			  "windows-1250",
-			  "windows-1251",
-			  "windows-1252",
-			  "windows-1253",
-			  "windows-1254",
-			  "windows-1255",
-			  "windows-1256",
-			  "windows-1257",
-			  "windows-1258",
-			  "koi8-r",
-			  "koi8-u"
-			};
+  struct lconv		*loc;		/* Locale data */
+  char			buffer[1024];	/* String buffer */
+  double		number;		/* Number */
+  static const char * const tests[] =	/* Test strings */
+  {
+    "1",
+    "-1",
+    "3",
+    "5.125"
+  };
 
 
+  _cupsSetLocale(argv);
+
   if (argc == 1)
   {
     language  = cupsLangDefault();
@@ -91,29 +76,50 @@ main(int  argc,				/* I - Number of command-line arguments */
 
   if (language != language2)
   {
+    errors ++;
+
     puts("**** ERROR: Language cache did not work! ****");
     puts("First result from cupsLangGet:");
   }
 
   printf("Language = \"%s\"\n", language->language);
-  printf("Encoding = \"%s\"\n", charsets[language->encoding]);
-  printf("No       = \"%s\"\n", cupsLangString(language, CUPS_MSG_NO));
-  printf("Yes      = \"%s\"\n", cupsLangString(language, CUPS_MSG_YES));
+  printf("Encoding = \"%s\"\n", _cupsEncodingName(language->encoding));
+  printf("No       = \"%s\"\n", _cupsLangString(language, "No"));
+  printf("Yes      = \"%s\"\n", _cupsLangString(language, "Yes"));
 
   if (language != language2)
   {
     puts("Second result from cupsLangGet:");
 
     printf("Language = \"%s\"\n", language2->language);
-    printf("Encoding = \"%s\"\n", charsets[language2->encoding]);
-    printf("No       = \"%s\"\n", cupsLangString(language2, CUPS_MSG_NO));
-    printf("Yes      = \"%s\"\n", cupsLangString(language2, CUPS_MSG_YES));
+    printf("Encoding = \"%s\"\n", _cupsEncodingName(language2->encoding));
+    printf("No       = \"%s\"\n", _cupsLangString(language2, "No"));
+    printf("Yes      = \"%s\"\n", _cupsLangString(language2, "Yes"));
   }
 
-  return (0);
+  loc = localeconv();
+
+  for (i = 0; i < (int)(sizeof(tests) / sizeof(tests[0])); i ++)
+  {
+    number = _cupsStrScand(tests[i], NULL, loc);
+
+    printf("_cupsStrScand(\"%s\") number=%f\n", tests[i], number);
+
+    _cupsStrFormatd(buffer, buffer + sizeof(buffer), number, loc);
+
+    printf("_cupsStrFormatd(%f) buffer=\"%s\"\n", number, buffer);
+
+    if (strcmp(buffer, tests[i]))
+    {
+      errors ++;
+      puts("**** ERROR: Bad formatted number! ****");
+    }
+  }
+
+  return (errors > 0);
 }
 
 
 /*
- * End of "$Id: testlang.c,v 1.8 2005/01/03 19:29:45 mike Exp $".
+ * End of "$Id: testlang.c 6346 2007-03-17 18:07:17Z mike $".
  */
