@@ -1,9 +1,9 @@
 /*
- * "$Id: transcode.c 6038 2006-10-14 15:53:10Z mike $"
+ * "$Id: transcode.c 6188 2007-01-10 16:23:06Z mike $"
  *
  *   Transcoding support for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products.
+ *   Copyright 1997-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are
  *   the property of Easy Software Products and are protected by Federal
@@ -292,7 +292,39 @@ cupsCharsetToUTF8(
       encoding < 0 || encoding >= CUPS_ENCODING_VBCS_END)
   {
     strlcpy((char *)dest, src, maxout);
-    return (strlen((char *)dest));
+    return ((int)strlen((char *)dest));
+  }
+
+ /*
+  * Handle ISO-8859-1 to UTF-8 directly...
+  */
+
+  if (encoding == CUPS_ISO8859_1)
+  {
+    int		ch;			/* Character from string */
+    cups_utf8_t	*destptr,		/* Pointer into UTF-8 buffer */
+		*destend;		/* End of UTF-8 buffer */
+
+
+    destptr = dest;
+    destend = dest + maxout - 2;
+
+    while (*src && destptr < destend)
+    {
+      ch = *src++ & 255;
+
+      if (ch & 128)
+      {
+	*destptr++ = 0xc0 | (ch >> 6);
+	*destptr++ = 0x80 | (ch & 0x3f);
+      }
+      else
+	*destptr++ = ch;
+    }
+
+    *destptr = '\0';
+
+    return ((int)(destptr - dest));
   }
 
  /*
@@ -360,7 +392,46 @@ cupsUTF8ToCharset(
       encoding < 0 || encoding >= CUPS_ENCODING_VBCS_END)
   {
     strlcpy(dest, (char *)src, maxout);
-    return (strlen(dest));
+    return ((int)strlen(dest));
+  }
+
+ /*
+  * Handle UTF-8 to ISO-8859-1 directly...
+  */
+
+  if (encoding == CUPS_ISO8859_1)
+  {
+    int		ch;			/* Character from string */
+    char	*destptr,		/* Pointer into ISO-8859-1 buffer */
+		*destend;		/* End of ISO-8859-1 buffer */
+
+
+    destptr = dest;
+    destend = dest + maxout - 1;
+
+    while (*src && destptr < destend)
+    {
+      ch = *src++;
+
+      if ((ch & 0xe0) == 0xc0)
+      {
+	ch = ((ch & 0x1f) << 6) | (*src++ & 0x3f);
+
+	if (ch < 256)
+          *destptr++ = ch;
+	else
+          *destptr++ = '?';
+      }
+      else if ((ch & 0xf0) == 0xe0 ||
+               (ch & 0xf8) == 0xf0)
+        *destptr++ = '?';
+      else if (!(ch & 0x80))
+	*destptr++ = ch;
+    }
+
+    *destptr = '\0';
+
+    return ((int)(destptr - dest));
   }
 
  /*
@@ -897,7 +968,7 @@ conv_utf8_to_vbcs(
 
     if (unichar < 0x80)
     {
-      *dest++ = (cups_vbcs_t)unichar;
+      *dest++ = (cups_sbcs_t)unichar;
       continue;
     }
 
@@ -1584,5 +1655,5 @@ get_vbcs_charmap(
 
 
 /*
- * End of "$Id: transcode.c 6038 2006-10-14 15:53:10Z mike $"
+ * End of "$Id: transcode.c 6188 2007-01-10 16:23:06Z mike $"
  */
