@@ -1,9 +1,9 @@
 /*
- * "$Id: common.h,v 1.13 2002/12/17 18:59:24 swdev Exp $"
+ * "$Id: common.h 6003 2006-10-02 16:26:04Z mike $"
  *
  *   Common filter definitions for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2003 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -15,9 +15,9 @@
  *       Attn: CUPS Licensing Information
  *       Easy Software Products
  *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636-3111 USA
+ *       Hollywood, Maryland 20636 USA
  *
- *       Voice: (301) 373-9603
+ *       Voice: (301) 373-9600
  *       EMail: cups-info@cups.org
  *         WWW: http://www.cups.org
  *
@@ -76,6 +76,7 @@ extern void	WriteCommon(void);
 extern void	WriteLabelProlog(const char *label, float bottom,
 		                 float top, float width);
 extern void	WriteLabels(int orient);
+extern void	WriteTextComment(const char *name, const char *value);
 
 
 /*
@@ -88,5 +89,5 @@ extern void	WriteLabels(int orient);
 
 
 /*
- * End of "$Id: common.h,v 1.13 2002/12/17 18:59:24 swdev Exp $".
+ * End of "$Id: common.h 6003 2006-10-02 16:26:04Z mike $".
  */
