@@ -18,7 +18,7 @@
 #include "GlobalParams.h"
 #include "Error.h"
 
-void CDECL error(int pos, const char *msg, ...) {
+void CDECL error(int pos, char *msg, ...) {
   va_list args;
 
   // NB: this can be called before the globalParams object is created
@@ -26,9 +26,9 @@ void CDECL error(int pos, const char *msg, ...) {
     return;
   }
   if (pos >= 0) {
-    fprintf(stderr, "ERROR: (%d) ", pos);
+    fprintf(stderr, "Error (%d): ", pos);
   } else {
-    fprintf(stderr, "ERROR: ");
+    fprintf(stderr, "Error: ");
   }
   va_start(args, msg);
   vfprintf(stderr, msg, args);
