@@ -1,9 +1,9 @@
 /*
- * "$Id: banners.h,v 1.8 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: banners.h 5305 2006-03-18 03:05:12Z mike $"
  *
  *   Banner definitions for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -26,32 +26,29 @@
  * Banner information structure...
  */
 
-typedef struct
+typedef struct				/**** Banner file information ****/
 {
-  char		name[256];	/* Name of banner */
-  mime_type_t	*filetype;	/* Filetype for banner */
-} banner_t;
+  char		*name;			/* Name of banner */
+  mime_type_t	*filetype;		/* Filetype for banner */
+} cupsd_banner_t;
 
 
 /*
  * Globals...
  */
 
-VAR int		NumBanners	VALUE(0);
-				/* Number of banner files available */
-VAR banner_t	*Banners	VALUE(NULL);
-				/* Available banner files */
+VAR cups_array_t	*Banners	VALUE(NULL);
+					/* Available banner files */
 
 
 /*
  * Prototypes...
  */
 
-extern void	AddBanner(const char *name, const char *filename);
-extern banner_t	*FindBanner(const char *name);
-extern void	LoadBanners(const char *d);
+extern cupsd_banner_t	*cupsdFindBanner(const char *name);
+extern void		cupsdLoadBanners(const char *d);
 
 
 /*
- * End of "$Id: banners.h,v 1.8 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: banners.h 5305 2006-03-18 03:05:12Z mike $".
  */
