@@ -1,5 +1,5 @@
 /*
- * "$Id: conf.c 5905 2006-08-29 20:48:59Z mike $"
+ * "$Id: conf.c 6410 2007-03-28 18:03:19Z mike $"
  *
  *   Configuration routines for the Common UNIX Printing System (CUPS).
  *
@@ -1146,7 +1146,7 @@ check_permissions(const char *filename,	/* I - File/directory name */
   {
     if (errno == ENOENT && create_dir)
     {
-      cupsdLogMessage(CUPSD_LOG_ERROR, "Creating missing directory \"%s\"",
+      cupsdLogMessage(CUPSD_LOG_DEBUG, "Creating missing directory \"%s\"",
                       filename);
 
       if (mkdir(filename, mode))
@@ -1185,9 +1185,9 @@ check_permissions(const char *filename,	/* I - File/directory name */
 
   if (dir_created || fileinfo.st_uid != user || fileinfo.st_gid != group)
   {
-    cupsdLogMessage(CUPSD_LOG_WARN, "Repairing ownership of \"%s\"", filename);
+    cupsdLogMessage(CUPSD_LOG_DEBUG, "Repairing ownership of \"%s\"", filename);
 
-    if (chown(filename, user, group))
+    if (chown(filename, user, group) && !getuid())
     {
       cupsdLogMessage(CUPSD_LOG_ERROR,
                       "Unable to change ownership of \"%s\" - %s", filename,
@@ -1198,7 +1198,8 @@ check_permissions(const char *filename,	/* I - File/directory name */
 
   if (dir_created || (fileinfo.st_mode & 07777) != mode)
   {
-    cupsdLogMessage(CUPSD_LOG_WARN, "Repairing access permissions of \"%s\"", filename);
+    cupsdLogMessage(CUPSD_LOG_DEBUG, "Repairing access permissions of \"%s\"",
+                    filename);
 
     if (chmod(filename, mode))
     {
@@ -1316,7 +1317,7 @@ get_addr_and_mask(const char *value,	/* I - String from config file */
   * Get the address...
   */
 
-  ip[0]   = ip[1]   = ip[2]   = ip[2]   = 0x00000000;
+  ip[0]   = ip[1]   = ip[2]   = ip[3]   = 0x00000000;
   mask[0] = mask[1] = mask[2] = mask[3] = 0xffffffff;
 
   if ((maskval = strchr(value, '/')) != NULL)
@@ -1501,7 +1502,7 @@ get_addr_and_mask(const char *value,	/* I - String from config file */
 
   cupsdLogMessage(CUPSD_LOG_DEBUG2,
                   "get_addr_and_mask(value=\"%s\", "
-                  "ip=[%08x:%08x:%08x:%08x], mask=[%08x:%08x:%08x:%08x]",
+                  "ip=[%08x:%08x:%08x:%08x], mask=[%08x:%08x:%08x:%08x])",
              value, ip[0], ip[1], ip[2], ip[3], mask[0], mask[1], mask[2],
 	     mask[3]);
 
@@ -1990,7 +1991,7 @@ parse_protocols(const char *s)		/* I - Space-delimited protocols */
       protocols |= BROWSE_DNSSD;
     else if (!strcasecmp(valstart, "all"))
       protocols |= BROWSE_ALL;
-    else
+    else if (strcasecmp(valstart, "none"))
       return (-1);
 
     for (valstart = valend; *valstart; valstart ++)
@@ -3289,5 +3290,5 @@ read_policy(cups_file_t *fp,		/* I - Configuration file */
 
 
 /*
- * End of "$Id: conf.c 5905 2006-08-29 20:48:59Z mike $".
+ * End of "$Id: conf.c 6410 2007-03-28 18:03:19Z mike $".
  */
