@@ -1,10 +1,10 @@
 /*
- * "$Id: conf.h,v 1.65 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: conf.h 5696 2006-06-26 18:34:20Z mike $"
  *
  *   Configuration file definitions for the Common UNIX Printing System (CUPS)
  *   scheduler.
  *
- *   Copyright 1997-2005 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -28,18 +28,22 @@
  * Log levels...
  */
 
-#define L_STATE		-2	/* Used internally for state-reasons */
-#define L_PAGE		-1	/* Used internally for page logging */
-#define L_NONE		0
-#define L_EMERG		1	/* Emergency issues */
-#define L_ALERT		2	/* Something bad happened that needs attention */
-#define L_CRIT		3	/* Critical error but server continues */
-#define L_ERROR		4	/* Error condition */
-#define L_WARN		5	/* Warning */
-#define L_NOTICE	6	/* Normal condition that needs logging */
-#define L_INFO		7	/* General information */
-#define L_DEBUG		8	/* General debugging */
-#define L_DEBUG2	9	/* Detailed debugging */
+typedef enum
+{
+  CUPSD_LOG_ATTR = -3,		/* Used internally for attributes */
+  CUPSD_LOG_STATE,		/* Used internally for state-reasons */
+  CUPSD_LOG_PAGE,		/* Used internally for page logging */
+  CUPSD_LOG_NONE,
+  CUPSD_LOG_EMERG,		/* Emergency issues */
+  CUPSD_LOG_ALERT,		/* Something bad happened that needs attention */
+  CUPSD_LOG_CRIT,		/* Critical error but server continues */
+  CUPSD_LOG_ERROR,		/* Error condition */
+  CUPSD_LOG_WARN,		/* Warning */
+  CUPSD_LOG_NOTICE,		/* Normal condition that needs logging */
+  CUPSD_LOG_INFO,		/* General information */
+  CUPSD_LOG_DEBUG,		/* General debugging */
+  CUPSD_LOG_DEBUG2		/* Detailed debugging */
+} cupsd_loglevel_t;
 
 
 /*
@@ -64,20 +68,27 @@ VAR char		*ConfigurationFile	VALUE(NULL),
 					/* Root directory for scheduler */
 			*ServerBin		VALUE(NULL),
 					/* Root directory for binaries */
+			*StateDir		VALUE(NULL),
+					/* Root directory for state data */
 			*RequestRoot		VALUE(NULL),
 					/* Directory for request files */
 			*DocumentRoot		VALUE(NULL);
 					/* Root directory for documents */
+VAR int			ServerNameIsIP		VALUE(0);
 VAR int			NumSystemGroups		VALUE(0);
 					/* Number of system group names */
-VAR char		*SystemGroups[MAX_SYSTEM_GROUPS],
+VAR char		*SystemGroups[MAX_SYSTEM_GROUPS];
 					/* System group names */
-			*AccessLog		VALUE(NULL),
+VAR gid_t		SystemGroupIDs[MAX_SYSTEM_GROUPS];
+					/* System group IDs */
+VAR char		*AccessLog		VALUE(NULL),
 					/* Access log filename */
 			*ErrorLog		VALUE(NULL),
 					/* Error log filename */
 			*PageLog		VALUE(NULL),
 					/* Page log filename */
+			*CacheDir		VALUE(NULL),
+					/* Cache file directory */
 			*DataDir		VALUE(NULL),
 					/* Data file directory */
 			*DefaultLanguage	VALUE(NULL),
@@ -106,11 +117,11 @@ VAR gid_t		Group			VALUE(0);
 					/* Group ID for server */
 VAR int			ClassifyOverride	VALUE(0),
 					/* Allow overrides? */
-			ConfigFilePerm		VALUE(0600),
+			ConfigFilePerm		VALUE(0640),
 					/* Permissions for config files */
 			LogFilePerm		VALUE(0644),
 					/* Permissions for log files */
-			LogLevel		VALUE(L_ERROR),
+			LogLevel		VALUE(CUPSD_LOG_ERROR),
 					/* Log level */
 			MaxClients		VALUE(0),
 					/* Maximum number of clients */
@@ -150,11 +161,11 @@ VAR int			ClassifyOverride	VALUE(0),
 					/* Timeout before reload from SIGHUP */
 			RootCertDuration	VALUE(300),
 					/* Root certificate update interval */
-			RunAsUser		VALUE(FALSE),
-					/* Run as unpriviledged user? */
 			RunUser,	/* User to run as, used for files */
-			PrintcapFormat		VALUE(PRINTCAP_BSD);
+			PrintcapFormat		VALUE(PRINTCAP_BSD),
 					/* Format of printcap file? */
+			DefaultShared		VALUE(TRUE);
+					/* Share printers by default? */
 VAR cups_file_t		*AccessFile		VALUE(NULL),
 					/* Access log file */
 			*ErrorFile		VALUE(NULL),
@@ -174,28 +185,31 @@ VAR char		*ServerCertificate	VALUE(NULL);
 #  if defined(HAVE_LIBSSL) || defined(HAVE_GNUTLS)
 VAR char		*ServerKey		VALUE(NULL);
 					/* Server key file */
-#  else
-VAR CFArrayRef		ServerCertificatesArray	VALUE(NULL);
-					/* Array containing certificates */
 #  endif /* HAVE_LIBSSL || HAVE_GNUTLS */
 #endif /* HAVE_SSL */
 
+#ifdef HAVE_LAUNCHD
+VAR int			LaunchdTimeout		VALUE(DEFAULT_TIMEOUT);
+					/* Time after which an idle cupsd will exit */
+VAR char		*LaunchdConf		VALUE(NULL);
+					/* launchd(8) configuration file */
+#endif /* HAVE_LAUNCHD */
 
 /*
  * Prototypes...
  */
 
-extern char	*GetDateTime(time_t t);
-extern int	ReadConfiguration(void);
-extern int	LogRequest(client_t *con, http_status_t code);
-extern int	LogMessage(int level, const char *message, ...)
+extern char	*cupsdGetDateTime(time_t t);
+extern int	cupsdReadConfiguration(void);
+extern int	cupsdLogRequest(cupsd_client_t *con, http_status_t code);
+extern int	cupsdLogMessage(int level, const char *message, ...)
 #ifdef __GNUC__
 __attribute__ ((__format__ (__printf__, 2, 3)))
 #endif /* __GNUC__ */
 ;
-extern int	LogPage(job_t *job, const char *page);
+extern int	cupsdLogPage(cupsd_job_t *job, const char *page);
 
 
 /*
- * End of "$Id: conf.h,v 1.65 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: conf.h 5696 2006-06-26 18:34:20Z mike $".
  */
