@@ -1,5 +1,5 @@
 /*
- * "$Id: cups-driverd.c 5422 2006-04-18 15:16:00Z mike $"
+ * "$Id: cups-driverd.c 6458 2007-04-17 19:22:41Z mike $"
  *
  *   PPD/driver support for the Common UNIX Printing System (CUPS).
  *
@@ -147,6 +147,7 @@ add_ppd(const char *name,		/* I - PPD name */
 	size_t     size)		/* I - File size */
 {
   ppd_info_t	*ppd;			/* PPD */
+  char		*recommended;		/* Foomatic driver string */
 
 
  /*
@@ -197,6 +198,14 @@ add_ppd(const char *name,		/* I - PPD name */
           sizeof(ppd->record.make_and_model));
   strlcpy(ppd->record.device_id, device_id, sizeof(ppd->record.device_id));
 
+ /*
+  * Strip confusing (and often wrong) "recommended" suffix added by
+  * Foomatic drivers...
+  */
+
+  if ((recommended = strstr(ppd->record.make_and_model, " (recommended)")) != NULL)
+    *recommended = '\0';
+
  /*
   * Return the new PPD pointer...
   */
@@ -666,7 +675,7 @@ load_ppds(const char *d,		/* I - Actual directory */
 		*language;		/* Language code */
   }		languages[] =
   {
-    { "chinese",	"cn" },
+    { "chinese",	"zh" },
     { "danish",		"da" },
     { "dutch",		"nl" },
     { "english",	"en" },
@@ -675,7 +684,7 @@ load_ppds(const char *d,		/* I - Actual directory */
     { "german",		"de" },
     { "greek",		"el" },
     { "italian",	"it" },
-    { "japanese",	"jp" },
+    { "japanese",	"ja" },
     { "norwegian",	"no" },
     { "polish",		"pl" },
     { "portuguese",	"pt" },
@@ -1113,5 +1122,5 @@ load_drivers(void)
 
 
 /*
- * End of "$Id: cups-driverd.c 5422 2006-04-18 15:16:00Z mike $".
+ * End of "$Id: cups-driverd.c 6458 2007-04-17 19:22:41Z mike $".
  */
