@@ -1,9 +1,9 @@
 /*
- * "$Id: dirsvc.c 6090 2006-11-14 16:35:27Z mike $"
+ * "$Id: dirsvc.c 6484 2007-04-30 17:18:21Z mike $"
  *
  *   Directory services routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -163,7 +163,7 @@ cupsdLoadRemoteCache(void)
   * Don't load the cache if the CUPS remote protocol is disabled...
   */
 
-  if (!(BrowseRemoteProtocols & BROWSE_CUPS))
+  if (!Browsing || !(BrowseRemoteProtocols & BROWSE_CUPS))
   {
     cupsdLogMessage(CUPSD_LOG_DEBUG,
                     "cupsdLoadRemoteCache: Not loading remote cache.");
@@ -2396,6 +2396,9 @@ process_implicit_classes(void)
         cupsdSetString(&pclass->location, p->location);
         cupsdSetString(&pclass->info, p->info);
 
+        cupsdSetString(&pclass->job_sheets[0], p->job_sheets[0]);
+        cupsdSetString(&pclass->job_sheets[1], p->job_sheets[1]);
+
         update = 1;
 
         cupsdLogMessage(CUPSD_LOG_DEBUG, "Added implicit class \"%s\"...",
@@ -2624,7 +2627,7 @@ send_cups_browse(cupsd_printer_t *p)	/* I - Printer to send */
 	{
 	  httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
 	                   iface->hostname, iface->port,
-			   (p->type & CUPS_PRINTER_CLASS) ? "/classes/%s%s" :
+			   (p->type & CUPS_PRINTER_CLASS) ? "/classes/%s" :
 			                                    "/printers/%s",
 			   p->name);
 	  snprintf(packet, sizeof(packet), "%x %x %s \"%s\" \"%s\" \"%s\" %s\n",
@@ -3192,5 +3195,5 @@ slp_url_callback(
 
 
 /*
- * End of "$Id: dirsvc.c 6090 2006-11-14 16:35:27Z mike $".
+ * End of "$Id: dirsvc.c 6484 2007-04-30 17:18:21Z mike $".
  */
