@@ -1,5 +1,5 @@
 /*
- * "$Id: job.c 6032 2006-10-12 19:19:47Z mike $"
+ * "$Id: job.c 6465 2007-04-23 20:36:09Z mike $"
  *
  *   Job management routines for the Common UNIX Printing System (CUPS).
  *
@@ -199,12 +199,11 @@ cupsdCancelJob(cupsd_job_t  *job,	/* I - Job to cancel */
 
     case IPP_JOB_COMPLETED :
        /*
-	* Clear the printer's state_message and state_reasons and move on...
+	* Clear the printer's printer-state-message and move on...
 	*/
 
 	printer->state_message[0] = '\0';
 
-	cupsdSetPrinterReasons(printer, "");
 	cupsdSetPrinterState(printer, IPP_PRINTER_IDLE, 0);
 
 	cupsdAddEvent(CUPSD_EVENT_JOB_COMPLETED, printer, job,
@@ -373,13 +372,12 @@ cupsdCheckJobs(void)
 
         pclass = printer;
 
-        if (!(pclass->type & CUPS_PRINTER_REMOTE))
-	{
-	  if (pclass->state != IPP_PRINTER_STOPPED)
-	    printer = cupsdFindAvailablePrinter(job->dest);
-	  else
-	    printer = NULL;
-	}
+        if (pclass->state == IPP_PRINTER_STOPPED)
+	  printer = NULL;
+        else if (pclass->type & CUPS_PRINTER_REMOTE)
+	  break;
+	else
+	  printer = cupsdFindAvailablePrinter(printer->name);
       }
 
       if (!printer && !pclass)
@@ -1497,7 +1495,7 @@ cupsdSetJobHoldUntil(cupsd_job_t *job,	/* I - Job */
     */
 
     if (job->hold_until < curtime)
-      job->hold_until += 24 * 60 * 60 * 60;
+      job->hold_until += 24 * 60 * 60;
   }
 
   cupsdLogMessage(CUPSD_LOG_DEBUG2, "cupsdSetJobHoldUntil: hold_until = %d",
@@ -1775,6 +1773,7 @@ cupsdUpdateJob(cupsd_job_t *job)	/* I - Job to check */
       strlcpy(job->printer->state_message, message,
               sizeof(job->printer->state_message));
       cupsdAddPrinterHistory(job->printer);
+      event |= CUPSD_EVENT_PRINTER_STATE_CHANGED;
     }
 
     if (!strchr(job->status_buffer->buffer, '\n'))
@@ -2840,6 +2839,7 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
       if ((!strcmp(attr->name, "page-label") ||
            !strcmp(attr->name, "page-border") ||
            !strncmp(attr->name, "number-up", 9) ||
+	   !strcmp(attr->name, "page-ranges") ||
 	   !strcmp(attr->name, "page-set") ||
 	   !strcasecmp(attr->name, "AP_FIRSTPAGE_InputSlot") ||
 	   !strcasecmp(attr->name, "AP_FIRSTPAGE_ManualFeed")) &&
@@ -3432,6 +3432,8 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
   cupsdClosePipe(job->status_pipes);
   cupsdStatBufDelete(job->status_buffer);
 
+  job->status_buffer = NULL;
+
   cupsArrayDelete(filters);
 
   if (printer->remote && job->num_files > 1)
@@ -3468,5 +3470,5 @@ unload_job(cupsd_job_t *job)		/* I - Job */
 
 
 /*
- * End of "$Id: job.c 6032 2006-10-12 19:19:47Z mike $".
+ * End of "$Id: job.c 6465 2007-04-23 20:36:09Z mike $".
  */
