@@ -1,5 +1,5 @@
 /*
- * "$Id: log.c 6027 2006-10-11 21:04:58Z mike $"
+ * "$Id: log.c 6333 2007-03-12 20:49:13Z mike $"
  *
  *   Log file routines for the Common UNIX Printing System (CUPS).
  *
@@ -414,9 +414,10 @@ static int				/* O  - 1 if log file open */
 check_log_file(cups_file_t **lf,	/* IO - Log file */
 	       const char  *logname)	/* I  - Log filename */
 {
-  char	backname[1024],			/* Backup log filename */
-	filename[1024],			/* Formatted log filename */
-	*ptr;				/* Pointer into filename */
+  char		backname[1024],		/* Backup log filename */
+		filename[1024],		/* Formatted log filename */
+		*ptr;			/* Pointer into filename */
+  const char	*logptr;		/* Pointer into log filename */
 
 
  /*
@@ -448,17 +449,17 @@ check_log_file(cups_file_t **lf,	/* IO - Log file */
     else
       filename[0] = '\0';
 
-    for (ptr = filename + strlen(filename);
-         *logname && ptr < (filename + sizeof(filename) - 1);
-	 logname ++)
-      if (*logname == '%')
+    for (logptr = logname, ptr = filename + strlen(filename);
+         *logptr && ptr < (filename + sizeof(filename) - 1);
+	 logptr ++)
+      if (*logptr == '%')
       {
        /*
         * Format spec...
 	*/
 
-        logname ++;
-	if (*logname == 's')
+        logptr ++;
+	if (*logptr == 's')
 	{
 	 /*
 	  * Insert the server name...
@@ -473,11 +474,11 @@ check_log_file(cups_file_t **lf,	/* IO - Log file */
 	  * Otherwise just insert the character...
 	  */
 
-	  *ptr++ = *logname;
+	  *ptr++ = *logptr;
 	}
       }
       else
-	*ptr++ = *logname;
+	*ptr++ = *logptr;
 
     *ptr = '\0';
   }
@@ -551,5 +552,5 @@ check_log_file(cups_file_t **lf,	/* IO - Log file */
 
 
 /*
- * End of "$Id: log.c 6027 2006-10-11 21:04:58Z mike $".
+ * End of "$Id: log.c 6333 2007-03-12 20:49:13Z mike $".
  */
