@@ -1,9 +1,9 @@
 /*
- * "$Id: main.c 6090 2006-11-14 16:35:27Z mike $"
+ * "$Id: main.c 6516 2007-05-07 19:10:54Z mike $"
  *
  *   Scheduler main loop for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -32,12 +32,7 @@
  *   cupsdSetStringf()         - Set a formatted string value.
  *   launchd_checkin()         - Check-in with launchd and collect the
  *                               listening fds.
- *   launchd_create_dict()     - Create a dictionary representing the launchd
- *			         config file org.cups.cupsd.plist.
- *   launchd_reload()          - Tell launchd to reload the configuration
- *                               file to pick up the new listening directives.
- *   launchd_sync_conf()       - Re-write the launchd config file
- *			         org.cups.cupsd.plist based on cupsd.conf.
+ *   launchd_checkout()        - Check-out with launchd.
  *   parent_handler()          - Catch USR1/CHLD signals...
  *   process_children()        - Process all dead children...
  *   sigchld_handler()         - Handle 'child' signals from old processes.
@@ -62,6 +57,17 @@
 #ifdef HAVE_LAUNCH_H
 #  include <launch.h>
 #  include <libgen.h>
+#  define CUPS_KEEPALIVE	CUPS_CACHEDIR "/org.cups.cupsd"
+					/* Name of the launchd KeepAlive file */
+#  ifndef LAUNCH_JOBKEY_KEEPALIVE
+#    define LAUNCH_JOBKEY_KEEPALIVE "KeepAlive"
+#  endif /* !LAUNCH_JOBKEY_KEEPALIVE */
+#  ifndef LAUNCH_JOBKEY_PATHSTATE
+#    define LAUNCH_JOBKEY_PATHSTATE "PathState"
+#  endif /* !LAUNCH_JOBKEY_PATHSTATE */
+#  ifndef LAUNCH_JOBKEY_SERVICEIPC
+#    define LAUNCH_JOBKEY_SERVICEIPC "ServiceIPC"
+#  endif /* !LAUNCH_JOBKEY_SERVICEIPC */
 #endif /* HAVE_LAUNCH_H */
 
 #if defined(HAVE_MALLOC_H) && defined(HAVE_MALLINFO)
@@ -78,9 +84,7 @@
 
 #ifdef HAVE_LAUNCHD
 static void		launchd_checkin(void);
-static CFDictionaryRef	launchd_create_dict(void);
-static void		launchd_reload(void);
-static int		launchd_sync_conf(void);
+static void		launchd_checkout(void);
 #endif /* HAVE_LAUNCHD */
 static void		parent_handler(int sig);
 static void		process_children(void);
@@ -106,13 +110,6 @@ static int		dead_children = 0;
 static int		stop_scheduler = 0;
 					/* Should the scheduler stop? */
 
-#ifdef HAVE_LAUNCHD
-static CFURLRef		launchd_conf_url = NULL;
-					/* org.cups.cupsd.plist url */
-static CFDictionaryRef	launchd_conf_dict = NULL;
-					/* org.cups.cupsd.plist dict */
-#endif /* HAVE_LAUNCHD */
-
 
 /*
  * 'main()' - Main entry for the CUPS scheduler.
@@ -351,7 +348,7 @@ main(int  argc,				/* I - Number of command-line args */
 
     getrlimit(RLIMIT_NOFILE, &limit);
 
-    for (i = 0; i < limit.rlim_cur; i ++)
+    for (i = 0; i < limit.rlim_cur && i < 1024; i ++)
       close(i);
 #endif /* DEBUG */
   }
@@ -415,23 +412,9 @@ main(int  argc,				/* I - Number of command-line args */
   if (Launchd)
   {
    /*
-    * If we were started by launchd make sure the cupsd plist file contains the
-    * same listeners as cupsd.conf; If it didn't then reload it before getting
-    * the list of listening file descriptors...
+    * If we were started by launchd get the listen sockets file descriptors...
     */
 
-    if (launchd_sync_conf())
-    {
-      launchd_reload();
-
-     /*
-      * Until rdar://3854821 is fixed we have to exit after the reload...
-      */
-
-      cupsdLogMessage(CUPSD_LOG_DEBUG2, "Exiting on launchd_reload");
-      exit(0);
-    }
-
     launchd_checkin();
   }
 #endif /* HAVE_LAUNCHD */
@@ -632,18 +615,9 @@ main(int  argc,				/* I - Number of command-line args */
 #if HAVE_LAUNCHD
 	if (Launchd)
 	{
-	  if (launchd_sync_conf())
-	  {
-	    launchd_reload();
-
-	   /*
-	    * Until rdar://3854821 is fixed we have to exit after the reload...
-	    */
-
-	    cupsdLogMessage(CUPSD_LOG_DEBUG2, "Exiting on launchd_reload");
-	    stop_scheduler = 1;
-	    break;
-	  }
+	 /*
+	  * If we were started by launchd get the listen sockets file descriptors...
+	  */
 
 	  launchd_checkin();
 	}
@@ -679,8 +653,10 @@ main(int  argc,				/* I - Number of command-line args */
     */
 
     if (timeout.tv_sec == 86400 && Launchd && LaunchdTimeout && !NumPolled &&
-	(!Browsing || !(BrowseLocalProtocols & BROWSE_DNSSD) ||
-	 cupsArrayCount(Printers) == 0))
+	(!Browsing || 
+	 (!BrowseRemoteProtocols && 
+	  (!NumBrowsers || !BrowseLocalProtocols ||
+	   cupsArrayCount(Printers) == 0))))
     {
       timeout.tv_sec    = LaunchdTimeout;
       launchd_idle_exit = 1;
@@ -1111,16 +1087,11 @@ main(int  argc,				/* I - Number of command-line args */
 
 #ifdef HAVE_LAUNCHD
  /*
-  * Update the launchd config file as needed...
+  * Update the launchd KeepAlive file as needed...
   */
 
-  launchd_sync_conf();
-
-  if (launchd_conf_url)
-    CFRelease(launchd_conf_url);
-
-  if (launchd_conf_dict)
-    CFRelease(launchd_conf_dict);
+  if (Launchd)
+    launchd_checkout();
 #endif /* HAVE_LAUNCHD */
 
 #ifdef __sgi
@@ -1364,6 +1335,8 @@ launchd_checkin(void)
   cupsd_listener_t	*lis;		/* Listeners array */
   http_addr_t		addr;		/* Address variable */
   socklen_t		addrlen;	/* Length of address */
+  int			fd;		/* File descriptor */
+  char			s[256];		/* String addresss */
 
 
   cupsdLogMessage(CUPSD_LOG_DEBUG, "launchd_checkin: pid=%d", (int)getpid());
@@ -1417,56 +1390,77 @@ launchd_checkin(void)
 
   if (launch_data_get_type(ld_array) == LAUNCH_DATA_ARRAY)
   {
-   /*
-    * Free the listeners array built from cupsd.conf...
-    */
-
-    cupsdDeleteAllListeners();
-
-   /*
-    * Create a new array of listeners from the launchd data...
-    */
-
-    Listeners = cupsArrayNew(NULL, NULL);
-    count     = launch_data_array_get_count(ld_array);
+    count = launch_data_array_get_count(ld_array);
 
     for (i = 0; i < count; i ++)
     {
      /*
-      * Copy the current address and log it...
+      * Get the launchd file descriptor and address...
       */
 
-      if ((lis = calloc(1, sizeof(cupsd_listener_t))) == NULL)
-      {
-	cupsdLogMessage(CUPSD_LOG_ERROR,
-                	"launchd_checkin: Unable to allocate listener - %s.",
-                	strerror(errno));
-	exit(EXIT_FAILURE);
-      }
-
-      cupsArrayAdd(Listeners, lis);
-
       tmp     = launch_data_array_get_index(ld_array, i);
-      lis->fd = launch_data_get_fd(tmp);
-      addrlen = sizeof(lis->address);
+      fd      = launch_data_get_fd(tmp);
+      addrlen = sizeof(addr);
 
-      if (getsockname(lis->fd, (struct sockaddr *)&(lis->address), &addrlen))
+      if (getsockname(fd, (struct sockaddr *)&addr, &addrlen))
       {
 	cupsdLogMessage(CUPSD_LOG_ERROR,
 	                "launchd_checkin: Unable to get local address - %s",
 			strerror(errno));
+	continue;
       }
 
+     /*
+      * Try to match the launchd socket address to one of the listeners...
+      */
+
+      for (lis = (cupsd_listener_t *)cupsArrayFirst(Listeners);
+	   lis;
+	   lis = (cupsd_listener_t *)cupsArrayNext(Listeners))
+	if (httpAddrEqual(&lis->address, &addr))
+	  break;
+
+     /*
+      * Add a new listener If there's no match...
+      */
+
+      if (lis)
+      {
+	cupsdLogMessage(CUPSD_LOG_DEBUG, 
+		"launchd_checkin: Matched existing listener %s with fd %d...",
+		httpAddrString(&(lis->address), s, sizeof(s)), fd);
+      }
+      else
+      {
+	cupsdLogMessage(CUPSD_LOG_DEBUG, 
+		"launchd_checkin: Adding new listener %s with fd %d...",
+		httpAddrString(&addr, s, sizeof(s)), fd);
+
+        if ((lis = calloc(1, sizeof(cupsd_listener_t))) == NULL)
+        {
+	  cupsdLogMessage(CUPSD_LOG_ERROR,
+               	          "launchd_checkin: Unable to allocate listener - %s.",
+                	  strerror(errno));
+	  exit(EXIT_FAILURE);
+        }
+
+        cupsArrayAdd(Listeners, lis);
+
+	memcpy(&lis->address, &addr, sizeof(lis->address));
+      }
+
+      lis->fd = fd;
+
 #  ifdef HAVE_SSL
       portnum = 0;
 
 #    ifdef AF_INET6
-      if (addr.addr.sa_family == AF_INET6)
-	portnum = ntohs(addr.ipv6.sin6_port);
+      if (lis->address.addr.sa_family == AF_INET6)
+	portnum = ntohs(lis->address.ipv6.sin6_port);
       else
 #    endif /* AF_INET6 */
-      if (addr.addr.sa_family == AF_INET)
-	portnum = ntohs(addr.ipv4.sin_port);
+      if (lis->address.addr.sa_family == AF_INET)
+	portnum = ntohs(lis->address.ipv4.sin_port);
 
       if (portnum == 443)
 	lis->encryption = HTTP_ENCRYPT_ALWAYS;
@@ -1474,458 +1468,45 @@ launchd_checkin(void)
     }
   }
 
- /*
-  * Collect the browse socket (if there is one)...
-  */
-
-  if ((ld_array = launch_data_dict_lookup(ld_sockets, "BrowseSockets")))
-  {
-    if (launch_data_get_type(ld_array) == LAUNCH_DATA_ARRAY)
-    {
-      if ((tmp = launch_data_array_get_index(ld_array, 0)))
-      {
-	if (launch_data_get_type(tmp) == LAUNCH_DATA_FD)
-	{
-	  if (BrowseSocket != -1)
-	    close(BrowseSocket);
-
-	  BrowseSocket = launch_data_get_fd(tmp);
-	}
-	else
-	  cupsdLogMessage(CUPSD_LOG_WARN,
-			  "launchd_checkin: BrowseSocket not a fd!");
-     }
-     else
-       cupsdLogMessage(CUPSD_LOG_WARN,
-		       "launchd_checkin: BrowseSockets is an empty array!");
-   }
-   else
-     cupsdLogMessage(CUPSD_LOG_WARN,
-                     "launchd_checkin: BrowseSockets is not an array!");
-  }
-  else
-    cupsdLogMessage(CUPSD_LOG_DEBUG, "launchd_checkin: No BrowseSockets");
-
   launch_data_free(ld_msg);
   launch_data_free(ld_resp);
 }
 
 
 /*
- * 'launchd_create_dict()' - Create a dictionary representing the launchd
- *			     config file org.cups.cupsd.plist.
- */
-
-static CFDictionaryRef			/* O - CFDictionary */
-launchd_create_dict(void)
-{
-  int			  portnum;	/* Port number */
-  bool			  runatload;	/* Run at load? */
-  CFMutableDictionaryRef  cupsd_dict,	/* org.cups.cupsd.plist dictionary */
-			  sockets,	/* Sockets dictionary */
-			  listener;	/* Listener dictionary */
-  CFMutableArrayRef	  array;	/* Array */
-  CFNumberRef		  socket_mode;	/* Domain socket mode bits */
-  CFStringRef		  socket_path;	/* Domain socket path */
-  CFTypeRef		  value;	/* CF values */
-  cupsd_listener_t	  *lis;		/* Current listening socket */
-  struct servent	  *service;	/* Services data base entry */
-  char			  temp[1024];	/* Temporary buffer for value */
-
-
-  if ((cupsd_dict = CFDictionaryCreateMutable(kCFAllocatorDefault, 0,
-				&kCFTypeDictionaryKeyCallBacks,
-				&kCFTypeDictionaryValueCallBacks)) == NULL)
-    return NULL;
-
-  CFDictionaryAddValue(cupsd_dict, CFSTR(LAUNCH_JOBKEY_LABEL),
-		       CFSTR("org.cups.cupsd"));
-  CFDictionaryAddValue(cupsd_dict, CFSTR(LAUNCH_JOBKEY_ONDEMAND),
-		       kCFBooleanTrue);
-
- /*
-  * Run-at-load if there are active jobs, polling or shared printers
-  * to advertise...
-  */
-  
-  runatload = (cupsArrayCount(ActiveJobs) || NumPolled || 
-	       (Browsing && BrowseLocalProtocols && 
-	        NumBrowsers && cupsArrayCount(Printers))) ? true : false;
-
-  CFDictionaryAddValue(cupsd_dict, CFSTR(LAUNCH_JOBKEY_RUNATLOAD),
-		       runatload ? kCFBooleanTrue : kCFBooleanFalse);
-#  ifdef LAUNCH_JOBKEY_SERVICEIPC
-  CFDictionaryAddValue(cupsd_dict, CFSTR(LAUNCH_JOBKEY_SERVICEIPC),
-		       kCFBooleanTrue);
-#  endif /* LAUNCH_JOBKEY_SERVICEIPC */
-
-  if ((array = CFArrayCreateMutable(kCFAllocatorDefault, 2,
-				    &kCFTypeArrayCallBacks)) != NULL)
-  {
-    CFDictionaryAddValue(cupsd_dict, CFSTR(LAUNCH_JOBKEY_PROGRAMARGUMENTS),
-			 array);
-    CFArrayAppendValue(array, CFSTR("/usr/sbin/cupsd"));
-    CFArrayAppendValue(array, CFSTR("-l"));
-    CFRelease(array);
-  }
-
- /*
-  * Add a sockets dictionary...
-  */
-
-  if ((sockets = (CFMutableDictionaryRef)CFDictionaryCreateMutable(
-			      kCFAllocatorDefault, 0,
-			      &kCFTypeDictionaryKeyCallBacks,
-			      &kCFTypeDictionaryValueCallBacks)) != NULL)
-  {
-    CFDictionaryAddValue(cupsd_dict, CFSTR(LAUNCH_JOBKEY_SOCKETS), sockets);
-
-   /*
-    * Add a Listeners array to the sockets dictionary...
-    */
-
-    if ((array = CFArrayCreateMutable(kCFAllocatorDefault, 0,
-				      &kCFTypeArrayCallBacks)) != NULL)
-    {
-      CFDictionaryAddValue(sockets, CFSTR("Listeners"), array);
-
-     /*
-      * For each listener add a dictionary to the listeners array...
-      */
-
-      for (lis = (cupsd_listener_t *)cupsArrayFirst(Listeners);
-	   lis;
-	   lis = (cupsd_listener_t *)cupsArrayNext(Listeners))
-      {
-	if ((listener = CFDictionaryCreateMutable(kCFAllocatorDefault, 0,
-			      &kCFTypeDictionaryKeyCallBacks,
-			      &kCFTypeDictionaryValueCallBacks)) != NULL)
-	{
-	  CFArrayAppendValue(array, listener);
-
-#  ifdef AF_LOCAL
-	  if (lis->address.addr.sa_family == AF_LOCAL)
-	  {
-	    if ((socket_path = CFStringCreateWithCString(kCFAllocatorDefault,
-				      lis->address.un.sun_path,
-				      kCFStringEncodingUTF8)))
-	    {
-	      CFDictionaryAddValue(listener,
-				   CFSTR(LAUNCH_JOBSOCKETKEY_PATHNAME),
-				   socket_path);
-	      CFRelease(socket_path);
-	    }
-	    portnum = 0140777; /* (S_IFSOCK|S_IRWXU|S_IRWXG|S_IRWXO) or *
-				* 49663d decimal                        */
-	    if ((socket_mode = CFNumberCreate(kCFAllocatorDefault,
-					      kCFNumberIntType, &portnum)))
-	    {
-	      CFDictionaryAddValue(listener, CFSTR("SockPathMode"),
-				   socket_mode);
-	      CFRelease(socket_mode);
-	    }
-	  }
-	  else
-#  endif /* AF_LOCAL */
-	  {
-#  ifdef AF_INET6
-	    if (lis->address.addr.sa_family == AF_INET6)
-	    {
-	      CFDictionaryAddValue(listener,
-				   CFSTR(LAUNCH_JOBSOCKETKEY_FAMILY),
-				   CFSTR("IPv6"));
-	      portnum = lis->address.ipv6.sin6_port;
-	    }
-	    else
-#  endif /* AF_INET6 */
-	    {
-	      CFDictionaryAddValue(listener,
-				   CFSTR(LAUNCH_JOBSOCKETKEY_FAMILY),
-				   CFSTR("IPv4"));
-	      portnum = lis->address.ipv4.sin_port;
-	    }
-
-	    if ((service = getservbyport(portnum, NULL)))
-	      value = CFStringCreateWithCString(kCFAllocatorDefault,
-						service->s_name,
-						kCFStringEncodingUTF8);
-	    else
-	      value = CFNumberCreate(kCFAllocatorDefault,
-				     kCFNumberIntType, &portnum);
-
-	    if (value)
-	    {
-	      CFDictionaryAddValue(listener,
-				   CFSTR(LAUNCH_JOBSOCKETKEY_SERVICENAME),
-				   value);
-	      CFRelease(value);
-	    }	
-
-	    httpAddrString(&lis->address, temp, sizeof(temp));
-	    if ((value = CFStringCreateWithCString(kCFAllocatorDefault, temp,
-						   kCFStringEncodingUTF8)))
-	    {
-	      CFDictionaryAddValue(listener,
-				   CFSTR(LAUNCH_JOBSOCKETKEY_NODENAME),
-				   value);
-	      CFRelease(value);
-	    }
-	  }
-
-	  CFRelease(listener);
-	}
-      }
-
-      CFRelease(array);
-    }
-
-   /*
-    * Add the BrowseSocket to the sockets dictionary...
-    */
-
-    if (Browsing && (BrowseRemoteProtocols & BROWSE_CUPS))
-    {
-      if ((array = CFArrayCreateMutable(kCFAllocatorDefault, 0,
-					&kCFTypeArrayCallBacks)) != NULL)
-      {
-	CFDictionaryAddValue(sockets, CFSTR("BrowseSockets"), array);
-
-	if ((listener = CFDictionaryCreateMutable(kCFAllocatorDefault, 0,
-				&kCFTypeDictionaryKeyCallBacks,
-				&kCFTypeDictionaryValueCallBacks)) != NULL)
-	{
-	  CFArrayAppendValue(array, listener);
-
-	  CFDictionaryAddValue(listener, CFSTR(LAUNCH_JOBSOCKETKEY_FAMILY),
-			       CFSTR("IPv4"));
-	  CFDictionaryAddValue(listener, CFSTR(LAUNCH_JOBSOCKETKEY_TYPE),
-			       CFSTR("dgram"));
-
-	  if ((service = getservbyport(BrowsePort, NULL)))
-	    value = CFStringCreateWithCString(kCFAllocatorDefault,
-					      service->s_name,
-					      kCFStringEncodingUTF8);
-	  else
-	    value = CFNumberCreate(kCFAllocatorDefault, kCFNumberIntType,
-				   &BrowsePort);
-
-	  CFDictionaryAddValue(listener,
-			       CFSTR(LAUNCH_JOBSOCKETKEY_SERVICENAME), value);
-	  CFRelease(value);
-
-	  CFRelease(listener);
-	}
-
-	CFRelease(array);
-      }
-    }
-
-    CFRelease(sockets);
-  }
-
-  return (cupsd_dict);
-}
-
-
-/*
- * 'launchd_reload()' - Tell launchd to reload the configuration file to pick
- *                      up the new listening directives.
+ * 'launchd_checkout()' - Update the launchd KeepAlive file as needed.
  */
 
 static void
-launchd_reload(void)
+launchd_checkout(void)
 {
-  int		child_status;		/* Exit status of child process */
-  pid_t		child_pid,		/* Child PID */
-		waitpid_status;		/* Child process exit status */
-  char		*argv[4];		/* Argument strings */
+  int	fd;				/* File descriptor */
 
 
  /*
-  * The current launchd doesn't support a reload option (rdar://3854821).
-  * Until this is fixed we need to reload the config file by execing launchctl
-  * twice (to unload then load). NOTE: This will cause us to exit on SIGTERM
-  * which will cancel all client & job activity.
-  *
-  * After this is fixed we'll be able to tell launchd to reload the file
-  * and pick up the new listening descriptors without disrupting current
-  * activity.
+  * Create or remove the launchd KeepAlive file based on whether
+  * there are active jobs, polling, browsing for remote printers or 
+  * shared printers to advertise...
   */
 
- /*
-  * Unloading the current configuration will cause launchd to send us a SIGTERM;
-  * block it for now so we can get our work done...
-  */
+  if ((cupsArrayCount(ActiveJobs) || NumPolled || 
+       (Browsing && 
+	(BrowseRemoteProtocols ||
+        (BrowseLocalProtocols && NumBrowsers && cupsArrayCount(Printers))))))
+  {
+    cupsdLogMessage(CUPSD_LOG_DEBUG,
+                    "Creating launchd keepalive file \"" CUPS_KEEPALIVE "\"...");
 
-  cupsdHoldSignals();
-
- /*
-  * Set up the unload arguments to launchctl...
-  */
-
-  argv[0] = "/bin/launchctl";
-  argv[1] = "unload";
-  argv[2] = LaunchdConf;
-  argv[3] = NULL;
-
-  if (cupsdStartProcess(argv[0], argv, NULL, -1, -1, -1, -1, 1, &child_pid) < 0)
-    cupsdLogMessage(CUPSD_LOG_ERROR,
-                    "launchd_reload: Unable to execute %s - %s", argv[0],
-                    strerror(errno));
+    if ((fd = open(CUPS_KEEPALIVE, O_RDONLY | O_CREAT | O_EXCL, S_IRUSR)) >= 0)
+      close(fd);
+  }
   else
   {
-    do
-    {
-      waitpid_status = waitpid(child_pid, &child_status, 0);
-    }
-    while (waitpid_status == (pid_t)-1 && errno == EINTR);
+    cupsdLogMessage(CUPSD_LOG_DEBUG,
+                    "Removing launchd keepalive file \"" CUPS_KEEPALIVE "\"...");
 
-    if (WIFSIGNALED(child_status))
-      cupsdLogMessage(CUPSD_LOG_DEBUG,
-                      "launchd_reload: %s pid %d crashed on signal %d!",
-		      basename(argv[0]), child_pid, WTERMSIG(child_status));
-    else
-      cupsdLogMessage(CUPSD_LOG_DEBUG,
-                      "launchd_reload: %s pid %d stopped with status %d!",
-		      basename(argv[0]), child_pid, WEXITSTATUS(child_status));
-
-   /*
-    * Do it again with the load command...
-    */
-
-    argv[1] = "load";
-
-    if (cupsdStartProcess(argv[0], argv, NULL, -1, -1, -1, -1, 1,
-                          &child_pid) < 0)
-    {
-      cupsdLogMessage(CUPSD_LOG_ERROR,
-                      "launchd_reload: Unable to fork for %s - %s", argv[0],
-                      strerror(errno));
-    }
-    else
-    {
-      do
-      {
-	waitpid_status = waitpid(child_pid, &child_status, 0);
-      } while (waitpid_status == (pid_t)-1 && errno == EINTR);
-
-      if (WIFSIGNALED(child_status))
-	cupsdLogMessage(CUPSD_LOG_DEBUG,
-	                "launchd_reload: %s pid %d crashed on signal %d!",
-			basename(argv[0]), child_pid, WTERMSIG(child_status));
-      else
-	cupsdLogMessage(CUPSD_LOG_DEBUG,
-	                "launchd_reload: %s pid %d stopped with status %d",
-			basename(argv[0]), child_pid,
-			WEXITSTATUS(child_status));
-    }
+    unlink(CUPS_KEEPALIVE);
   }
-
- /*
-  * Leave signals blocked since exit() will be called momentarily anyways...
-  */
-}
-
-
-/*
- * 'launchd_sync_conf()' - Rewrite the launchd config file
- *			   org.cups.cupsd.plist based on cupsd.conf.
- */
-
-static int				/* O - 1 if the file was updated */
-launchd_sync_conf(void)
-{
-  SInt32		errorCode;	/* Error code */
-  CFDataRef		resourceData;	/* XML property list */
-  CFDictionaryRef	cupsd_dict;	/* New org.cups.cupsd.plist dict */
-
-
- /*
-  * If needed reconstitute the existing org.cups.cupsd.plist...
-  */
-
-  if (!launchd_conf_url && 
-      !(launchd_conf_url = CFURLCreateFromFileSystemRepresentation(
-				kCFAllocatorDefault,
-				(const unsigned char *)LaunchdConf,
-				strlen(LaunchdConf), false)))
-  {
-    cupsdLogMessage(CUPSD_LOG_ERROR, "launchd_sync_conf: "
-		    "Unable to create file URL for \"%s\"\n", LaunchdConf);
-    return (0);
-  }
-
-  if (!launchd_conf_dict)
-  {
-    if (CFURLCreateDataAndPropertiesFromResource(NULL, launchd_conf_url, 
-				&resourceData, NULL, NULL, &errorCode))
-    {
-      launchd_conf_dict = CFPropertyListCreateFromXMLData(NULL, resourceData,
-					      kCFPropertyListImmutable, NULL);
-      CFRelease(resourceData);
-    }
-
-    if (!launchd_conf_dict)
-    {
-      cupsdLogMessage(CUPSD_LOG_ERROR, "launchd_sync_conf: "
-		      "Unable to create dictionary for \"%s\"\n", LaunchdConf);
-    }
-  }
-
- /*
-  * Create a new org.cups.cupsd.plist dictionary...
-  */
-
-  if ((cupsd_dict = launchd_create_dict()) == NULL)
-  {
-    cupsdLogMessage(CUPSD_LOG_ERROR, "launchd_sync_conf: "
-		    "Unable to create file URL for \"%s\"\n", LaunchdConf);
-    return (0);
-  }
-
- /*
-  * If the dictionaries are different write a new org.cups.cupsd.plist...
-  */
-
-  if (!CFEqual(cupsd_dict, launchd_conf_dict))
-  {
-    if ((resourceData = CFPropertyListCreateXMLData(kCFAllocatorDefault,
-						  cupsd_dict)))
-    {
-      if (CFURLWriteDataAndPropertiesToResource(launchd_conf_url, resourceData,
-						 NULL, &errorCode))
-      {
-       /*
-        * The new cupsd dictionary becomes the on-disk launchd dictionary...
-        */
-
-	if (launchd_conf_dict)
-	  CFRelease(launchd_conf_dict);
-
-	launchd_conf_dict = cupsd_dict;
-      }
-      else
-      {
-	cupsdLogMessage(CUPSD_LOG_WARN,
-			"launchd_sync_conf: "
-			"CFURLWriteDataAndPropertiesToResource(\"%s\") "
-			"failed: %d\n",
-			LaunchdConf, (int)errorCode);
-
-	CFRelease(cupsd_dict);
-      }
-  
-      CFRelease(resourceData);
-    }
-
-   /*
-    * Let the caller know we updated the file...
-    */
-
-    return (1);
-  }
-
-  return (0);
 }
 #endif /* HAVE_LAUNCHD */
 
@@ -2340,5 +1921,5 @@ usage(int status)			/* O - Exit status */
 
 
 /*
- * End of "$Id: main.c 6090 2006-11-14 16:35:27Z mike $".
+ * End of "$Id: main.c 6516 2007-05-07 19:10:54Z mike $".
  */
