@@ -1,9 +1,9 @@
 /*
- * "$Id: printers.c 5970 2006-09-19 20:11:08Z mike $"
+ * "$Id: printers.c 6450 2007-04-11 13:18:38Z mike $"
  *
  *   Printer routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -265,7 +265,7 @@ cupsdCreateCommonData(void)
 			*notifier;	/* Current notifier */
   static const int nups[] =		/* number-up-supported values */
 		{ 1, 2, 4, 6, 9, 16 };
-  static const ipp_orient_t orients[4] =/* orientation-requested-supported values */
+  static const int orients[4] =/* orientation-requested-supported values */
 		{
 		  IPP_PORTRAIT,
 		  IPP_LANDSCAPE,
@@ -288,7 +288,7 @@ cupsdCreateCommonData(void)
 		  "1.0",
 		  "1.1"
 		};
-  static const ipp_op_t	ops[] =		/* operations-supported values */
+  static const int	ops[] =		/* operations-supported values */
 		{
 		  IPP_PRINT_JOB,
 		  IPP_VALIDATE_JOB,
@@ -556,11 +556,11 @@ cupsdCreateCommonData(void)
   /* operations-supported */
   ippAddIntegers(CommonData, IPP_TAG_PRINTER, IPP_TAG_ENUM,
                  "operations-supported",
-                 sizeof(ops) / sizeof(ops[0]) + JobFiles - 1, (int *)ops);
+                 sizeof(ops) / sizeof(ops[0]) + JobFiles - 1, ops);
 
   /* orientation-requested-supported */
   ippAddIntegers(CommonData, IPP_TAG_PRINTER, IPP_TAG_ENUM,
-                 "orientation-requested-supported", 4, (int *)orients);
+                 "orientation-requested-supported", 4, orients);
 
   /* page-ranges-supported */
   ippAddBoolean(CommonData, IPP_TAG_PRINTER, "page-ranges-supported", 1);
@@ -1187,7 +1187,20 @@ cupsdLoadAllPrinters(void)
     else if (!strcasecmp(line, "OpPolicy"))
     {
       if (value)
-        cupsdSetString(&p->op_policy, value);
+      {
+        cupsd_policy_t *pol;		/* Policy */
+
+
+        if ((pol = cupsdFindPolicy(value)) != NULL)
+	{
+          cupsdSetString(&p->op_policy, value);
+	  p->op_policy_ptr = pol;
+	}
+	else
+	  cupsdLogMessage(CUPSD_LOG_ERROR,
+	                  "Bad policy \"%s\" on line %d of printers.conf",
+			  value, linenum);
+      }
       else
       {
 	cupsdLogMessage(CUPSD_LOG_ERROR,
@@ -1286,6 +1299,7 @@ cupsdSaveAllPrinters(void)
   time_t		curtime;	/* Current time */
   struct tm		*curdate;	/* Current date */
   cups_option_t		*option;	/* Current option */
+  const char		*ptr;		/* Pointer into info/location */
 
 
  /*
@@ -1360,11 +1374,40 @@ cupsdSaveAllPrinters(void)
       cupsFilePrintf(fp, "<Printer %s>\n", printer->name);
 
     if (printer->info)
-      cupsFilePrintf(fp, "Info %s\n", printer->info);
+    {
+      if ((ptr = strchr(printer->info, '#')) != NULL)
+      {
+       /*
+        * Need to quote the first # in the info string...
+	*/
+
+        cupsFilePuts(fp, "Info ");
+	cupsFileWrite(fp, printer->info, ptr - printer->info);
+	cupsFilePutChar(fp, '\\');
+	cupsFilePuts(fp, ptr);
+	cupsFilePutChar(fp, '\n');
+      }
+      else
+        cupsFilePrintf(fp, "Info %s\n", printer->info);
+    }
 
     if (printer->location)
-      cupsFilePrintf(fp, "Location %s\n", printer->location);
+    {
+      if ((ptr = strchr(printer->info, '#')) != NULL)
+      {
+       /*
+        * Need to quote the first # in the location string...
+	*/
 
+        cupsFilePuts(fp, "Location ");
+	cupsFileWrite(fp, printer->location, ptr - printer->location);
+	cupsFilePutChar(fp, '\\');
+	cupsFilePuts(fp, ptr);
+	cupsFilePutChar(fp, '\n');
+      }
+      else
+        cupsFilePrintf(fp, "Location %s\n", printer->location);
+    }
     if (printer->device_uri)
       cupsFilePrintf(fp, "DeviceURI %s\n", printer->device_uri);
 
@@ -1454,7 +1497,7 @@ cupsdSetPrinterAttrs(cupsd_printer_t *p)/* I - Printer to setup */
   ipp_attribute_t *attr;		/* Attribute data */
   ipp_value_t	*val;			/* Attribute value */
   int		num_finishings;		/* Number of finishings */
-  ipp_finish_t	finishings[5];		/* finishings-supported values */
+  int		finishings[5];		/* finishings-supported values */
   cups_option_t	*option;		/* Current printer option */
   static const char * const sides[3] =	/* sides-supported values */
 		{
@@ -2051,7 +2094,7 @@ cupsdSetPrinterAttrs(cupsd_printer_t *p)/* I - Printer to setup */
       }
 
       ippAddIntegers(p->attrs, IPP_TAG_PRINTER, IPP_TAG_ENUM,
-                     "finishings-supported", num_finishings, (int *)finishings);
+                     "finishings-supported", num_finishings, finishings);
       ippAddInteger(p->attrs, IPP_TAG_PRINTER, IPP_TAG_ENUM,
                     "finishings-default", IPP_FINISHINGS_NONE);
     }
@@ -3327,5 +3370,5 @@ write_irix_state(cupsd_printer_t *p)	/* I - Printer to update */
 
 
 /*
- * End of "$Id: printers.c 5970 2006-09-19 20:11:08Z mike $".
+ * End of "$Id: printers.c 6450 2007-04-11 13:18:38Z mike $".
  */
