@@ -1,9 +1,9 @@
 /*
- * "$Id: subscriptions.c 5878 2006-08-24 15:55:42Z mike $"
+ * "$Id: subscriptions.c 6448 2007-04-10 18:24:19Z mike $"
  *
  *   Subscription routines for the Common UNIX Printing System (CUPS) scheduler.
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -50,6 +50,11 @@
 #include "cupsd.h"
 #ifdef HAVE_DBUS
 #  include <dbus/dbus.h>
+#  ifdef HAVE_DBUS_MESSAGE_ITER_INIT_APPEND
+#    define dbus_message_append_iter_init dbus_message_iter_init_append
+#    define dbus_message_iter_append_string(i,v) dbus_message_iter_append_basic(i, DBUS_TYPE_STRING, &(v))
+#    define dbus_message_iter_append_uint32(i,v) dbus_message_iter_append_basic(i, DBUS_TYPE_UINT32, &(v))
+#  endif /* HAVE_DBUS_MESSAGE_ITER_INIT_APPEND */
 #endif /* HAVE_DBUS */
 
 
@@ -1355,13 +1360,13 @@ cupsd_send_dbus(cupsd_eventmask_t event,/* I - Event to send */
   message = dbus_message_new_signal("/com/redhat/PrinterSpooler",
 				    "com.redhat.PrinterSpooler", what);
 
-  dbus_message_iter_init_append(message, &iter);
+  dbus_message_append_iter_init(message, &iter);
   if (dest)
-    dbus_message_iter_append_basic(&iter, DBUS_TYPE_STRING, &(dest->name));
+    dbus_message_iter_append_string(&iter, dest->name);
   if (job)
   {
-    dbus_message_iter_append_basic(&iter, DBUS_TYPE_UINT32, &(job->id));
-    dbus_message_iter_append_basic(&iter, DBUS_TYPE_STRING, &(job->username));
+    dbus_message_iter_append_uint32(&iter, job->id);
+    dbus_message_iter_append_string(&iter, job->username);
   }
 
   dbus_connection_send(con, message, NULL);
@@ -1622,5 +1627,5 @@ cupsd_start_notifier(
 
 
 /*
- * End of "$Id: subscriptions.c 5878 2006-08-24 15:55:42Z mike $".
+ * End of "$Id: subscriptions.c 6448 2007-04-10 18:24:19Z mike $".
  */
