@@ -1,5 +1,5 @@
 /*
- * "$Id: testspeed.c,v 1.11 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: testspeed.c 5305 2006-03-18 03:05:12Z mike $"
  *
  *   Scheduler speed test for the Common UNIX Printing System (CUPS).
  *
@@ -23,8 +23,10 @@
  *
  * Contents:
  *
- *   main() - Send multiple IPP requests and report on the average response
- *            time.
+ *   main()    - Send multiple IPP requests and report on the average response
+ *               time.
+ *   do_test() - Run a test on a specific host...
+ *   usage()   - Show program usage...
  */
 
 /*
@@ -47,9 +49,9 @@
  * Local functions...
  */
 
-int	do_test(const char *server, http_encryption_t encryption,
-		int requests);
-void	usage(void);
+static int	do_test(const char *server, http_encryption_t encryption,
+			int requests, int verbose);
+static void	usage(void);
 
 
 /*
@@ -71,6 +73,7 @@ main(int  argc,				/* I - Number of command-line arguments */
   time_t	start,			/* Start time */
 		end;			/* End time */
   double	elapsed;		/* Elapsed time */
+  int		verbose;		/* Verbosity */
 
 
  /*
@@ -81,6 +84,7 @@ main(int  argc,				/* I - Number of command-line arguments */
   children   = 5;
   server     = cupsServer();
   encryption = HTTP_ENCRYPT_IF_REQUESTED;
+  verbose    = 0;
 
   for (i = 1; i < argc; i ++)
     if (!strcmp(argv[i], "-c"))
@@ -101,6 +105,8 @@ main(int  argc,				/* I - Number of command-line arguments */
     }
     else if (!strcmp(argv[i], "-E"))
       encryption = HTTP_ENCRYPT_REQUIRED;
+    else if (!strcmp(argv[i], "-v"))
+      verbose ++;
     else if (argv[i][0] == '-')
       usage();
     else
@@ -116,35 +122,42 @@ main(int  argc,				/* I - Number of command-line arguments */
 
   start = time(NULL);
 
-  for (i = 0; i < children; i ++)
-    if ((pid = fork()) == 0)
-    {
-     /*
-      * Child goes here...
-      */
-
-      exit(do_test(server, encryption, requests));
-    }
-    else if (pid < 0)
-    {
-      perror("fork failed");
-      break;
-    }
-    else
-      printf("testspeed(%d): Started...\n", pid);
-
- /*
-  * Wait for children to finish...
-  */
-
-  for (;;)
+  if (children == 1)
   {
-    pid = wait(&status);
+    do_test(server, encryption, requests, verbose);
+  }
+  else
+  {
+    for (i = 0; i < children; i ++)
+      if ((pid = fork()) == 0)
+      {
+       /*
+	* Child goes here...
+	*/
 
-    if (pid < 0 && errno != EINTR)
-      break;
+	exit(do_test(server, encryption, requests, verbose));
+      }
+      else if (pid < 0)
+      {
+	perror("fork failed");
+	break;
+      }
+      else
+	printf("testspeed(%d): Started...\n", pid);
 
-    printf("testspeed(%d): Ended (%d)...\n", pid, status);
+   /*
+    * Wait for children to finish...
+    */
+
+    for (;;)
+    {
+      pid = wait(&status);
+
+      if (pid < 0 && errno != EINTR)
+	break;
+
+      printf("testspeed(%d): Ended (%d)...\n", pid, status);
+    }
   }
 
  /*
@@ -170,10 +183,11 @@ main(int  argc,				/* I - Number of command-line arguments */
  * 'do_test()' - Run a test on a specific host...
  */
 
-int					/* O - Exit status */
+static int				/* O - Exit status */
 do_test(const char        *server,	/* I - Server to use */
         http_encryption_t encryption,	/* I - Encryption to use */
-	int               requests)	/* I - Number of requests to send */
+	int               requests,	/* I - Number of requests to send */
+	int               verbose)	/* I - Verbose output? */
 {
   int		i;			/* Looping var */
   http_t	*http;			/* Connection to server */
@@ -212,8 +226,9 @@ do_test(const char        *server,	/* I - Server to use */
 
   for (elapsed = 0.0, i = 0; i < requests; i ++)
   {
-    if ((i % 10) == 0)
-      printf("testspeed(%d): %d%% complete...\n", getpid(), i * 100 / requests);
+    if (verbose && (i % 10) == 0)
+      printf("testspeed(%d): %d%% complete...\n", (int)getpid(),
+             i * 100 / requests);
 
    /*
     * Build a request which requires the following attributes:
@@ -268,7 +283,7 @@ do_test(const char        *server,	/* I - Server to use */
   httpClose(http);
 
   printf("testspeed(%d): %d requests in %.1fs (%.3fs/r, %.1fr/s)\n",
-         getpid(), i, elapsed, elapsed / i, i / elapsed);
+         (int)getpid(), i, elapsed, elapsed / i, i / elapsed);
 
   return (0);
 }
@@ -278,15 +293,15 @@ do_test(const char        *server,	/* I - Server to use */
  * 'usage()' - Show program usage...
  */
 
-void
+static void
 usage(void)
 {
-  puts("Usage: testspeed [-c children] [-h] [-r requests] [-E] hostname");
+  puts("Usage: testspeed [-c children] [-h] [-r requests] [-v] [-E] hostname");
   exit(0);
 }
 
 
 
 /*
- * End of "$Id: testspeed.c,v 1.11 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: testspeed.c 5305 2006-03-18 03:05:12Z mike $".
  */
