@@ -1,10 +1,10 @@
 /*
- * "$Id: accept.c,v 1.21 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: accept.c 5926 2006-09-05 20:45:47Z mike $"
  *
  *   "accept", "disable", "enable", and "reject" commands for the Common
  *   UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -33,34 +33,33 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
-
-#include <config.h>
-#include <cups/cups.h>
+#include <errno.h>
 #include <cups/string.h>
-#include <cups/language.h>
+#include <cups/cups.h>
+#include <cups/i18n.h>
 
 
 /*
  * 'main()' - Parse options and accept/reject jobs or disable/enable printers.
  */
 
-int				/* O - Exit status */
-main(int  argc,			/* I - Number of command-line arguments */
-     char *argv[])		/* I - Command-line arguments */
+int					/* O - Exit status */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  http_t	*http;		/* HTTP connection to server */
-  int		i;		/* Looping var */
-  char		*command,	/* Command to do */
-		uri[1024],	/* Printer URI */
-		*reason;	/* Reason for reject/disable */
-  ipp_t		*request;	/* IPP request */
-  ipp_t		*response;	/* IPP response */
-  ipp_op_t	op;		/* Operation */
-  cups_lang_t	*language;	/* Language */
-  int		cancel;		/* Cancel jobs? */
+  http_t	*http;			/* HTTP connection to server */
+  int		i;			/* Looping var */
+  char		*command,		/* Command to do */
+		uri[1024],		/* Printer URI */
+		*reason;		/* Reason for reject/disable */
+  ipp_t		*request;		/* IPP request */
+  ipp_t		*response;		/* IPP response */
+  ipp_op_t	op;			/* Operation */
+  int		cancel;			/* Cancel jobs? */
 
 
+  _cupsSetLocale(argv);
+
  /*
   * See what operation we're supposed to do...
   */
@@ -72,17 +71,18 @@ main(int  argc,			/* I - Number of command-line arguments */
 
   cancel = 0;
 
-  if (strcmp(command, "accept") == 0)
+  if (!strcmp(command, "accept"))
     op = CUPS_ACCEPT_JOBS;
-  else if (strcmp(command, "reject") == 0)
+  else if (!strcmp(command, "reject"))
     op = CUPS_REJECT_JOBS;
-  else if (strcmp(command, "disable") == 0)
+  else if (!strcmp(command, "cupsdisable") || !strcmp(command, "disable"))
     op = IPP_PAUSE_PRINTER;
-  else if (strcmp(command, "enable") == 0)
+  else if (!strcmp(command, "cupsenable") || !strcmp(command, "enable"))
     op = IPP_RESUME_PRINTER;
   else
   {
-    fprintf(stderr, "%s: Don't know what to do!\n", command);
+    _cupsLangPrintf(stderr, _("%s: Don't know what to do!\n"),
+                    command);
     return (1);
   }
 
@@ -104,11 +104,31 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    if (http)
 	      httpEncryption(http, HTTP_ENCRYPT_REQUIRED);
 #else
-            fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
-	            command);
+            _cupsLangPrintf(stderr,
+	                    _("%s: Sorry, no encryption support compiled in!\n"),
+	        	    command);
 #endif /* HAVE_SSL */
 	    break;
 
+        case 'U' : /* Username */
+	    if (argv[i][2] != '\0')
+	      cupsSetUser(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected username after "
+				  "\'-U\' option!\n"),
+		        	command);
+	        return (1);
+	      }
+
+              cupsSetUser(argv[i]);
+	    }
+	    break;
+	    
         case 'c' : /* Cancel jobs */
 	    cancel = 1;
 	    break;
@@ -124,8 +144,10 @@ main(int  argc,			/* I - Number of command-line arguments */
 	      i ++;
 	      if (i >= argc)
 	      {
-	        fprintf(stderr, "%s: Expected server name after -h!\n",
-		        command);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected hostname after "
+				  "\'-h\' option!\n"),
+		        	command);
 	        return (1);
 	      }
 
@@ -141,7 +163,10 @@ main(int  argc,			/* I - Number of command-line arguments */
 	      i ++;
 	      if (i >= argc)
 	      {
-	        fprintf(stderr, "%s: Expected reason text after -r!\n", command);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected reason text after "
+				  "\'-r\' option!\n"),
+				command);
 		return (1);
 	      }
 
@@ -150,8 +175,8 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    break;
 
 	default :
-	    fprintf(stderr, "%s: Unknown option \'%c\'!\n", command,
-	            argv[i][1]);
+	    _cupsLangPrintf(stderr, _("%s: Error - unknown option \'%c\'!\n"),
+	                    command, argv[i][1]);
 	    return (1);
       }
     else
@@ -165,8 +190,9 @@ main(int  argc,			/* I - Number of command-line arguments */
 
       if (http == NULL)
       {
-	fputs(command, stderr);
-	perror(": Unable to connect to server");
+	_cupsLangPrintf(stderr,
+	                _("%s: Unable to connect to server: %s\n"),
+	                command, strerror(errno));
 	return (1);
       }
 
@@ -180,23 +206,16 @@ main(int  argc,			/* I - Number of command-line arguments */
       *    printer-state-message [optional]
       */
 
-      request = ippNew();
+      request = ippNewRequest(op);
 
-      request->request.op.operation_id = op;
-      request->request.op.request_id   = 1;
-
-      language = cupsLangDefault();
-
-      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-              	   "attributes-charset", NULL, cupsLangEncoding(language));
-
-      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-                   "attributes-natural-language", NULL, language->language);
-
-      snprintf(uri, sizeof(uri), "ipp://localhost/printers/%s", argv[i]);
+      httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
+                       "localhost", 0, "/printers/%s", argv[i]);
       ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
                    "printer-uri", NULL, uri);
 
+      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_NAME,
+                   "requesting-user-name", NULL, cupsUser());
+
       if (reason != NULL)
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_TEXT,
                      "printer-state-message", NULL, reason);
@@ -209,8 +228,9 @@ main(int  argc,			/* I - Number of command-line arguments */
       {
         if (response->request.status.status_code > IPP_OK_CONFLICT)
 	{
-          fprintf(stderr, "%s: Operation failed: %s\n", command,
-	          ippErrorString(cupsLastError()));
+          _cupsLangPrintf(stderr,
+	                  _("%s: Operation failed: %s\n"),
+			  command, ippErrorString(cupsLastError()));
 	  return (1);
 	}
 	
@@ -218,8 +238,7 @@ main(int  argc,			/* I - Number of command-line arguments */
       }
       else
       {
-        fprintf(stderr, "%s: Operation failed: %s\n", command,
-	        ippErrorString(cupsLastError()));
+        _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
 	return (1);
       }
 
@@ -238,18 +257,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 	*    printer-uri
 	*/
 
-	request = ippNew();
-
-	request->request.op.operation_id = IPP_PURGE_JOBS;
-	request->request.op.request_id   = 1;
-
-	language = cupsLangDefault();
-
-	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-              	     "attributes-charset", NULL, cupsLangEncoding(language));
-
-	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-                     "attributes-natural-language", NULL, language->language);
+	request = ippNewRequest(IPP_PURGE_JOBS);
 
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
                      "printer-uri", NULL, uri);
@@ -258,8 +266,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 	{
           if (response->request.status.status_code > IPP_OK_CONFLICT)
 	  {
-            fprintf(stderr, "%s: Operation failed: %s\n", command,
-	            ippErrorString(cupsLastError()));
+            _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
 	    return (1);
 	  }
 
@@ -267,8 +274,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 	}
 	else
 	{
-          fprintf(stderr, "%s: Operation failed: %s\n", command,
-	          ippErrorString(cupsLastError()));
+          _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
 	  return (1);
 	}
       }
@@ -282,5 +288,5 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 
 /*
- * End of "$Id: accept.c,v 1.21 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: accept.c 5926 2006-09-05 20:45:47Z mike $".
  */
