@@ -1,9 +1,9 @@
 /*
- * "$Id: cancel.c,v 1.33 2004/02/25 20:14:53 mike Exp $"
+ * "$Id: cancel.c 5926 2006-09-05 20:45:47Z mike $"
  *
  *   "cancel" command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2004 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -15,9 +15,9 @@
  *       Attn: CUPS Licensing Information
  *       Easy Software Products
  *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636-3111 USA
+ *       Hollywood, Maryland 20636 USA
  *
- *       Voice: (301) 373-9603
+ *       Voice: (301) 373-9600
  *       EMail: cups-info@cups.org
  *         WWW: http://www.cups.org
  *
@@ -32,50 +32,49 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
-
-#include <config.h>
-#include <cups/cups.h>
 #include <cups/string.h>
-#include <cups/language.h>
+#include <cups/cups.h>
+#include <cups/i18n.h>
 
 
 /*
  * 'main()' - Parse options and cancel jobs.
  */
 
-int				/* O - Exit status */
-main(int  argc,			/* I - Number of command-line arguments */
-     char *argv[])		/* I - Command-line arguments */
+int					/* O - Exit status */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  http_t	*http;		/* HTTP connection to server */
-  int		i;		/* Looping var */
-  int		job_id;		/* Job ID */
-  int		num_dests;	/* Number of destinations */
-  cups_dest_t	*dests;		/* Destinations */
-  char		*dest,		/* Destination printer */
-		*job,		/* Job ID pointer */
-		*user;		/* Cancel jobs for a user */
-  int		purge;		/* Purge or cancel jobs? */
-  char		uri[1024];	/* Printer or job URI */
-  ipp_t		*request;	/* IPP request */
-  ipp_t		*response;	/* IPP response */
-  ipp_op_t	op;		/* Operation */
-  cups_lang_t	*language;	/* Language */
+  http_t	*http;			/* HTTP connection to server */
+  int		i;			/* Looping var */
+  int		job_id;			/* Job ID */
+  int		num_dests;		/* Number of destinations */
+  cups_dest_t	*dests;			/* Destinations */
+  char		*dest,			/* Destination printer */
+		*job,			/* Job ID pointer */
+		*user;			/* Cancel jobs for a user */
+  int		purge;			/* Purge or cancel jobs? */
+  char		uri[1024];		/* Printer or job URI */
+  ipp_t		*request;		/* IPP request */
+  ipp_t		*response;		/* IPP response */
+  ipp_op_t	op;			/* Operation */
 
 
+  _cupsSetLocale(argv);
+
  /*
   * Setup to cancel individual print jobs...
   */
 
-  op         = IPP_CANCEL_JOB;
-  purge      = 0;
-  job_id     = 0;
-  dest       = NULL;
-  user       = NULL;
-  http       = NULL;
-  num_dests  = 0;
-  dests      = NULL;
+  op        = IPP_CANCEL_JOB;
+  purge     = 0;
+  job_id    = 0;
+  dest      = NULL;
+  user      = NULL;
+  http      = NULL;
+  num_dests = 0;
+  dests     = NULL;
+
 
  /*
   * Process command-line arguments...
@@ -92,11 +91,31 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    if (http)
 	      httpEncryption(http, HTTP_ENCRYPT_REQUIRED);
 #else
-            fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
-	            argv[0]);
+            _cupsLangPrintf(stderr,
+	                    _("%s: Sorry, no encryption support compiled in!\n"),
+	                    argv[0]);
 #endif /* HAVE_SSL */
 	    break;
 
+        case 'U' : /* Username */
+	    if (argv[i][2] != '\0')
+	      cupsSetUser(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected username after "
+				  "\'-U\' option!\n"),
+		        	argv[0]);
+	        return (1);
+	      }
+
+              cupsSetUser(argv[i]);
+	    }
+	    break;
+	    
         case 'a' : /* Cancel all jobs */
 	    purge = 1;
 	    op    = IPP_PURGE_JOBS;
@@ -104,7 +123,10 @@ main(int  argc,			/* I - Number of command-line arguments */
 
         case 'h' : /* Connect to host */
 	    if (http != NULL)
+	    {
 	      httpClose(http);
+	      http = NULL;
+	    }
 
 	    if (argv[i][2] != '\0')
               cupsSetServer(argv[i] + 2);
@@ -114,7 +136,10 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("cancel: Error - expected hostname after \'-h\' option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		        	_("%s: Error - expected hostname after "
+			          "\'-h\' option!\n"),
+				argv[0]);
 		return (1);
               }
 	      else
@@ -133,7 +158,10 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("cancel: Error - expected username after \'-u\' option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		        	_("%s: Error - expected username after "
+			          "\'-u\' option!\n"),
+				argv[0]);
 		return (1);
               }
 	      else
@@ -142,7 +170,9 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    break;
 
 	default :
-	    fprintf(stderr, "cancel: Unknown option \'%c\'!\n", argv[i][1]);
+	    _cupsLangPrintf(stderr,
+	                    _("%s: Error - unknown option \'%c\'!\n"),
+			    argv[0], argv[i][1]);
 	    return (1);
       }
     else
@@ -154,7 +184,7 @@ main(int  argc,			/* I - Number of command-line arguments */
       if (num_dests == 0)
         num_dests = cupsGetDests(&dests);
 
-      if (strcmp(argv[i], "-") == 0)
+      if (!strcmp(argv[i], "-"))
       {
        /*
         * Delete the current job...
@@ -198,7 +228,9 @@ main(int  argc,			/* I - Number of command-line arguments */
         * Bad printer name!
 	*/
 
-        fprintf(stderr, "cancel: Unknown destination \"%s\"!\n", argv[i]);
+        _cupsLangPrintf(stderr,
+	                _("%s: Error - unknown destination \"%s\"!\n"),
+			argv[0], argv[i]);
 	return (1);
       }
 
@@ -219,7 +251,9 @@ main(int  argc,			/* I - Number of command-line arguments */
 	if ((http = httpConnectEncrypt(cupsServer(), ippPort(),
 	                               cupsEncryption())) == NULL)
 	{
-	  fputs("cancel: Unable to contact server!\n", stderr);
+	  _cupsLangPrintf(stderr,
+	                  _("%s: Unable to contact server!\n"),
+			  argv[0]);
 	  return (1);
 	}
 
@@ -233,22 +267,12 @@ main(int  argc,			/* I - Number of command-line arguments */
       *    [requesting-user-name]
       */
 
-      request = ippNew();
-
-      request->request.op.operation_id = op;
-      request->request.op.request_id   = 1;
-
-      language = cupsLangDefault();
-
-      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-              	   "attributes-charset", NULL, cupsLangEncoding(language));
-
-      ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-                   "attributes-natural-language", NULL, language->language);
+      request = ippNewRequest(op);
 
       if (dest)
       {
-        snprintf(uri, sizeof(uri), "ipp://localhost/printers/%s", dest);
+	httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
+	                 "localhost", 0, "/printers/%s", dest);
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
 	             "printer-uri", NULL, uri);
 	ippAddInteger(request, IPP_TAG_OPERATION, IPP_TAG_INTEGER, "job-id",
@@ -278,7 +302,7 @@ main(int  argc,			/* I - Number of command-line arguments */
       * Do the request and get back a response...
       */
 
-      if (op == IPP_PURGE_JOBS)
+      if (op == IPP_PURGE_JOBS && (!user || strcasecmp(user, cupsUser())))
         response = cupsDoRequest(http, request, "/admin/");
       else
         response = cupsDoRequest(http, request, "/jobs/");
@@ -286,10 +310,9 @@ main(int  argc,			/* I - Number of command-line arguments */
       if (response == NULL ||
           response->request.status.status_code > IPP_OK_CONFLICT)
       {
-	fprintf(stderr, "cancel: %s failed: %s\n",
-	        op == IPP_PURGE_JOBS ? "purge-jobs" : "cancel-job",
-        	response ? ippErrorString(response->request.status.status_code) :
-		           ippErrorString(cupsLastError()));
+	_cupsLangPrintf(stderr, _("%s: %s failed: %s\n"), argv[0],
+	        	op == IPP_PURGE_JOBS ? "purge-jobs" : "cancel-job",
+        		cupsLastErrorString());
 
 	if (response)
 	  ippDelete(response);
@@ -310,7 +333,8 @@ main(int  argc,			/* I - Number of command-line arguments */
       if ((http = httpConnectEncrypt(cupsServer(), ippPort(),
 	                             cupsEncryption())) == NULL)
       {
-	fputs("cancel: Unable to contact server!\n", stderr);
+	_cupsLangPrintf(stderr, _("%s: Unable to contact server!\n"),
+	                argv[0]);
 	return (1);
       }
 
@@ -324,18 +348,7 @@ main(int  argc,			/* I - Number of command-line arguments */
     *    [requesting-user-name]
     */
 
-    request = ippNew();
-
-    request->request.op.operation_id = op;
-    request->request.op.request_id   = 1;
-
-    language = cupsLangDefault();
-
-    ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-              	 "attributes-charset", NULL, cupsLangEncoding(language));
-
-    ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-                 "attributes-natural-language", NULL, language->language);
+    request = ippNewRequest(op);
 
     ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
 	         "printer-uri", NULL, "ipp://localhost/printers/");
@@ -361,10 +374,9 @@ main(int  argc,			/* I - Number of command-line arguments */
     if (response == NULL ||
         response->request.status.status_code > IPP_OK_CONFLICT)
     {
-      fprintf(stderr, "cancel: %s failed: %s\n",
-	      op == IPP_PURGE_JOBS ? "purge-jobs" : "cancel-job",
-              response ? ippErrorString(response->request.status.status_code) :
-		         ippErrorString(cupsLastError()));
+      _cupsLangPrintf(stderr, _("%s: %s failed: %s\n"), argv[0],
+		      op == IPP_PURGE_JOBS ? "purge-jobs" : "cancel-job",
+        	      cupsLastErrorString());
 
       if (response)
 	ippDelete(response);
@@ -380,5 +392,5 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 
 /*
- * End of "$Id: cancel.c,v 1.33 2004/02/25 20:14:53 mike Exp $".
+ * End of "$Id: cancel.c 5926 2006-09-05 20:45:47Z mike $".
  */
