@@ -1,9 +1,9 @@
 /*
- * "$Id: lp.c,v 1.50 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: lp.c 6359 2007-03-19 14:46:09Z mike $"
  *
  *   "lp" command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -36,9 +36,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
-#include <cups/cups.h>
 #include <cups/string.h>
-#include <cups/language.h>
+#include <cups/cups.h>
+#include <cups/i18n.h>
 
 
 #ifndef WIN32
@@ -52,8 +52,9 @@
 
 void	sighandler(int);
 #endif /* !WIN32 */
-int	restart_job(int job_id);
-int	set_job_attrs(int job_id, int num_options, cups_option_t *options);
+int	restart_job(const char *command, int job_id);
+int	set_job_attrs(const char *command, int job_id, int num_options,
+	              cups_option_t *options);
 
 
 /*
@@ -68,30 +69,33 @@ char	tempfile[1024];		/* Temporary file for printing from stdin */
  */
 
 int
-main(int  argc,		/* I - Number of command-line arguments */
-     char *argv[])	/* I - Command-line arguments */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  int		i, j;		/* Looping vars */
-  int		job_id;		/* Job ID */
-  char		*printer,	/* Printer name */
-		*instance,	/* Instance name */ 
-		*val,		/* Option value */
-		*title;		/* Job title */
-  int		priority;	/* Job priority (1-100) */
-  int		num_copies;	/* Number of copies per file */
-  int		num_files;	/* Number of files to print */
-  const char	*files[1000];	/* Files to print */
-  int		num_dests;	/* Number of destinations */
-  cups_dest_t	*dests,		/* Destinations */
-		*dest;		/* Selected destination */
-  int		num_options;	/* Number of options */
-  cups_option_t	*options;	/* Options */
-  int		silent;		/* Silent or verbose output? */
-  char		buffer[8192];	/* Copy buffer */
-  int		temp;		/* Temporary file descriptor */
+  int		i, j;			/* Looping vars */
+  int		job_id;			/* Job ID */
+  char		*printer,		/* Printer name */
+		*instance,		/* Instance name */ 
+		*val,			/* Option value */
+		*title;			/* Job title */
+  int		priority;		/* Job priority (1-100) */
+  int		num_copies;		/* Number of copies per file */
+  int		num_files;		/* Number of files to print */
+  const char	*files[1000];		/* Files to print */
+  int		num_dests;		/* Number of destinations */
+  cups_dest_t	*dests,			/* Destinations */
+		*dest;			/* Selected destination */
+  int		num_options;		/* Number of options */
+  cups_option_t	*options;		/* Options */
+  int		end_options;		/* No more options? */
+  int		silent;			/* Silent or verbose output? */
+  char		buffer[8192];		/* Copy buffer */
+  ssize_t	bytes;			/* Bytes copied */
+  off_t		filesize;		/* Size of temp file */
+  int		temp;			/* Temporary file descriptor */
 #if defined(HAVE_SIGACTION) && !defined(HAVE_SIGSET)
-  struct sigaction action;	/* Signal action */
-  struct sigaction oldaction;	/* Old signal action */
+  struct sigaction action;		/* Signal action */
+  struct sigaction oldaction;		/* Old signal action */
 #endif /* HAVE_SIGACTION && !HAVE_SIGSET*/
 
 
@@ -109,10 +113,12 @@ main(int  argc,		/* I - Number of command-line arguments */
   else
     val = argv[0];
 
-  if (strcmp(val, "printd") == 0)
+  if (!strcmp(val, "printd"))
     return (0);
 #endif /* __sun */
 
+  _cupsSetLocale(argv);
+
   silent      = 0;
   printer     = NULL;
   num_dests   = 0;
@@ -122,20 +128,41 @@ main(int  argc,		/* I - Number of command-line arguments */
   num_files   = 0;
   title       = NULL;
   job_id      = 0;
+  end_options = 0;
 
   for (i = 1; i < argc; i ++)
-    if (argv[i][0] == '-' && argv[i][1])
+    if (argv[i][0] == '-' && argv[i][1] && !end_options)
       switch (argv[i][1])
       {
         case 'E' : /* Encrypt */
 #ifdef HAVE_SSL
 	    cupsSetEncryption(HTTP_ENCRYPT_REQUIRED);
 #else
-            fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
-	            argv[0]);
+            _cupsLangPrintf(stderr,
+	                    _("%s: Sorry, no encryption support compiled in!\n"),
+	                    argv[0]);
 #endif /* HAVE_SSL */
 	    break;
 
+        case 'U' : /* Username */
+	    if (argv[i][2] != '\0')
+	      cupsSetUser(argv[i] + 2);
+	    else
+	    {
+	      i ++;
+	      if (i >= argc)
+	      {
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected username after "
+				  "\'-U\' option!\n"),
+		        	argv[0]);
+	        return (1);
+	      }
+
+              cupsSetUser(argv[i]);
+	    }
+	    break;
+	    
         case 'c' : /* Copy to spool dir (always enabled) */
 	    break;
 
@@ -148,7 +175,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected destination after -d option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		        	_("%s: Error - expected destination after "
+			          "\'-d\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -178,12 +208,16 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected form after -f option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected form after \'-f\' "
+				  "option!\n"),
+				argv[0]);
 		return (1);
               }
 	    }
 
-	    fputs("lp: Warning - form option ignored!\n", stderr);
+	    _cupsLangPrintf(stderr, _("%s: Warning - form option ignored!\n"),
+	                    argv[0]);
 	    break;
 
         case 'h' : /* Destination host */
@@ -195,7 +229,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected hostname after -h option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected hostname after "
+				  "\'-h\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -212,7 +249,9 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected job ID after -i option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Expected job ID after \'-i\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -221,7 +260,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
             if (num_files > 0)
 	    {
-	      fputs("lp: Error - cannot print files and alter jobs simultaneously!\n", stderr);
+	      _cupsLangPrintf(stderr,
+		              _("%s: Error - cannot print files and alter "
+			        "jobs simultaneously!\n"),
+			      argv[0]);
 	      return (1);
 	    }
 
@@ -232,7 +274,7 @@ main(int  argc,		/* I - Number of command-line arguments */
 
             if (job_id < 0)
 	    {
-	      fputs("lp: Error - bad job ID!\n", stderr);
+	      _cupsLangPrintf(stderr, _("%s: Error - bad job ID!\n"), argv[0]);
 	      break;
 	    }
 	    break;
@@ -242,6 +284,17 @@ main(int  argc,		/* I - Number of command-line arguments */
 	case 'p' : /* Notify on completion */
 #endif /* __sun */
 	case 'w' : /* Write to console or email */
+	    {
+	      char	email[1024];	/* EMail address */
+
+
+	      snprintf(email, sizeof(email), "mailto:%s@%s", cupsUser(),
+	               httpGetHostname(NULL, buffer, sizeof(buffer)));
+	      num_options = cupsAddOption("notify-recipient-uri", email,
+	                                  num_options, &options);
+	    }
+
+	    silent = 1;
 	    break;
 
 	case 'n' : /* Number of copies */
@@ -253,7 +306,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected copies after -n option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected copies after "
+				  "\'-n\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -273,7 +329,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected option string after -o option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected option string after "
+				  "\'-o\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -289,15 +348,17 @@ main(int  argc,		/* I - Number of command-line arguments */
 	      priority = atoi(argv[i] + 2);
 	    else
 	    {
-	      i ++;
-
-	      if (i >= argc)
+	      if ((i + 1) >= argc)
 	      {
-	        fprintf(stderr, "lp: Expected priority after -%c option!\n",
-		        argv[i - 1][1]);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected priority after "
+				  "\'-%c\' option!\n"),
+		        	argv[0], argv[i][1]);
 		return (1);
               }
 
+	      i ++;
+
 	      priority = atoi(argv[i]);
 	    }
 
@@ -312,7 +373,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	    if (priority < 1 || priority > 100)
 	    {
-	      fputs("lp: Priority must be between 1 and 100.\n", stderr);
+	      _cupsLangPrintf(stderr,
+		              _("%s: Error - priority must be between 1 and "
+			        "100.\n"),
+		              argv[0]);
 	      return (1);
 	    }
 
@@ -333,7 +397,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected title after -t option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected title after "
+				  "\'-t\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -348,12 +415,17 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected mode list after -y option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected mode list after "
+				  "\'-y\' option!\n"),
+				argv[0]);
 		return (1);
               }
 	    }
 
-	    fputs("lp: Warning - mode option ignored!\n", stderr);
+	    _cupsLangPrintf(stderr,
+		            _("%s: Warning - mode option ignored!\n"),
+			    argv[0]);
 	    break;
 
         case 'H' : /* Hold job */
@@ -365,32 +437,38 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected hold name after -H option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected hold name after "
+				  "\'-H\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
 	      val = argv[i];
 	    }
 
-	    if (strcmp(val, "hold") == 0)
+	    if (!strcmp(val, "hold"))
               num_options = cupsAddOption("job-hold-until", "indefinite",
 	                                  num_options, &options);
-	    else if (strcmp(val, "resume") == 0 ||
-	             strcmp(val, "release") == 0)
+	    else if (!strcmp(val, "resume") ||
+	             !strcmp(val, "release"))
               num_options = cupsAddOption("job-hold-until", "no-hold",
 	                                  num_options, &options);
-	    else if (strcmp(val, "immediate") == 0)
+	    else if (!strcmp(val, "immediate"))
               num_options = cupsAddOption("job-priority", "100",
 	                                  num_options, &options);
-	    else if (strcmp(val, "restart") == 0)
+	    else if (!strcmp(val, "restart"))
 	    {
 	      if (job_id < 1)
 	      {
-	        fputs("lp: Need job ID (-i) before \"-H restart\"!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Need job ID (\'-i jobid\') before "
+			          "\'-H restart\'!\n"),
+				argv[0]);
 		return (1);
 	      }
 
-	      if (restart_job(job_id))
+	      if (restart_job(argv[0], job_id))
 	        return (1);
 	    }
 	    else
@@ -407,7 +485,10 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected page list after -P option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected page list after "
+				  "\'-P\' option!\n"),
+				argv[0]);
 		return (1);
               }
 
@@ -425,12 +506,17 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected character set after -S option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		                _("%s: Error - expected character set after "
+				  "\'-S\' option!\n"),
+				argv[0]);
 		return (1);
               }
 	    }
 
-	    fputs("lp: Warning - character set option ignored!\n", stderr);
+	    _cupsLangPrintf(stderr,
+		            _("%s: Warning - character set option ignored!\n"),
+			    argv[0]);
 	    break;
 
         case 'T' : /* Content-Type */
@@ -440,24 +526,36 @@ main(int  argc,		/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("lp: Expected content type after -T option!\n", stderr);
+	        _cupsLangPrintf(stderr,
+		        	_("%s: Error - expected content type after "
+			          "\'-T\' option!\n"),
+				argv[0]);
 		return (1);
               }
 	    }
 
-	    fputs("lp: Warning - content type option ignored!\n", stderr);
+	    _cupsLangPrintf(stderr,
+		            _("%s: Warning - content type option ignored!\n"),
+			    argv[0]);
+	    break;
+
+        case '-' : /* Stop processing options */
+	    end_options = 1;
 	    break;
 
 	default :
-	    fprintf(stderr, "lp: Unknown option \'%c\'!\n", argv[i][1]);
+	    _cupsLangPrintf(stderr, _("%s: Error - unknown option \'%c\'!\n"),
+	                    argv[0], argv[i][1]);
 	    return (1);
       }
     else if (!strcmp(argv[i], "-"))
     {
       if (num_files || job_id)
       {
-        fputs("lp: Error - cannot print from stdin if files or a job ID are "
-	      "provided!\n", stderr);
+        _cupsLangPrintf(stderr,
+			_("%s: Error - cannot print from stdin if files or a "
+		          "job ID are provided!\n"),
+			 argv[0]);
 	return (1);
       }
 
@@ -471,8 +569,8 @@ main(int  argc,		/* I - Number of command-line arguments */
 
       if (access(argv[i], R_OK) != 0)
       {
-        fprintf(stderr, "lp: Unable to access \"%s\" - %s\n", argv[i],
-	        strerror(errno));
+        _cupsLangPrintf(stderr, _("%s: Error - unable to access \"%s\" - %s\n"),
+	                argv[0], argv[i], strerror(errno));
         return (1);
       }
 
@@ -488,14 +586,15 @@ main(int  argc,		/* I - Number of command-line arguments */
       }
     }
     else
-      fprintf(stderr, "lp: Too many files - \"%s\"\n", argv[i]);
+      _cupsLangPrintf(stderr, _("%s: Error - too many files - \"%s\"\n"),
+                      argv[0], argv[i]);
 
  /*
   * See if we are altering an existing job...
   */
 
   if (job_id)
-    return (set_job_attrs(job_id, num_options, options));
+    return (set_job_attrs(argv[0], job_id, num_options, options));
 
  /*
   * See if we have any files to print; if not, print from stdin...
@@ -536,12 +635,18 @@ main(int  argc,		/* I - Number of command-line arguments */
       val = "LPDEST";
 
     if (printer && !cupsGetDest(printer, NULL, num_dests, dests))
-      fprintf(stderr, "lp: error - %s environment variable names non-existent destination \"%s\"!\n",
-              val, printer);
+      _cupsLangPrintf(stderr,
+		      _("%s: Error - %s environment variable names "
+		        "non-existent destination \"%s\"!\n"),
+        	      argv[0], val, printer);
     else if (cupsLastError() == IPP_NOT_FOUND)
-      fputs("lp: error - no default destination available.\n", stderr);
+      _cupsLangPrintf(stderr,
+		      _("%s: Error - no default destination available.\n"),
+		      argv[0]);
     else
-      fputs("lp: error - scheduler not responding!\n", stderr);
+      _cupsLangPrintf(stderr,
+		      _("%s: Error - scheduler not responding!\n"),
+		      argv[0]);
 
     return (1);
   }
@@ -579,20 +684,33 @@ main(int  argc,		/* I - Number of command-line arguments */
 
     if (temp < 0)
     {
-      fprintf(stderr, "lp: unable to create temporary file \"%s\" - %s\n",
-              tempfile, strerror(errno));
+      _cupsLangPrintf(stderr,
+		      _("%s: Error - unable to create temporary file \"%s\" - %s\n"),
+        	      argv[0], tempfile, strerror(errno));
       return (1);
     }
 
-    while ((i = read(0, buffer, sizeof(buffer))) > 0)
-      write(temp, buffer, i);
+    while ((bytes = read(0, buffer, sizeof(buffer))) > 0)
+      if (write(temp, buffer, bytes) < 0)
+      {
+	_cupsLangPrintf(stderr,
+		        _("%s: Error - unable to write to temporary file "
+			  "\"%s\" - %s\n"),
+        	        argv[0], tempfile, strerror(errno));
+        close(temp);
+        unlink(tempfile);
+	return (1);
+      }
 
-    i = lseek(temp, 0, SEEK_CUR);
+    filesize = lseek(temp, 0, SEEK_CUR);
     close(temp);
 
-    if (i == 0)
+    if (filesize <= 0)
     {
-      fputs("lp: stdin is empty, so no job has been sent.\n", stderr);
+      _cupsLangPrintf(stderr,
+		      _("%s: Error - stdin is empty, so no job has been sent.\n"),
+		      argv[0]);
+      unlink(tempfile);
       return (1);
     }
 
@@ -606,12 +724,12 @@ main(int  argc,		/* I - Number of command-line arguments */
 
   if (job_id < 1)
   {
-    fprintf(stderr, "lp: unable to print file: %s\n",
-	    ippErrorString(cupsLastError()));
+    _cupsLangPrintf(stderr, "%s: %s\n", argv[0], cupsLastErrorString());
     return (1);
   }
   else if (!silent)
-    printf("request id is %s-%d (%d file(s))\n", printer, job_id, num_files);
+    _cupsLangPrintf(stdout, _("request id is %s-%d (%d file(s))\n"),
+		    printer, job_id, num_files);
 
   return (0);
 }
@@ -622,28 +740,17 @@ main(int  argc,		/* I - Number of command-line arguments */
  */
 
 int					/* O - Exit status */
-restart_job(int job_id)			/* I - Job ID */
+restart_job(const char *command,	/* I - Command name */
+            int        job_id)		/* I - Job ID */
 {
   http_t	*http;			/* HTTP connection to server */
-  ipp_t		*request,		/* IPP request */
-		*response;		/* IPP response */
-  cups_lang_t	*language;		/* Language for request */
+  ipp_t		*request;		/* IPP request */
   char		uri[HTTP_MAX_URI];	/* URI for job */
 
 
   http = httpConnectEncrypt(cupsServer(), ippPort(), cupsEncryption());
 
-  language = cupsLangDefault();
-
-  request = ippNew();
-  request->request.op.operation_id = IPP_RESTART_JOB;
-  request->request.op.request_id   = 1;
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-               "attributes-charset", NULL, cupsLangEncoding(language));
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-               "attributes-natural-language", NULL, language->language);
+  request = ippNewRequest(IPP_RESTART_JOB);
 
   sprintf(uri, "ipp://localhost/jobs/%d", job_id);
 
@@ -653,22 +760,11 @@ restart_job(int job_id)			/* I - Job ID */
   ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_NAME,
                "requesting-user-name", NULL, cupsUser());
 
-  if ((response = cupsDoRequest(http, request, "/jobs")) != NULL)
-  {
-    if (response->request.status.status_code > IPP_OK_CONFLICT)
-    {
-      fprintf(stderr, "lp: restart-job failed: %s\n",
-              ippErrorString(response->request.status.status_code));
-      ippDelete(response);
-      return (1);
-    }
+  ippDelete(cupsDoRequest(http, request, "/jobs"));
 
-    ippDelete(response);
-  }
-  else
+  if (cupsLastError() > IPP_OK_CONFLICT)
   {
-    fprintf(stderr, "lp: restart-job failed: %s\n",
-            ippErrorString(cupsLastError()));
+    _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
     return (1);
   }
 
@@ -681,14 +777,13 @@ restart_job(int job_id)			/* I - Job ID */
  */
 
 int					/* O - Exit status */
-set_job_attrs(int           job_id,	/* I - Job ID */
+set_job_attrs(const char    *command,	/* I - Command name */
+              int           job_id,	/* I - Job ID */
               int           num_options,/* I - Number of options */
 	      cups_option_t *options)	/* I - Options */
 {
   http_t	*http;			/* HTTP connection to server */
-  ipp_t		*request,		/* IPP request */
-		*response;		/* IPP response */
-  cups_lang_t	*language;		/* Language for request */
+  ipp_t		*request;		/* IPP request */
   char		uri[HTTP_MAX_URI];	/* URI for job */
 
 
@@ -697,17 +792,7 @@ set_job_attrs(int           job_id,	/* I - Job ID */
 
   http = httpConnectEncrypt(cupsServer(), ippPort(), cupsEncryption());
 
-  language = cupsLangDefault();
-
-  request = ippNew();
-  request->request.op.operation_id = IPP_SET_JOB_ATTRIBUTES;
-  request->request.op.request_id   = 1;
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-               "attributes-charset", NULL, cupsLangEncoding(language));
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-               "attributes-natural-language", NULL, language->language);
+  request = ippNewRequest(IPP_SET_JOB_ATTRIBUTES);
 
   sprintf(uri, "ipp://localhost/jobs/%d", job_id);
 
@@ -719,22 +804,11 @@ set_job_attrs(int           job_id,	/* I - Job ID */
 
   cupsEncodeOptions(request, num_options, options);
 
-  if ((response = cupsDoRequest(http, request, "/jobs")) != NULL)
-  {
-    if (response->request.status.status_code > IPP_OK_CONFLICT)
-    {
-      fprintf(stderr, "lp: set-job-attributes failed: %s\n",
-              ippErrorString(response->request.status.status_code));
-      ippDelete(response);
-      return (1);
-    }
+  ippDelete(cupsDoRequest(http, request, "/jobs"));
 
-    ippDelete(response);
-  }
-  else
+  if (cupsLastError() > IPP_OK_CONFLICT)
   {
-    fprintf(stderr, "lp: set-job-attributes failed: %s\n",
-            ippErrorString(cupsLastError()));
+    _cupsLangPrintf(stderr, "%s: %s\n", command, cupsLastErrorString());
     return (1);
   }
 
@@ -748,7 +822,7 @@ set_job_attrs(int           job_id,	/* I - Job ID */
  */
 
 void
-sighandler(int s)	/* I - Signal number */
+sighandler(int s)			/* I - Signal number */
 {
  /*
   * Remove the temporary file we're using to print from stdin...
@@ -766,5 +840,5 @@ sighandler(int s)	/* I - Signal number */
 
 
 /*
- * End of "$Id: lp.c,v 1.50 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: lp.c 6359 2007-03-19 14:46:09Z mike $".
  */
