@@ -1,9 +1,9 @@
 /*
- * "$Id: lpmove.c,v 1.13 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: lpmove.c 5926 2006-09-05 20:45:47Z mike $"
  *
  *   "lpmove" command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -33,18 +33,19 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
-#include <cups/cups.h>
-#include <cups/language.h>
-#include <cups/debug.h>
+#include <errno.h>
 #include <cups/string.h>
+#include <cups/cups.h>
+#include <cups/i18n.h>
+#include <cups/debug.h>
 
 
 /*
  * Local functions...
  */
 
-static void	move_job(http_t *, int, const char *);
+static int	move_job(http_t *http, const char *src, int jobid,
+		         const char *dest);
 
 
 /*
@@ -52,22 +53,28 @@ static void	move_job(http_t *, int, const char *);
  */
 
 int
-main(int  argc,			/* I - Number of command-line arguments */
-     char *argv[])		/* I - Command-line arguments */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  int		i;		/* Looping var */
-  http_t	*http;		/* Connection to server */
-  const char	*job;		/* Job name */
-  int		num_dests;	/* Number of destinations */
-  cups_dest_t	*dests;		/* Destinations */
-  const char	*dest;		/* New destination */
+  int		i;			/* Looping var */
+  http_t	*http;			/* Connection to server */
+  const char	*job;			/* Job name */
+  int		jobid;			/* Job ID */
+  int		num_dests;		/* Number of destinations */
+  cups_dest_t	*dests;			/* Destinations */
+  const char	*src,			/* Original queue */
+		*dest;			/* New destination */
 
 
+  _cupsSetLocale(argv);
+
+  dest      = NULL;
+  dests     = NULL;
   http      = NULL;
   job       = NULL;
-  dest      = NULL;
+  jobid     = 0;
   num_dests = 0;
-  dests     = NULL;
+  src       = NULL;
 
   for (i = 1; i < argc; i ++)
     if (argv[i][0] == '-')
@@ -80,8 +87,9 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    if (http)
 	      httpEncryption(http, HTTP_ENCRYPT_REQUIRED);
 #else
-            fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
-	            argv[0]);
+            _cupsLangPrintf(stderr,
+	                    _("%s: Sorry, no encryption support compiled in!\n"),
+	                    argv[0]);
 #endif /* HAVE_SSL */
 	    break;
 
@@ -100,7 +108,8 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 	      if (i >= argc)
 	      {
-	        fputs("Error: need hostname after \'-h\' option!\n", stderr);
+	        _cupsLangPuts(stderr,
+		              _("Error: need hostname after \'-h\' option!\n"));
 		return (1);
               }
 
@@ -109,31 +118,33 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    break;
 
 	default :
-	    fprintf(stderr, "lpmove: Unknown option \'%c\'!\n", argv[i][1]);
+	    _cupsLangPrintf(stderr, _("lpmove: Unknown option \'%c\'!\n"),
+	                    argv[i][1]);
 	    return (1);
       }
-    else if (job == NULL)
+    else if (!jobid && !src)
     {
       if (num_dests == 0)
         num_dests = cupsGetDests(&dests);
 
       if ((job = strrchr(argv[i], '-')) != NULL &&
           cupsGetDest(argv[i], NULL, num_dests, dests) == NULL)
-        job ++;
+        jobid = atoi(job + 1);
       else
-        job = argv[i];
+        src = argv[i];
     }
     else if (dest == NULL)
       dest = argv[i];
     else
     {
-      fprintf(stderr, "lpmove: Unknown argument \'%s\'!\n", argv[i]);
+      _cupsLangPrintf(stderr, _("lpmove: Unknown argument \'%s\'!\n"),
+                      argv[i]);
       return (1);
     }
 
-  if (job == NULL || dest == NULL)
+  if ((!jobid && !src) || !dest)
   {
-    puts("Usage: lpmove job dest");
+    _cupsLangPuts(stdout, _("Usage: lpmove job/src dest\n"));
     return (1);
   }
 
@@ -143,14 +154,14 @@ main(int  argc,			/* I - Number of command-line arguments */
 
     if (http == NULL)
     {
-      perror("lpmove: Unable to connect to server");
+      _cupsLangPrintf(stderr,
+                      _("lpmove: Unable to connect to server: %s\n"),
+		      strerror(errno));
       return (1);
     }
   }
 
-  move_job(http, atoi(job), dest);
-
-  return (0);
+  return (move_job(http, src, jobid, dest));
 }
 
 
@@ -158,22 +169,19 @@ main(int  argc,			/* I - Number of command-line arguments */
  * 'move_job()' - Move a job.
  */
 
-static void
-move_job(http_t     *http,	/* I - HTTP connection to server */
-         int        jobid,	/* I - Job ID */
-	 const char *dest)	/* I - Destination */
+static int				/* O - 0 on success, 1 on error */
+move_job(http_t     *http,		/* I - HTTP connection to server */
+         const char *src,		/* I - Source queue */
+         int        jobid,		/* I - Job ID */
+	 const char *dest)		/* I - Destination queue */
 {
-  ipp_t		*request,	/* IPP Request */
-		*response;	/* IPP Response */
-  cups_lang_t	*language;	/* Default language */
-  char		job_uri[HTTP_MAX_URI],
-				/* job-uri */
-		printer_uri[HTTP_MAX_URI];
-				/* job-printer-uri */
+  ipp_t	*request;			/* IPP Request */
+  char	job_uri[HTTP_MAX_URI],		/* job-uri */
+	printer_uri[HTTP_MAX_URI];	/* job-printer-uri */
 
 
-  if (http == NULL)
-    return;
+  if (!http)
+    return (1);
 
  /*
   * Build a CUPS_MOVE_JOB request, which requires the following
@@ -181,30 +189,32 @@ move_job(http_t     *http,	/* I - HTTP connection to server */
   *
   *    attributes-charset
   *    attributes-natural-language
-  *    job-uri
+  *    job-uri/printer-uri
   *    job-printer-uri
+  *    requesting-user-name
   */
 
-  request = ippNew();
+  request = ippNewRequest(CUPS_MOVE_JOB);
 
-  request->request.op.operation_id = CUPS_MOVE_JOB;
-  request->request.op.request_id   = 1;
-
-  language = cupsLangDefault();
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
-               "attributes-charset", NULL, cupsLangEncoding(language));
-
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
-               "attributes-natural-language", NULL, language->language);
-
-  snprintf(job_uri, sizeof(job_uri), "ipp://localhost/jobs/%d", jobid);
-  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI, "job-uri", NULL, job_uri);
+  if (jobid)
+  {
+    snprintf(job_uri, sizeof(job_uri), "ipp://localhost/jobs/%d", jobid);
+    ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI, "job-uri", NULL,
+        	 job_uri);
+  }
+  else
+  {
+    httpAssembleURIf(HTTP_URI_CODING_ALL, job_uri, sizeof(job_uri), "ipp", NULL,
+                     "localhost", 0, "/printers/%s", src);
+    ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI, "printer-uri", NULL,
+        	 job_uri);
+  }
 
   ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_NAME, "requesting-user-name",
                NULL, cupsUser());
 
-  snprintf(printer_uri, sizeof(printer_uri), "ipp://localhost/printers/%s", dest);
+  httpAssembleURIf(HTTP_URI_CODING_ALL, printer_uri, sizeof(printer_uri),
+                   "ipp", NULL, "localhost", 0, "/printers/%s", dest);
   ippAddString(request, IPP_TAG_JOB, IPP_TAG_URI, "job-printer-uri",
                NULL, printer_uri);
 
@@ -212,24 +222,18 @@ move_job(http_t     *http,	/* I - HTTP connection to server */
   * Do the request and get back a response...
   */
 
-  if ((response = cupsDoRequest(http, request, "/jobs")) != NULL)
-  {
-    if (response->request.status.status_code > IPP_OK_CONFLICT)
-    {
-      fprintf(stderr, "lpmove: move-job failed: %s\n",
-              ippErrorString(response->request.status.status_code));
-      ippDelete(response);
-      return;
-    }
+  ippDelete(cupsDoRequest(http, request, "/jobs"));
 
-    ippDelete(response);
+  if (cupsLastError() > IPP_OK_CONFLICT)
+  {
+    _cupsLangPrintf(stderr, "lpmove: %s\n", cupsLastErrorString());
+    return (1);
   }
   else
-    fprintf(stderr, "lpmove: move-job failed: %s\n",
-            ippErrorString(cupsLastError()));
+    return (0);
 }
 
 
 /*
- * End of "$Id: lpmove.c,v 1.13 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: lpmove.c 5926 2006-09-05 20:45:47Z mike $".
  */
