@@ -1,9 +1,9 @@
 /*
- * "$Id: lpoptions.c,v 1.19 2005/01/03 19:29:59 mike Exp $"
+ * "$Id: lpoptions.c 6348 2007-03-18 03:21:59Z mike $"
  *
  *   Printer option program for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -33,9 +33,11 @@
  * Include necessary headers...
  */
 
-#include <cups/cups.h>
 #include <cups/string.h>
+#include <cups/cups.h>
+#include <cups/i18n.h>
 #include <stdlib.h>
+#include <errno.h>
 
 
 /*
@@ -51,22 +53,24 @@ void	usage(void);
  * 'main()' - Main entry.
  */
 
-int				/* O - Exit status */
-main(int  argc,			/* I - Number of command-line arguments */
-     char *argv[])		/* I - Command-line arguments */
+int					/* O - Exit status */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  int		i, j;		/* Looping vars */
-  int		changes;	/* Did we make changes? */
-  int		num_options;	/* Number of options */
-  cups_option_t	*options;	/* Options */
-  int		num_dests;	/* Number of destinations */
-  cups_dest_t	*dests;		/* Destinations */
-  cups_dest_t	*dest;		/* Current destination */
-  char		*printer,	/* Printer name */
-		*instance,	/* Instance name */ 
- 		*option;	/* Current option */
+  int		i, j;			/* Looping vars */
+  int		changes;		/* Did we make changes? */
+  int		num_options;		/* Number of options */
+  cups_option_t	*options;		/* Options */
+  int		num_dests;		/* Number of destinations */
+  cups_dest_t	*dests;			/* Destinations */
+  cups_dest_t	*dest;			/* Current destination */
+  char		*printer,		/* Printer name */
+		*instance,		/* Instance name */ 
+ 		*option;		/* Current option */
 
 
+  _cupsSetLocale(argv);
+
  /*
   * Loop through the command-line arguments...
   */
@@ -103,7 +107,8 @@ main(int  argc,			/* I - Number of command-line arguments */
 
             if ((dest = cupsGetDest(printer, instance, num_dests, dests)) == NULL)
 	    {
-	      fputs("lpoptions: Unknown printer or class!\n", stderr);
+	      _cupsLangPuts(stderr,
+	                    _("lpoptions: Unknown printer or class!\n"));
 	      return (1);
 	    }
 
@@ -153,7 +158,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    }
 
             if (dest == NULL)
-	      fputs("lpoptions: No printers!?!\n", stderr);
+	      _cupsLangPuts(stderr, _("lpoptions: No printers!?!\n"));
 	    else
 	      list_options(dest);
 
@@ -161,6 +166,27 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    break;
 
 	case 'o' : /* -o option[=value] */
+            if (dest == NULL)
+	    {
+	      if (num_dests == 0)
+		num_dests = cupsGetDests(&dests);
+
+	      if ((dest = cupsGetDest(NULL, NULL, num_dests, dests)) == NULL)
+	        dest = dests;
+
+	      if (dest == NULL)
+              {
+		_cupsLangPuts(stderr, _("lpoptions: No printers!?!\n"));
+                return (1);
+              }
+
+	      for (j = 0; j < dest->num_options; j ++)
+		if (cupsGetOption(dest->options[j].name, num_options, options) == NULL)
+		  num_options = cupsAddOption(dest->options[j].name,
+	                                      dest->options[j].value,
+	                                      num_options, &options);
+	    }
+
 	    if (argv[i][2])
 	      num_options = cupsParseOptions(argv[i] + 2, num_options, &options);
 	    else
@@ -200,7 +226,10 @@ main(int  argc,			/* I - Number of command-line arguments */
 
               if (dest == NULL)
 	      {
-	        perror("lpoptions: Unable to add printer or instance");
+	        _cupsLangPrintf(stderr,
+		                _("lpoptions: Unable to add printer or "
+				  "instance: %s\n"),
+				strerror(errno));
 		return (1);
 	      }
 	    }
@@ -213,6 +242,27 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    break;
 
 	case 'r' : /* -r option (remove) */
+            if (dest == NULL)
+	    {
+	      if (num_dests == 0)
+		num_dests = cupsGetDests(&dests);
+
+	      if ((dest = cupsGetDest(NULL, NULL, num_dests, dests)) == NULL)
+	        dest = dests;
+
+	      if (dest == NULL)
+              {
+		_cupsLangPuts(stderr, _("lpoptions: No printers!?!\n"));
+                return (1);
+              }
+
+	      for (j = 0; j < dest->num_options; j ++)
+		if (cupsGetOption(dest->options[j].name, num_options, options) == NULL)
+		  num_options = cupsAddOption(dest->options[j].name,
+	                                      dest->options[j].value,
+	                                      num_options, &options);
+	    }
+
 	    if (argv[i][2])
 	      option = argv[i] + 2;
 	    else
@@ -225,7 +275,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 	    }
 
             for (j = 0; j < num_options; j ++)
-	      if (strcasecmp(options[j].name, option) == 0)
+	      if (!strcasecmp(options[j].name, option))
 	      {
 	       /*
 	        * Remove this option...
@@ -336,18 +386,20 @@ main(int  argc,			/* I - Number of command-line arguments */
     for (i = 0; i < num_options; i ++)
     {
       if (i)
-        putchar(' ');
+        _cupsLangPuts(stdout, " ");
 
       if (!options[i].value[0])
-        printf("%s", options[i].name);
+        _cupsLangPrintf(stdout, "%s", options[i].name);
       else if (strchr(options[i].value, ' ') != NULL ||
                strchr(options[i].value, '\t') != NULL)
-	printf("%s=\'%s\'", options[i].name, options[i].value);
+	_cupsLangPrintf(stdout, "%s=\'%s\'", options[i].name,
+	                options[i].value);
       else
-	printf("%s=%s", options[i].name, options[i].value);
+	_cupsLangPrintf(stdout, "%s=%s", options[i].name,
+	                options[i].value);
     }
 
-    putchar('\n');
+    _cupsLangPuts(stdout, "\n");
   }
 
   return (0);
@@ -368,15 +420,15 @@ list_group(ppd_group_t *group)	/* I - Group to show */
 
   for (i = group->num_options, option = group->options; i > 0; i --, option ++)
   {
-    printf("%s/%s:", option->keyword, option->text);
+    _cupsLangPrintf(stdout, "%s/%s:", option->keyword, option->text);
 
     for (j = option->num_choices, choice = option->choices; j > 0; j --, choice ++)
       if (choice->marked)
-        printf(" *%s", choice->choice);
+        _cupsLangPrintf(stdout, " *%s", choice->choice);
       else
-        printf(" %s", choice->choice);
+        _cupsLangPrintf(stdout, " %s", choice->choice);
 
-    putchar('\n');
+    _cupsLangPuts(stdout, "\n");
   }
 
   for (i = group->num_subgroups, subgroup = group->subgroups; i > 0; i --, subgroup ++)
@@ -399,14 +451,18 @@ list_options(cups_dest_t *dest)	/* I - Destination to list */
 
   if ((filename = cupsGetPPD(dest->name)) == NULL)
   {
-    fprintf(stderr, "lpoptions: Destination %s has no PPD file!\n", dest->name);
+    _cupsLangPrintf(stderr,
+                    _("lpoptions: Unable to get PPD file for %s: %s\n"),
+		    dest->name, cupsLastErrorString());
     return;
   }
 
   if ((ppd = ppdOpenFile(filename)) == NULL)
   {
     unlink(filename);
-    fprintf(stderr, "lpoptions: Unable to open PPD file for %s!\n", dest->name);
+    _cupsLangPrintf(stderr,
+                    _("lpoptions: Unable to open PPD file for %s!\n"),
+		    dest->name);
     return;
   }
 
@@ -428,15 +484,17 @@ list_options(cups_dest_t *dest)	/* I - Destination to list */
 void
 usage(void)
 {
-  puts("Usage: lpoptions [-h server] [-E] -d printer");
-  puts("       lpoptions [-h server] [-E] [-p printer] -l");
-  puts("       lpoptions [-h server] [-E] -p printer -o option[=value] ...");
-  puts("       lpoptions [-h server] [-E] -x printer");
+  _cupsLangPuts(stdout,
+                _("Usage: lpoptions [-h server] [-E] -d printer\n"
+		  "       lpoptions [-h server] [-E] [-p printer] -l\n"
+		  "       lpoptions [-h server] [-E] -p printer -o "
+		  "option[=value] ...\n"
+		  "       lpoptions [-h server] [-E] -x printer\n"));
 
   exit(1);
 }
 
 
 /*
- * End of "$Id: lpoptions.c,v 1.19 2005/01/03 19:29:59 mike Exp $".
+ * End of "$Id: lpoptions.c 6348 2007-03-18 03:21:59Z mike $".
  */
