@@ -1,9 +1,9 @@
 /*
- * "$Id: ipptest.c,v 1.19 2005/01/03 19:30:00 mike Exp $"
+ * "$Id: ipptest.c 5878 2006-08-24 15:55:42Z mike $"
  *
  *   IPP test command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products.
+ *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -23,13 +23,12 @@
  *
  * Contents:
  *
- *   main()          - Parse options and do tests.
- *   do_tests()      - Do tests as specified in the test file.
- *   get_operation() - Get an IPP opcode from an operation name...
- *   get_status()    - Get an IPP status from a status name...
- *   get_tag()       - Get an IPP value or group tag from a name...
- *   get_token()     - Get a token from a file.
- *   print_attr()    - Print an attribute on the screen.
+ *   main()       - Parse options and do tests.
+ *   do_tests()   - Do tests as specified in the test file.
+ *   get_tag()    - Get an IPP value or group tag from a name...
+ *   get_token()  - Get a token from a file.
+ *   print_attr() - Print an attribute on the screen.
+ *   usage()      - Show program usage.
  */
 
 /*
@@ -47,20 +46,68 @@
 
 
 /*
- * Local globals...
+ * Globals...
  */
 
+int		Verbosity = 0;		/* Show all attributes? */
+const char	* const TagNames[] =
+		{			/* Value/group tag names */
+		  "zero",		/* 0x00 */
+		  "operation",		/* 0x01 */
+		  "job",		/* 0x02 */
+		  "end",		/* 0x03 */
+		  "printer",		/* 0x04 */
+		  "unsupported-group",	/* 0x05 */
+		  "subscription",	/* 0x06 */
+		  "event-notification",	/* 0x07 */
+		  "", "", "", "", "", "", "", "",
+		  "unsupported-value",	/* 0x10 */
+		  "default",		/* 0x11 */
+		  "unknown",		/* 0x12 */
+		  "novalue",		/* 0x13 */
+		  "",
+		  "notsettable",	/* 0x15 */
+		  "deleteattr",		/* 0x16 */
+		  "anyvalue",		/* 0x17 */
+		  "", "", "", "", "", "", "", "", "",
+		  "integer",		/* 0x21 */
+		  "boolean",		/* 0x22 */
+		  "enum",		/* 0x23 */
+		  "", "", "", "", "", "", "", "", "", "", "", "",
+		  "string",		/* 0x30 */
+		  "date",		/* 0x31 */
+		  "resolution",		/* 0x32 */
+		  "range",		/* 0x33 */
+		  "collection",		/* 0x34 */
+		  "textlang",		/* 0x35 */
+		  "namelang",		/* 0x36 */
+		  "", "", "", "", "", "", "", "", "", "",
+		  "text",		/* 0x41 */
+		  "name",		/* 0x42 */
+		  "",
+		  "keyword",		/* 0x44 */
+		  "uri",		/* 0x45 */
+		  "urischeme",		/* 0x46 */
+		  "charset",		/* 0x47 */
+		  "language",		/* 0x48 */
+		  "mimetype"		/* 0x49 */
+		};
+
+
+
 
 /*
  * Local functions...
  */
 
 int		do_tests(const char *, const char *);
-ipp_op_t	get_operation(const char *);
-ipp_status_t	get_status(const char *);
+ipp_op_t	ippOpValue(const char *);
+ipp_status_t	ippErrorValue(const char *);
 ipp_tag_t	get_tag(const char *);
-char		*get_token(FILE *, char *, int);
+const char	*get_tag_string(ipp_tag_t tag);
+char		*get_token(FILE *, char *, int, int *linenum);
 void		print_attr(ipp_attribute_t *);
+void		usage(const char *option);
 
 
 /*
@@ -73,6 +120,9 @@ main(int  argc,				/* I - Number of command-line arguments */
 {
   int		i;			/* Looping var */
   int		status;			/* Status of tests... */
+  const char	*uri;			/* URI to use */
+  const char	*testfile;		/* Test file to use */
+  int		interval;		/* Test interval */
 
 
  /*
@@ -81,24 +131,77 @@ main(int  argc,				/* I - Number of command-line arguments */
   *     testipp URL testfile
   */
 
-  if (argc < 3)
+  uri      = NULL;
+  testfile = NULL;
+  status   = 0;
+  interval = 0;
+
+  for (i = 1; i < argc; i ++)
   {
-    fputs("Usage: ipptest URL testfile [ ... testfileN ]\n", stderr);
-    return (1);
+    if (argv[i][0] == '-')
+    {
+      if (!strcmp(argv[i], "-v"))
+        Verbosity ++;
+      else if (!strcmp(argv[i], "-i"))
+      {
+        i++;
+
+	if (i >= argc)
+	  usage(NULL);
+	else
+	  interval = atoi(argv[i]);
+      }
+      else
+        usage(argv[i]);
+    }
+    else if (!strncmp(argv[i], "ipp://", 6) ||
+             !strncmp(argv[i], "http://", 7) ||
+             !strncmp(argv[i], "https://", 8))
+    {
+     /*
+      * Set URI...
+      */
+
+      if (!testfile && uri)
+        usage(NULL);
+
+      uri      = argv[i];
+      testfile = NULL;
+    }
+    else
+    {
+     /*
+      * Run test...
+      */
+
+      testfile = argv[i];
+
+      if (!do_tests(uri, testfile))
+        status ++;
+    }
   }
 
+  if (!uri || !testfile)
+    usage(NULL);
+
  /*
-  * Run tests...
+  * Loop if the interval is set...
   */
 
-  for (i = 2, status = 1; status && i < argc; i ++)
-    status = status && do_tests(argv[1], argv[i]);
+  if (interval)
+  {
+    for (;;)
+    {
+      sleep(interval);
+      do_tests(uri, testfile);
+    }
+  }
 
  /*
   * Exit...
   */
 
-  return (!status);
+  return (status);
 }
 
 
@@ -111,6 +214,7 @@ do_tests(const char *uri,		/* I - URI to connect on */
          const char *testfile)		/* I - Test file to use */
 {
   int		i;			/* Looping var */
+  int		linenum;		/* Current line number */
   int		version;		/* IPP version number to use */
   http_t	*http;			/* HTTP connection to server */
   char		method[HTTP_MAX_URI],	/* URI method */
@@ -134,10 +238,13 @@ do_tests(const char *uri,		/* I - URI to connect on */
   ipp_status_t	statuses[100];		/* Valid status codes */
   int		num_expects;		/* Number of expected attributes */
   char		*expects[100];		/* Expected attributes */
+  int		num_displayed;		/* Number of displayed attributes */
+  char		*displayed[100];	/* Displayed attributes */
   char		name[1024];		/* Name of test */
   char		filename[1024];		/* Filename */
   int		pass;			/* Did we pass the test? */
   int		job_id;			/* Job ID from last operation */
+  int		subscription_id;	/* Subscription ID from last operation */
 
 
  /*
@@ -154,7 +261,9 @@ do_tests(const char *uri,		/* I - URI to connect on */
   * Connect to the server...
   */
 
-  httpSeparate(uri, method, userpass, server, &port, resource);
+  httpSeparateURI(HTTP_URI_CODING_ALL, uri, method, sizeof(method), userpass,
+                  sizeof(userpass), server, sizeof(server), &port, resource,
+		  sizeof(resource));
   if ((http = httpConnect(server, port)) == NULL)
   {
     printf("Unable to connect to %s on port %d - %s\n", server, port,
@@ -167,19 +276,22 @@ do_tests(const char *uri,		/* I - URI to connect on */
   */
 
   printf("\"%s\":\n", testfile);
-  pass    = 1;
-  job_id  = 0;
-  version = 1;
+  pass            = 1;
+  job_id          = 0;
+  subscription_id = 0;
+  version         = 1;
+  linenum         = 1;
 
-  while (get_token(fp, token, sizeof(token)) != NULL)
+  while (get_token(fp, token, sizeof(token), &linenum) != NULL)
   {
    /*
     * Expect an open brace...
     */
 
-    if (strcmp(token, "{") != 0)
+    if (strcmp(token, "{"))
     {
-      printf("Unexpected token %s seen - aborting test!\n", token);
+      printf("Unexpected token %s seen on line %d - aborting test!\n", token,
+             linenum);
       httpClose(http);
       return (0);
     }
@@ -188,15 +300,18 @@ do_tests(const char *uri,		/* I - URI to connect on */
     * Initialize things...
     */
 
-    httpSeparate(uri, method, userpass, server, &port, resource);
+    httpSeparateURI(HTTP_URI_CODING_ALL, uri, method, sizeof(method), userpass,
+                    sizeof(userpass), server, sizeof(server), &port, resource,
+		    sizeof(resource));
 
-    request      = ippNew();
-    op           = (ipp_op_t)0;
-    group        = IPP_TAG_OPERATION;
-    value        = IPP_TAG_ZERO;
-    num_statuses = 0;
-    num_expects  = 0;
-    filename[0]  = '\0';
+    request       = ippNew();
+    op            = (ipp_op_t)0;
+    group         = IPP_TAG_ZERO;
+    value         = IPP_TAG_ZERO;
+    num_statuses  = 0;
+    num_expects   = 0;
+    num_displayed = 0;
+    filename[0]   = '\0';
 
     strcpy(name, testfile);
     if (strrchr(name, '.') != NULL)
@@ -206,63 +321,80 @@ do_tests(const char *uri,		/* I - URI to connect on */
     * Parse until we see a close brace...
     */
 
-    while (get_token(fp, token, sizeof(token)) != NULL)
+    while (get_token(fp, token, sizeof(token), &linenum) != NULL)
     {
-      if (strcmp(token, "}") == 0)
+      if (!strcmp(token, "}"))
         break;
-      else if (strcasecmp(token, "NAME") == 0)
+      else if (!strcasecmp(token, "NAME"))
       {
        /*
         * Name of test...
 	*/
 
-	get_token(fp, name, sizeof(name));
+	get_token(fp, name, sizeof(name), &linenum);
       }
-      else if (strcasecmp(token, "VERSION") == 0)
+      else if (!strcasecmp(token, "VERSION"))
       {
        /*
         * IPP version number for test...
 	*/
 
-	get_token(fp, temp, sizeof(temp));
+	get_token(fp, temp, sizeof(temp), &linenum);
 	sscanf(temp, "%*d.%d", &version);
       }
-      else if (strcasecmp(token, "RESOURCE") == 0)
+      else if (!strcasecmp(token, "RESOURCE"))
       {
        /*
         * Resource name...
 	*/
 
-	get_token(fp, resource, sizeof(resource));
+	get_token(fp, resource, sizeof(resource), &linenum);
       }
-      else if (strcasecmp(token, "OPERATION") == 0)
+      else if (!strcasecmp(token, "OPERATION"))
       {
        /*
         * Operation...
 	*/
 
-	get_token(fp, token, sizeof(token));
-	op = get_operation(token);
+	get_token(fp, token, sizeof(token), &linenum);
+	op = ippOpValue(token);
       }
-      else if (strcasecmp(token, "GROUP") == 0)
+      else if (!strcasecmp(token, "GROUP"))
       {
        /*
         * Attribute group...
 	*/
 
-	get_token(fp, token, sizeof(token));
-	group = get_tag(token);
+	get_token(fp, token, sizeof(token), &linenum);
+	value = get_tag(token);
+
+	if (value == group)
+	  ippAddSeparator(request);
+
+        group = value;
       }
-      else if (strcasecmp(token, "ATTR") == 0)
+      else if (!strcasecmp(token, "DELAY"))
+      {
+       /*
+        * Delay before operation...
+	*/
+
+        int delay;
+
+	get_token(fp, token, sizeof(token), &linenum);
+	if ((delay = atoi(token)) > 0)
+	  sleep(delay);
+      }
+      else if (!strcasecmp(token, "ATTR"))
       {
        /*
         * Attribute...
 	*/
 
-	get_token(fp, token, sizeof(token));
+	get_token(fp, token, sizeof(token), &linenum);
 	value = get_tag(token);
-	get_token(fp, attr, sizeof(attr));
-	get_token(fp, temp, sizeof(temp));
+	get_token(fp, attr, sizeof(attr), &linenum);
+	get_token(fp, temp, sizeof(temp), &linenum);
 
         token[sizeof(token) - 1] = '\0';
 
@@ -274,44 +406,50 @@ do_tests(const char *uri,		/* I - URI to connect on */
 	    * Substitute a string/number...
 	    */
 
-            if (strncasecmp(tempptr + 1, "uri", 3) == 0)
+            if (!strncasecmp(tempptr + 1, "uri", 3))
 	    {
 	      strlcpy(tokenptr, uri, sizeof(token) - (tokenptr - token));
 	      tempptr += 4;
 	    }
-	    else if (strncasecmp(tempptr + 1, "method", 6) == 0)
+	    else if (!strncasecmp(tempptr + 1, "method", 6))
 	    {
 	      strlcpy(tokenptr, method, sizeof(token) - (tokenptr - token));
 	      tempptr += 7;
 	    }
-	    else if (strncasecmp(tempptr + 1, "username", 8) == 0)
+	    else if (!strncasecmp(tempptr + 1, "username", 8))
 	    {
 	      strlcpy(tokenptr, userpass, sizeof(token) - (tokenptr - token));
 	      tempptr += 9;
 	    }
-	    else if (strncasecmp(tempptr + 1, "hostname", 8) == 0)
+	    else if (!strncasecmp(tempptr + 1, "hostname", 8))
 	    {
 	      strlcpy(tokenptr, server, sizeof(token) - (tokenptr - token));
 	      tempptr += 9;
 	    }
-	    else if (strncasecmp(tempptr + 1, "port", 4) == 0)
+	    else if (!strncasecmp(tempptr + 1, "port", 4))
 	    {
 	      snprintf(tokenptr, sizeof(token) - (tokenptr - token),
 	               "%d", port);
 	      tempptr += 5;
 	    }
-	    else if (strncasecmp(tempptr + 1, "resource", 8) == 0)
+	    else if (!strncasecmp(tempptr + 1, "resource", 8))
 	    {
 	      strlcpy(tokenptr, resource, sizeof(token) - (tokenptr - token));
 	      tempptr += 9;
 	    }
-	    else if (strncasecmp(tempptr + 1, "job-id", 6) == 0)
+	    else if (!strncasecmp(tempptr + 1, "job-id", 6))
 	    {
 	      snprintf(tokenptr, sizeof(token) - (tokenptr - token),
 	               "%d", job_id);
 	      tempptr += 7;
 	    }
-	    else if (strncasecmp(tempptr + 1, "user", 4) == 0)
+	    else if (!strncasecmp(tempptr + 1, "notify-subscription-id", 22))
+	    {
+	      snprintf(tokenptr, sizeof(token) - (tokenptr - token),
+	               "%d", subscription_id);
+	      tempptr += 23;
+	    }
+	    else if (!strncasecmp(tempptr + 1, "user", 4))
 	    {
 	      strlcpy(tokenptr, cupsUser(), sizeof(token) - (tokenptr - token));
 	      tempptr += 5;
@@ -333,7 +471,7 @@ do_tests(const char *uri,		/* I - URI to connect on */
         switch (value)
 	{
 	  case IPP_TAG_BOOLEAN :
-	      if (strcasecmp(token, "true") == 0)
+	      if (!strcasecmp(token, "true"))
 		ippAddBoolean(request, group, attr, 1);
               else
 		ippAddBoolean(request, group, attr, atoi(token));
@@ -353,41 +491,80 @@ do_tests(const char *uri,		/* I - URI to connect on */
 	      break;
 
 	  default :
-	      ippAddString(request, group, value, attr, NULL, token);
+	      if (!strchr(token, ','))
+	        ippAddString(request, group, value, attr, NULL, token);
+	      else
+	      {
+	       /*
+	        * Multiple string values...
+		*/
+
+                int	num_values;	/* Number of values */
+                char	*values[100],	/* Values */
+			*ptr;		/* Pointer to next value */
+
+
+                values[0]  = token;
+		num_values = 1;
+
+                for (ptr = strchr(token, ','); ptr; ptr = strchr(ptr, ','))
+		{
+		  *ptr++ = '\0';
+		  values[num_values] = ptr;
+		  num_values ++;
+		}
+
+	        ippAddStrings(request, group, value, attr, num_values,
+		              NULL, (const char **)values);
+	      }
 	      break;
 	}
       }
-      else if (strcasecmp(token, "FILE") == 0)
+      else if (!strcasecmp(token, "FILE"))
       {
        /*
         * File...
 	*/
 
-	get_token(fp, filename, sizeof(filename));
+	get_token(fp, filename, sizeof(filename), &linenum);
       }
-      else if (strcasecmp(token, "STATUS") == 0)
+      else if (!strcasecmp(token, "STATUS") &&
+               num_statuses < (int)(sizeof(statuses) / sizeof(statuses[0])))
       {
        /*
         * Status...
 	*/
 
-	get_token(fp, token, sizeof(token));
-	statuses[num_statuses] = get_status(token);
+	get_token(fp, token, sizeof(token), &linenum);
+	statuses[num_statuses] = ippErrorValue(token);
 	num_statuses ++;
       }
-      else if (strcasecmp(token, "EXPECT") == 0)
+      else if (!strcasecmp(token, "EXPECT") &&
+               num_expects < (int)(sizeof(expects) / sizeof(expects[0])))
       {
        /*
-        * Status...
+        * Expected attributes...
 	*/
 
-	get_token(fp, token, sizeof(token));
+	get_token(fp, token, sizeof(token), &linenum);
 	expects[num_expects] = strdup(token);
 	num_expects ++;
       }
+      else if (!strcasecmp(token, "DISPLAY") &&
+               num_displayed < (int)(sizeof(displayed) / sizeof(displayed[0])))
+      {
+       /*
+        * Display attributes...
+	*/
+
+	get_token(fp, token, sizeof(token), &linenum);
+	displayed[num_displayed] = strdup(token);
+	num_displayed ++;
+      }
       else
       {
-	printf("Unexpected token %s seen - aborting test!\n", token);
+	printf("Unexpected token %s seen on line %d - aborting test!\n", token,
+	       linenum);
 	httpClose(http);
 	ippDelete(request);
 	return (0);
@@ -402,7 +579,15 @@ do_tests(const char *uri,		/* I - URI to connect on */
     request->request.op.operation_id = op;
     request->request.op.request_id   = 1;
 
-    printf("    %-60.60s [    ]", name);
+    if (Verbosity)
+    {
+      printf("%s:\n", ippOpString(op));
+
+      for (attrptr = request->attrs; attrptr; attrptr = attrptr->next)
+	print_attr(attrptr);
+    }
+
+    printf("    %-60.60s [", name);
     fflush(stdout);
 
     if (filename[0])
@@ -416,63 +601,84 @@ do_tests(const char *uri,		/* I - URI to connect on */
 
       curtime = time(NULL);
 
-      printf("\b\b\b\b\bFAIL]\n");
-      printf("        ERROR %x\n", cupsLastError());
-      printf("        (%s) @ %s\n",
-	     ippErrorString(cupsLastError()), ctime(&curtime));
+      puts("FAIL]");
+      printf("        ERROR %04x (%s) @ %s\n", cupsLastError(),
+	     cupsLastErrorString(), ctime(&curtime));
       pass = 0;
     }
     else
     {
-      if ((attrptr = ippFindAttribute(response, "job-id", IPP_TAG_INTEGER)) != NULL)
+      if ((attrptr = ippFindAttribute(response, "job-id",
+                                      IPP_TAG_INTEGER)) != NULL)
         job_id = attrptr->values[0].integer;
 
+      if ((attrptr = ippFindAttribute(response, "notify-subscription-id",
+                                      IPP_TAG_INTEGER)) != NULL)
+        subscription_id = attrptr->values[0].integer;
+
       for (i = 0; i < num_statuses; i ++)
         if (response->request.status.status_code == statuses[i])
 	  break;
 
       if (i == num_statuses && num_statuses > 0)
-      {
-	printf("\b\b\b\b\bFAIL]\n");
-        printf("        STATUS %x\n", response->request.status.status_code);
-        printf("        (%s)\n",
-	       ippErrorString(response->request.status.status_code));
-	printf("        (%lu bytes in response)\n",
-	       (unsigned long)ippLength(response));
-
 	pass = 0;
-      }
       else
       {
         for (i = 0; i < num_expects; i ++)
 	  if (ippFindAttribute(response, expects[i], IPP_TAG_ZERO) == NULL)
 	  {
-	    if (pass)
-	    {
-	      printf("\b\b\b\b\bFAIL]\n");
-	      printf("        (%lu bytes in response)\n",
-	             (unsigned long)ippLength(response));
-	      pass = 0;
-	    }
-
-	    printf("        EXPECTED %s\n", expects[i]);
+	    pass = 0;
+	    break;
 	  }
+      }
 
-	if (pass)
-	{
-	  printf("\b\b\b\b\bPASS]\n");
-	  printf("        (%lu bytes in response)\n",
-	         (unsigned long)ippLength(response));
-	}
-	else
-	{
-	  puts("        RECEIVED");
-	  printf("        status-code = %04x\n",
-	         response->request.status.status_code);
+      if (pass)
+      {
+	puts("PASS]");
+	printf("        RECEIVED: %lu bytes in response\n",
+	       (unsigned long)ippLength(response));
 
+        if (Verbosity)
+	{
 	  for (attrptr = response->attrs; attrptr != NULL; attrptr = attrptr->next)
 	    print_attr(attrptr);
-	}
+        }
+        else if (num_displayed > 0)
+	{
+	  for (attrptr = response->attrs; attrptr != NULL; attrptr = attrptr->next)
+	    if (attrptr->name)
+	    {
+	      for (i = 0; i < num_displayed; i ++)
+		if (!strcmp(displayed[i], attrptr->name))
+		{
+		  print_attr(attrptr);
+		  break;
+		}
+	    }
+        }
+      }
+      else
+      {
+	puts("FAIL]");
+	printf("        RECEIVED: %lu bytes in response\n",
+	       (unsigned long)ippLength(response));
+
+	for (i = 0; i < num_statuses; i ++)
+          if (response->request.status.status_code == statuses[i])
+	    break;
+
+	if (i == num_statuses && num_statuses > 0)
+	  puts("        BAD STATUS");
+
+	printf("        status-code = %04x (%s)\n",
+	       cupsLastError(), cupsLastErrorString());
+
+        for (i = 0; i < num_expects; i ++)
+	  if (ippFindAttribute(response, expects[i], IPP_TAG_ZERO) == NULL)
+	    printf("        EXPECTED: %s\n", expects[i]);
+
+	for (attrptr = response->attrs; attrptr != NULL; attrptr = attrptr->next)
+	  print_attr(attrptr);
       }
 
       ippDelete(response);
@@ -492,184 +698,52 @@ do_tests(const char *uri,		/* I - URI to connect on */
 }
 
 
-/*
- * 'get_operation()' - Get an IPP opcode from an operation name...
- */
-
-ipp_op_t
-get_operation(const char *name)
-{
-  int		i;
-  static char	*ipp_ops[] =
-		{
-		  "",
-		  "",
-		  "print-job",
-		  "print-uri",
-		  "validate-job",
-		  "create-job",
-		  "send-document",
-		  "send-uri",
-		  "cancel-job",
-		  "get-job-attributes",
-		  "get-jobs",
-		  "get-printer-attributes",
-		  "hold-job",
-		  "release-job",
-		  "restart-job",
-		  "",
-		  "pause-printer",
-		  "resume-printer",
-		  "purge-jobs",
-		  "set-printer-attributes",
-		  "set-job-attributes",
-		  "get-printer-supported-values"
-		},
-		*cups_ops[] =
-		{
-		  "cups-get-default",
-		  "cups-get-printers",
-		  "cups-add-printer",
-		  "cups-delete-printer",
-		  "cups-get-classes",
-		  "cups-add-class",
-		  "cups-delete-class",
-		  "cups-accept-jobs",
-		  "cups-reject-jobs",
-		  "cups-set-default",
-		  "cups-get-devices",
-		  "cups-get-ppds",
-		  "cups-move-job"
-		};
-
-
-  for (i = 0; i < (sizeof(ipp_ops) / sizeof(ipp_ops[0])); i ++)
-    if (strcasecmp(name, ipp_ops[i]) == 0)
-      return ((ipp_op_t)i);
-
-  if (strcasecmp(name, "windows-ext") == 0)
-    return (IPP_PRIVATE);
-
-  for (i = 0; i < (sizeof(cups_ops) / sizeof(cups_ops[0])); i ++)
-    if (strcasecmp(name, cups_ops[i]) == 0)
-      return ((ipp_op_t)(i + 0x4001));
-
-  return ((ipp_op_t)0);
-}
-
-
-/*
- * 'get_status()' - Get an IPP status from a status name...
- */
-
-ipp_status_t
-get_status(const char *name)
-{
-  int		i;
-  static const char *status_oks[] =	/* "OK" status codes */
-		{
-		  "successful-ok",
-		  "successful-ok-ignored-or-substituted-attributes",
-		  "successful-ok-conflicting-attributes"
-		},
-		*status_400s[] =	/* Client errors */
-		{
-		  "client-error-bad-request",
-		  "client-error-forbidden",
-		  "client-error-not-authenticated",
-		  "client-error-not-authorized",
-		  "client-error-not-possible",
-		  "client-error-timeout",
-		  "client-error-not-found",
-		  "client-error-gone",
-		  "client-error-request-entity-too-large",
-		  "client-error-request-value-too-long",
-		  "client-error-document-format-not-supported",
-		  "client-error-attributes-or-values-not-supported",
-		  "client-error-uri-scheme-not-supported",
-		  "client-error-charset-not-supported",
-		  "client-error-conflicting-attributes",
-		  "client-error-compression-not-supported",
-		  "client-error-compression-error",
-		  "client-error-document-format-error",
-		  "client-error-document-access-error"
-		},
-		*status_500s[] =	/* Server errors */
-		{
-		  "server-error-internal-error",
-		  "server-error-operation-not-supported",
-		  "server-error-service-unavailable",
-		  "server-error-version-not-supported",
-		  "server-error-device-error",
-		  "server-error-temporary-error",
-		  "server-error-not-accepting-jobs",
-		  "server-error-busy",
-		  "server-error-job-canceled",
-		  "server-error-multiple-document-jobs-not-supported"
-		};
-
-
-  for (i = 0; i < (sizeof(status_oks) / sizeof(status_oks[0])); i ++)
-    if (strcasecmp(name, status_oks[i]) == 0)
-      return ((ipp_status_t)i);
-
-  for (i = 0; i < (sizeof(status_400s) / sizeof(status_400s[0])); i ++)
-    if (strcasecmp(name, status_400s[i]) == 0)
-      return ((ipp_status_t)(i + 0x400));
-
-  for (i = 0; i < (sizeof(status_500s) / sizeof(status_500s[0])); i ++)
-    if (strcasecmp(name, status_500s[i]) == 0)
-      return ((ipp_status_t)(i + 0x500));
-
-  return ((ipp_status_t)-1);
-}
-
-
 /*
  * 'get_tag()' - Get an IPP value or group tag from a name...
  */
 
-ipp_tag_t
-get_tag(const char *name)
+ipp_tag_t				/* O - Value/group tag */
+get_tag(const char *name)		/* I - Name of value/group tag */
 {
-  int		i;
-  static char	*names[] =
-		{
-		  "zero", "operation", "job", "end", "printer",
-		  "unsupported-group", "", "", "", "", "", "", "",
-		  "", "", "", "unsupported-value", "default",
-		  "unknown", "novalue", "", "notsettable",
-		  "deleteattr", "anyvalue", "", "", "", "", "", "",
-		  "", "", "", "integer", "boolean", "enum", "", "",
-		  "", "", "", "", "", "", "", "", "", "", "string",
-		  "date", "resolution", "range", "collection",
-		  "textlang", "namelang", "", "", "", "", "", "", "",
-		  "", "", "", "text", "name", "", "keyword", "uri",
-		  "urischeme", "charset", "language", "mimetype"
-		};
+  int			i;		/* Looping var */
 
 
-  for (i = 0; i < (sizeof(names) / sizeof(names[0])); i ++)
-    if (strcasecmp(name, names[i]) == 0)
+  for (i = 0; i < (sizeof(TagNames) / sizeof(TagNames[0])); i ++)
+    if (!strcasecmp(name, TagNames[i]))
       return ((ipp_tag_t)i);
 
   return (IPP_TAG_ZERO);
 }
 
 
+/*
+ * 'get_tag_string()' - Get the string associated with a tag.
+ */
+
+const char *				/* O - Tag name string */
+get_tag_string(ipp_tag_t tag)		/* I - IPP tag */
+{
+  if (tag < (ipp_tag_t)(sizeof(TagNames) / sizeof(TagNames[0])))
+    return (TagNames[tag]);
+  else
+    return ("UNKNOWN");
+}
+
+
 /*
  * 'get_token()' - Get a token from a file.
  */
 
-char *				/* O - Token from file or NULL on EOF */
-get_token(FILE *fp,		/* I - File to read from */
-          char *buf,		/* I - Buffer to read into */
-	  int  buflen)		/* I - Length of buffer */
+char *					/* O  - Token from file or NULL on EOF */
+get_token(FILE *fp,			/* I  - File to read from */
+          char *buf,			/* I  - Buffer to read into */
+	  int  buflen,			/* I  - Length of buffer */
+	  int  *linenum)		/* IO - Current line number */
 {
-  int	ch,			/* Character from file */
-	quote;			/* Quoting character */
-  char	*bufptr,		/* Pointer into buffer */
-	*bufend;		/* End of buffer */
+  int	ch,				/* Character from file */
+	quote;				/* Quoting character */
+  char	*bufptr,			/* Pointer into buffer */
+	*bufend;			/* End of buffer */
 
 
   for (;;)
@@ -678,7 +752,11 @@ get_token(FILE *fp,		/* I - File to read from */
     * Skip whitespace...
     */
 
-    while (isspace(ch = getc(fp)));
+    while (isspace(ch = getc(fp)))
+    {
+      if (ch == '\n')
+        (*linenum) ++;
+    }
 
    /*
     * Read a token...
@@ -714,6 +792,8 @@ get_token(FILE *fp,		/* I - File to read from */
       while ((ch = getc(fp)) != EOF)
 	if (ch == '\n')
           break;
+
+      (*linenum) ++;
     }
     else
     {
@@ -758,7 +838,9 @@ print_attr(ipp_attribute_t *attr)	/* I - Attribute to print */
     return;
   }
 
-  printf("        %s = ", attr->name);
+  printf("        %s (%s%s) = ", attr->name,
+         attr->num_values > 1 ? "1setOf " : "",
+	 get_tag_string(attr->value_tag));
 
   switch (attr->value_tag)
   {
@@ -822,5 +904,25 @@ print_attr(ipp_attribute_t *attr)	/* I - Attribute to print */
 
 
 /*
- * End of "$Id: ipptest.c,v 1.19 2005/01/03 19:30:00 mike Exp $".
+ * 'usage()' - Show program usage.
+ */
+
+void
+usage(const char *option)		/* I - Option string or NULL */
+{
+  if (option)
+    fprintf(stderr, "ipptest: Unknown option \"%s\"!\n", option);
+
+  fputs("Usage: ipptest [options] URL testfile [ ... testfileN ]\n", stderr);
+  fputs("Options:\n", stderr);
+  fputs("\n", stderr);
+  fputs("-i N    Repeat the last test file once every N seconds.\n", stderr);
+  fputs("-v      Show all attributes in response, even on success.\n", stderr);
+
+  exit(1);
+}
+
+
+/*
+ * End of "$Id: ipptest.c 5878 2006-08-24 15:55:42Z mike $".
  */
