@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# "$Id: run-stp-tests.sh 5493 2006-05-05 16:33:57Z mike $"
+# "$Id: run-stp-tests.sh 6393 2007-03-24 14:37:13Z mike $"
 #
 #   Perform the complete set of IPP compliance tests specified in the
 #   CUPS Software Test Plan.
@@ -120,8 +120,8 @@ echo "certificate for testing; these tests currently require the OpenSSL"
 echo "tools:"
 echo ""
 echo "0 - Do not do SSL/TLS encryption tests"
-echo "1 - Create a SSL/TLS certificate and key, but do not require encryption"
-echo "2 - Create a SSL/TLS certificate and key and require encryption"
+echo "1 - Test but do not require encryption"
+echo "2 - Test and require encryption"
 echo ""
 echo $ac_n "Enter the number of the SSL/TLS tests to perform: [0] $ac_c"
 
@@ -134,25 +134,14 @@ fi
 echo ""
 
 case "$ssltype" in
-	1 | 2)
-		if test -f server.key; then
-			echo "Using existing SSL/TLS certificate and key..."
-		else
-			echo "Generating SSL/TLS certificate and key..."
-			openssl req -new -x509 -keyout server.key -out server.crt -days 3650 -nodes >/dev/null <<EOF
-ZZ
-Testland
-Testville
-Test Company
-
-`hostname`
-test@domain.com
-EOF
-		fi
+	1)
+		echo "Will test but not require encryption (1)"
+		;;
+	2)
+		echo "Will test and require encryption (2)"
 		;;
-
 	*)
-		echo "Not using SSL/TLS..."
+		echo "Not using SSL/TLS (0)"
 		ssltype=0
 		;;
 esac
@@ -415,6 +404,13 @@ CUPS_DATADIR=/tmp/cups-$user/share; export CUPS_DATADIR
 HOME=/tmp/cups-$user
 export HOME
 
+#
+# Force POSIX locale for tests...
+#
+
+LANG=C
+export LANG
+
 #
 # Start the server; run as foreground daemon in the background...
 #
@@ -595,5 +591,5 @@ echo "A HTML report was created in test/$strfile."
 echo ""
 
 #
-# End of "$Id: run-stp-tests.sh 5493 2006-05-05 16:33:57Z mike $"
+# End of "$Id: run-stp-tests.sh 6393 2007-03-24 14:37:13Z mike $"
 #
